<?php
/**
 * Featured Content options
 *
 * @package Catch_Store
 */

/**
 * Add featured content options to theme options
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function catch_store_featured_content_options( $wp_customize ) {
	// Add note to ECT Featured Content Section
    catch_store_register_option( $wp_customize, array(
            'name'              => 'catch_store_featured_content_jetpack_note',
            'sanitize_callback' => 'sanitize_text_field',
            'custom_control'    => 'catch_store_Note_Control',
            'label'             => sprintf( esc_html__( 'For all Featured Content Options for Catch Store Theme, go %1$shere%2$s', 'catch-store-pro' ),
                '<a href="javascript:wp.customize.section( \'catch_store_featured_content\' ).focus();">',
                 '</a>'
            ),
           'section'            => 'featured_content',
            'type'              => 'description',
            'priority'          => 1,
        )
    );

    $wp_customize->add_section( 'catch_store_featured_content', array(
			'title' => esc_html__( 'Featured Content', 'catch-store-pro' ),
			'panel' => 'catch_store_theme_options',
		)
	);

	// Add color scheme setting and control.
	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_featured_content_option',
			'default'           => 'homepage',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'choices'           => catch_store_section_visibility_options(),
			'label'             => esc_html__( 'Enable on', 'catch-store-pro' ),
			'section'           => 'catch_store_featured_content',
			'type'              => 'select',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_featured_content_layout',
			'default'           => 'layout-four',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'active_callback'   => 'catch_store_is_featured_content_active',
			'choices'           => catch_store_sections_layout_options(),
			'label'             => esc_html__( 'Select Featured Content Layout', 'catch-store-pro' ),
			'section'           => 'catch_store_featured_content',
			'type'              => 'select',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_featured_content_archive_title',
			'default'           => esc_html__( 'Featured', 'catch-store-pro' ),
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'catch_store_is_featured_page_post_tag_category_image_content_active',
			'label'             => esc_html__( 'Featured Content Title', 'catch-store-pro' ),
			'section'           => 'catch_store_featured_content',
			'type'              => 'text',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_featured_content_sub_title',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'catch_store_is_featured_page_post_tag_category_image_content_active',
			'label'             => esc_html__( 'Featured Content Archive Content', 'catch-store-pro' ),
			'section'           => 'catch_store_featured_content',
			'type'              => 'textarea',
		)
	);

	$type = catch_store_section_type_options();

	unset( $type['demo'] );

	$type['featured-content'] = esc_html__( 'Custom Post Type', 'catch-store-pro' );

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_featured_content_type',
			'default'           => 'category',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'active_callback'   => 'catch_store_is_featured_content_active',
			/* translators: 1: plugin <a>/link tag start, 2: plugin </a>/link tag close. */
			'description'       => sprintf( esc_html__( 'For Custom Post Type Content, install %1$sEssential Content Types%2$s Plugin with Featured Content Type Enabled', 'catch-store-pro' ),
                '<a target="_blank" href="https://wordpress.org/plugins/essential-content-types/">',
                '</a>'
            ),
            'choices'           => $type,
			'label'             => esc_html__( 'Type', 'catch-store-pro' ),
			'section'           => 'catch_store_featured_content',
			'type'              => 'select',
		)
	);

    catch_store_register_option( $wp_customize, array(
            'name'              => 'catch_store_featured_content_cpt_note',
            'sanitize_callback' => 'sanitize_text_field',
            'custom_control'    => 'catch_store_Note_Control',
            'active_callback'   => 'catch_store_is_featured_cpt_content_active',
            /* translators: 1: <a>/link tag start, 2: </a>/link tag close. */
			'label'             => sprintf( esc_html__( 'For CPT heading and sub-heading, go %1$shere%2$s', 'catch-store-pro' ),
                 '<a href="javascript:wp.customize.control( \'featured_content_title\' ).focus();">',
                 '</a>'
            ),
            'section'           => 'catch_store_featured_content',
            'type'              => 'description',
        )
    );

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_featured_content_number',
			'default'           => 4,
			'sanitize_callback' => 'catch_store_sanitize_number_range',
			'active_callback'   => 'catch_store_is_featured_content_active',
			'description'       => esc_html__( 'Save and refresh the page if No. of Featured Content is changed (Max no of Featured Content is 20)', 'catch-store-pro' ),
			'input_attrs'       => array(
				'style' => 'width: 100px;',
				'min'   => 0,
			),
			'label'             => esc_html__( 'No of Featured Content', 'catch-store-pro' ),
			'section'           => 'catch_store_featured_content',
			'type'              => 'number',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_featured_content_show',
			'default'           => 'excerpt',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'active_callback'   => 'catch_store_is_featured_post_product_tag_category_cpt_content_active',
			'choices'           => catch_store_content_show(),
			'label'             => esc_html__( 'Display Content', 'catch-store-pro' ),
			'section'           => 'catch_store_featured_content',
			'type'              => 'select',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_featured_meta_show',
			'default'           => 'hide-meta',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'active_callback'   => 'catch_store_is_featured_post_product_tag_category_cpt_content_active',
			'choices'           => catch_store_meta_show(),
			'label'             => esc_html__( 'Display Meta', 'catch-store-pro' ),
			'section'           => 'catch_store_featured_content',
			'type'              => 'select',
		)
	);


	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_featured_content_select_category',
			'sanitize_callback' => 'catch_store_sanitize_category_list',
			'custom_control'    => 'catch_store_Multi_Categories_Control',
			'active_callback'   => 'catch_store_is_featured_category_content_active',
			'label'             => esc_html__( 'Select Categories', 'catch-store-pro' ),
			'name'              => 'catch_store_featured_content_select_category',
			'section'           => 'catch_store_featured_content',
			'type'              => 'dropdown-categories',
		)
	);

	$number = get_theme_mod( 'catch_store_featured_content_number', 4 );

	//loop for featured post content
	for ( $i = 1; $i <= $number ; $i++ ) {
		catch_store_register_option( $wp_customize, array(
				'name'              => 'catch_store_featured_content_post_' . $i,
				'sanitize_callback' => 'catch_store_sanitize_post',
				'default'           => 0,
				'active_callback'   => 'catch_store_is_featured_post_content_active',
				'input_attrs'       => array(
					'style'             => 'width: 40px;'
				),
				'label'             => esc_html__( 'Post', 'catch-store-pro' ) . ' ' . $i ,
				'section'           => 'catch_store_featured_content',
				'choices'           => catch_store_generate_post_array(),
				'type'              => 'select'
			)
		);

		if ( catch_store_is_woocommerce_activated() ) {
			catch_store_register_option( $wp_customize, array(
					'name'              => 'catch_store_featured_content_product_' . $i,
					'sanitize_callback' => 'catch_store_sanitize_post',
					'active_callback'   => 'catch_store_is_featured_product_content_active',
					'label'             => esc_html__( 'Featured Product', 'catch-store-pro' ) . ' ' . $i ,
					'section'           => 'catch_store_featured_content',
					'type'              => 'select',
					'choices'           => catch_store_generate_products_array(),
				)
			);
		}

		catch_store_register_option( $wp_customize, array(
				'name'              => 'catch_store_featured_content_page_' . $i,
				'sanitize_callback' => 'catch_store_sanitize_post',
				'active_callback'   => 'catch_store_is_featured_page_content_active',
				'label'             => esc_html__( 'Featured Page', 'catch-store-pro' ) . ' ' . $i ,
				'section'           => 'catch_store_featured_content',
				'type'              => 'dropdown-pages',
			)
		);

		catch_store_register_option( $wp_customize, array(
				'name'              => 'catch_store_featured_content_cpt_' . $i,
				'sanitize_callback' => 'catch_store_sanitize_post',
				'active_callback'   => 'catch_store_is_featured_cpt_content_active',
				'label'             => esc_html__( 'Featured Content', 'catch-store-pro' ) . ' ' . $i ,
				'section'           => 'catch_store_featured_content',
				'type'              => 'select',
                'choices'           => catch_store_generate_post_array( 'featured-content' ),
			)
		);

		catch_store_register_option( $wp_customize, array(
				'name'              => 'catch_store_featured_content_note_' . $i,
				'sanitize_callback' => 'sanitize_text_field',
				'custom_control'    => 'catch_store_Note_Control',
				'active_callback'   => 'catch_store_is_featured_image_content_active',
				'label'             => esc_html__( 'Featured Content #', 'catch-store-pro' ) .  $i,
				'section'           => 'catch_store_featured_content',
				'type'              => 'description',
			)
		);

		catch_store_register_option( $wp_customize, array(
				'name'              => 'catch_store_featured_content_image_' . $i,
				'sanitize_callback' => 'catch_store_sanitize_image',
				'custom_control'    => 'WP_Customize_Image_Control',
				'active_callback'   => 'catch_store_is_featured_image_content_active',
				'label'             => esc_html__( 'Image', 'catch-store-pro' ),
				'section'           => 'catch_store_featured_content',
			)
		);

		catch_store_register_option( $wp_customize, array(
				'name'              => 'catch_store_featured_content_link_' . $i,
				'sanitize_callback' => 'esc_url_raw',
				'active_callback'   => 'catch_store_is_featured_image_content_active',
				'label'             => esc_html__( 'Link', 'catch-store-pro' ),
				'section'           => 'catch_store_featured_content',
			)
		);

		catch_store_register_option( $wp_customize, array(
				'name'              => 'catch_store_featured_content_target_' . $i,
				'sanitize_callback' => 'catch_store_sanitize_checkbox',
				'active_callback'   => 'catch_store_is_featured_image_content_active',
				'label'             => esc_html__( 'Check to Open Link in New Window/Tab', 'catch-store-pro' ),
				'section'           => 'catch_store_featured_content',
				'type'              => 'checkbox',
			)
		);

		catch_store_register_option( $wp_customize, array(
				'name'              => 'catch_store_featured_content_title_' . $i,
				'sanitize_callback' => 'wp_kses_post',
				'active_callback'   => 'catch_store_is_featured_image_content_active',
				'label'             => esc_html__( 'Title', 'catch-store-pro' ),
				'section'           => 'catch_store_featured_content',
				'type'              => 'text',
			)
		);

		catch_store_register_option( $wp_customize, array(
				'name'              => 'catch_store_featured_content_content_' . $i,
				'sanitize_callback' => 'wp_kses_post',
				'active_callback'   => 'catch_store_is_featured_image_content_active',
				'label'             => esc_html__( 'Content', 'catch-store-pro' ),
				'section'           => 'catch_store_featured_content',
				'type'              => 'textarea',
			)
		);
	} // End for().
}
add_action( 'customize_register', 'catch_store_featured_content_options', 10 );

/** Active Callback Functions **/
if( ! function_exists( 'catch_store_is_featured_content_active' ) ) :
	/**
	* Return true if featured content is active
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_featured_content_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'catch_store_featured_content_option' )->value();

		//return true only if previwed page on customizer matches the type of content option selected
		return ( 'entire-site' == $enable || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'homepage' == $enable )
	);
	}
endif;


if( ! function_exists( 'catch_store_is_demo_featured_content_inactive' ) ) :
	/**
	* Return true if demo featured content is inactive
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_demo_featured_content_inactive( $control ) {
		$type = $control->manager->get_setting( 'catch_store_featured_content_type' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and is or is not selected type
		return ( catch_store_is_featured_content_active( $control ) && !( 'demo' === $type )
	);
	}
endif;


if( ! function_exists( 'catch_store_is_featured_post_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_featured_post_content_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_featured_content_type' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and is or is not selected type
		return ( catch_store_is_featured_content_active( $control ) && ( 'post' === $type )
	);
	}
endif;


if( ! function_exists( 'catch_store_is_featured_page_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_featured_page_content_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_featured_content_type' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and is or is not selected type
		return ( catch_store_is_featured_content_active( $control ) && ( 'page' === $type )
	);
	}
endif;

if( ! function_exists( 'catch_store_is_featured_cpt_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_featured_cpt_content_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_featured_content_type' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and is or is not selected type
		return ( catch_store_is_featured_content_active( $control ) && ( 'featured-content' === $type )
	);
	}
endif;


if( ! function_exists( 'catch_store_is_featured_category_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_featured_category_content_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_featured_content_type' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and is or is not selected type
		return ( catch_store_is_featured_content_active( $control ) && ( 'category' === $type )
	);
	}
endif;


if( ! function_exists( 'catch_store_is_featured_page_post_tag_category_image_content_active' ) ) :
	/**
	* Return true if page/post/category/image content is active
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_featured_page_post_tag_category_image_content_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_featured_content_type' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and is or is not selected type
		return ( catch_store_is_featured_content_active( $control ) && ( 'image' === $type || 'category' === $type || 'page' === $type ) || 'post' === $type || 'tag' === $type );
	}
endif;


if( ! function_exists( 'catch_store_is_featured_post_product_tag_category_cpt_content_active' ) ) :
	/**
	* Return true if page/post/category/image content is active
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_featured_post_product_tag_category_cpt_content_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_featured_content_type' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and is or is not selected type
		return ( catch_store_is_featured_content_active( $control ) && ( 'category' === $type || 'post' === $type || 'tag' === $type || 'featured-content' === $type || 'product' === $type ) );
	}
endif;


if( ! function_exists( 'catch_store_is_featured_image_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_featured_image_content_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_featured_content_type' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and is or is not selected type
		return ( catch_store_is_featured_content_active( $control ) && ( 'image' === $type )
	);
	}
endif;


if( ! function_exists( 'catch_store_is_featured_tag_content_active' ) ) :
	/**
	* Return true if tag content is active
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_featured_tag_content_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_featured_content_type' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and is or is not selected type
		return ( catch_store_is_featured_content_active( $control ) && ( 'tag' === $type )
	);
	}
endif;

if( ! function_exists( 'catch_store_is_featured_product_content_active' ) ) :
	/**
	* Return true if product content is active
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_featured_product_content_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_featured_content_type' )->value();

		return ( catch_store_is_featured_content_active( $control ) && ( 'product' === $type ) );
	}
endif;