<?php
/**
 * Featured Slider Options
 *
 * @package Catch_Store
 */

/**
 * Add hero content options to theme options
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function catch_store_slider_options( $wp_customize ) {
	$wp_customize->add_section( 'catch_store_featured_slider', array(
			'panel' => 'catch_store_theme_options',
			'title' => esc_html__( 'Featured Slider', 'catch-store-pro' ),
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_slider_option',
			'default'           => 'disabled',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'choices'           => catch_store_section_visibility_options(),
			'label'             => esc_html__( 'Enable on', 'catch-store-pro' ),
			'section'           => 'catch_store_featured_slider',
			'type'              => 'select',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_slider_transition_effect',
			'default'           => 'fade',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'active_callback'   => 'catch_store_is_slider_active',
			'choices'           => catch_store_slider_transition_effects(),
			'label'             => esc_html__( 'Transition Effect', 'catch-store-pro' ),
			'section'           => 'catch_store_featured_slider',
			'type'              => 'select',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_slider_transition_delay',
			'default'           => '4',
			'sanitize_callback' => 'absint',
			'active_callback'   => 'catch_store_is_slider_active',
			'description'       => esc_html__( 'seconds(s)', 'catch-store-pro' ),
			'input_attrs'       => array(
				'style' => 'width: 40px;',
			),
			'label'             => esc_html__( 'Transition Delay', 'catch-store-pro' ),
			'section'           => 'catch_store_featured_slider',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_slider_transition_length',
			'default'           => '1',
			'sanitize_callback' => 'absint',

			'active_callback'   => 'catch_store_is_slider_active',
			'description'       => esc_html__( 'seconds(s)', 'catch-store-pro' ),
			'input_attrs'       => array(
				'style' => 'width: 100px;',
			),
			'label'             => esc_html__( 'Transition Length', 'catch-store-pro' ),
			'section'           => 'catch_store_featured_slider',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_slider_image_loader',
			'default'           => 'false',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'active_callback'   => 'catch_store_is_slider_active',
			'choices'           => catch_store_slider_image_loader(),
			'label'             => esc_html__( 'Image Loader', 'catch-store-pro' ),
			'section'           => 'catch_store_featured_slider',
			'type'              => 'select',
		)
	);

	$type = catch_store_section_type_options();

	unset( $type['demo'] );

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_slider_type',
			'default'           => 'category',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'active_callback'   => 'catch_store_is_slider_active',
			'choices'           => $type,
			'label'             => esc_html__( 'Select Slider Type', 'catch-store-pro' ),
			'section'           => 'catch_store_featured_slider',
			'type'              => 'select',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_slider_number',
			'default'           => '4',
			'sanitize_callback' => 'catch_store_sanitize_number_range',

			'active_callback'   => 'catch_store_is_slider_active',
			'description'       => esc_html__( 'Save and refresh the page if No. of Slides is changed (Max no of slides is 20)', 'catch-store-pro' ),
			'input_attrs'       => array(
				'style' => 'width: 100px;',
				'min'   => 0,
				'max'   => 20,
				'step'  => 1,
			),
			'label'             => esc_html__( 'No of Slides', 'catch-store-pro' ),
			'section'           => 'catch_store_featured_slider',
			'type'              => 'number',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_slider_content_show',
			'default'           => 'hide-content',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'active_callback'   => 'catch_store_is_slider_active',
			'choices'           => catch_store_content_show(),
			'label'             => esc_html__( 'Display Content', 'catch-store-pro' ),
			'section'           => 'catch_store_featured_slider',
			'type'              => 'select',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_slider_meta_show',
			'default'           => 'show-meta',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'active_callback'   => 'catch_store_is_post_category_slider_active',
			'choices'           => catch_store_meta_show(),
			'label'             => esc_html__( 'Display Meta', 'catch-store-pro' ),
			'section'           => 'catch_store_featured_slider',
			'type'              => 'select',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_exclude_slider_post',
			'sanitize_callback' => 'catch_store_sanitize_checkbox',
			'active_callback'   => 'catch_store_is_post_slider_active',
			'label'             => esc_html__( 'Check to exclude Slider post from Homepage posts', 'catch-store-pro' ),
			'section'           => 'catch_store_featured_slider',
			'type'              => 'checkbox',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_slider_select_category',
			'sanitize_callback' => 'catch_store_sanitize_category_list',
			'custom_control'    => 'catch_store_Multi_Categories_Control',
			'active_callback'   => 'catch_store_is_category_slider_active',
			'label'             => esc_html__( 'Select Categories', 'catch-store-pro' ),
			'name'              => 'catch_store_slider_select_category',
			'section'           => 'catch_store_featured_slider',
			'type'              => 'dropdown-categories',
		)
	);

	$slider_number = get_theme_mod( 'catch_store_slider_number', 4 );

	for ( $i = 1; $i <= $slider_number ; $i++ ) {
		// Post Sliders
		catch_store_register_option( $wp_customize, array(
				'name'              =>'catch_store_slider_post_' . $i,
				'sanitize_callback' => 'catch_store_sanitize_post',
				'active_callback'   => 'catch_store_is_post_slider_active',
				'input_attrs'       => array(
					'style' => 'width: 80px;',
				),
				'label'             => esc_html__( 'Post', 'catch-store-pro' ) . ' # ' . $i,
				'section'           => 'catch_store_featured_slider',
				'choices'           => catch_store_generate_post_array(),
				'type'              => 'select',
			)
		);

		// Page Sliders
		catch_store_register_option( $wp_customize, array(
				'name'              =>'catch_store_slider_page_' . $i,
				'sanitize_callback' => 'catch_store_sanitize_post',
				'active_callback'   => 'catch_store_is_page_slider_active',
				'label'             => esc_html__( 'Page', 'catch-store-pro' ) . ' # ' . $i,
				'section'           => 'catch_store_featured_slider',
				'type'              => 'dropdown-pages',
			)
		);

		if ( catch_store_is_woocommerce_activated() ) {
			// Product Sliders
			catch_store_register_option( $wp_customize, array(
					'name'              => 'catch_store_slider_product_' . $i,
					'sanitize_callback' => 'catch_store_sanitize_post',
					'active_callback'   => 'catch_store_is_product_slider_active',
					'label'             => esc_html__( 'Product', 'catch-store-pro' ) . ' # ' . $i,
					'section'           => 'catch_store_featured_slider',
					'choices'           => catch_store_generate_products_array(),
					'type'              => 'select',
				)
			);
		}

		// Image Sliders
		catch_store_register_option( $wp_customize, array(
				'name'              =>'catch_store_slider_note_' . $i,
				'sanitize_callback' => 'sanitize_text_field',
				'custom_control'    => 'catch_store_Note_Control',
				'active_callback'   => 'catch_store_is_image_slider_active',
				'label'             => esc_html__( 'Slide #', 'catch-store-pro' ) . $i,
				'section'           => 'catch_store_featured_slider',
				'type'              => 'description',
			)
		);

		catch_store_register_option( $wp_customize, array(
				'name'              =>'catch_store_slider_image_' . $i,
				'sanitize_callback' => 'catch_store_sanitize_image',
				'custom_control'    => 'WP_Customize_Image_Control',
				'active_callback'   => 'catch_store_is_image_slider_active',
				'label'             => esc_html__( 'Image', 'catch-store-pro' ),
				'section'           => 'catch_store_featured_slider',
			)
		);

		catch_store_register_option( $wp_customize, array(
				'name'              =>'catch_store_featured_link_' . $i,
				'sanitize_callback' => 'esc_url_raw',
				'active_callback'   => 'catch_store_is_image_slider_active',
				'label'             => esc_html__( 'Link', 'catch-store-pro' ),
				'section'           => 'catch_store_featured_slider',
			)
		);

		catch_store_register_option( $wp_customize, array(
				'name'              =>'catch_store_featured_target_' . $i,
				'sanitize_callback' => 'catch_store_sanitize_checkbox',
				'active_callback'   => 'catch_store_is_image_slider_active',
				'label'             => esc_html__( 'Check to Open Link in New Window/Tab', 'catch-store-pro' ),
				'section'           => 'catch_store_featured_slider',
				'type'              => 'checkbox',
			)
		);

		catch_store_register_option( $wp_customize, array(
				'name'              =>'catch_store_featured_title_' . $i,
				'sanitize_callback' => 'wp_kses_post',
				'active_callback'   => 'catch_store_is_image_slider_active',
				'label'             => esc_html__( 'Title', 'catch-store-pro' ),
				'section'           => 'catch_store_featured_slider',
				'type'              => 'text',
			)
		);

		catch_store_register_option( $wp_customize, array(
				'name'              =>'catch_store_featured_content_' . $i,
				'sanitize_callback' => 'wp_kses_post',
				'active_callback'   => 'catch_store_is_image_slider_active',
				'label'             => esc_html__( 'Content', 'catch-store-pro' ),
				'section'           => 'catch_store_featured_slider',
				'type'              => 'textarea',
			)
		);
	} // End for().
}
add_action( 'customize_register', 'catch_store_slider_options' );


/**
 * Returns an array of feature slider transition effects
 *
 * @since Catch Store Pro 1.0
 */
function catch_store_slider_transition_effects() {
	$options = array(
		'fade'       => esc_html__( 'Fade', 'catch-store-pro' ),
		'fadeout'    => esc_html__( 'Fade Out', 'catch-store-pro' ),
		'none'       => esc_html__( 'None', 'catch-store-pro' ),
		'scrollHorz' => esc_html__( 'Scroll Horizontal', 'catch-store-pro' ),
		'scrollVert' => esc_html__( 'Scroll Vertical', 'catch-store-pro' ),
		'flipHorz'   => esc_html__( 'Flip Horizontal', 'catch-store-pro' ),
		'flipVert'   => esc_html__( 'Flip Vertical', 'catch-store-pro' ),
		'tileSlide'  => esc_html__( 'Tile Slide', 'catch-store-pro' ),
		'tileBlind'  => esc_html__( 'Tile Blind', 'catch-store-pro' ),
		'shuffle'    => esc_html__( 'Shuffle', 'catch-store-pro' ),
	);

	return apply_filters( 'catch_store_slider_transition_effects', $options );
}


/**
 * Returns an array of featured slider image loader options
 *
 * @since Catch Store Pro 1.0
 */
function catch_store_slider_image_loader() {
	$options = array(
		'true'  => esc_html__( 'True', 'catch-store-pro' ),
		'wait'  => esc_html__( 'Wait', 'catch-store-pro' ),
		'false' => esc_html__( 'False', 'catch-store-pro' ),
	);

	return apply_filters( 'catch_store_slider_image_loader', $options );
}


/**
 * Returns an array of featured content show registered
 *
 * @since Catch Store Pro 1.0
 */
function catch_store_content_show() {
	$options = array(
		'excerpt'      => esc_html__( 'Show Excerpt', 'catch-store-pro' ),
		'full-content' => esc_html__( 'Full Content', 'catch-store-pro' ),
		'hide-content' => esc_html__( 'Hide Content', 'catch-store-pro' ),
	);
	return apply_filters( 'catch_store_content_show', $options );
}


/**
 * Returns an array of featured content show registered
 *
 * @since Catch Store Pro 1.0
 */
function catch_store_meta_show() {
	$options = array(
		'show-meta'      => esc_html__( 'Show Meta', 'catch-store-pro' ),
		'hide-meta' => esc_html__( 'Hide Meta', 'catch-store-pro' ),
	);
	return apply_filters( 'catch_store_meta_show', $options );
}

/** Active Callback Functions */

if( ! function_exists( 'catch_store_is_slider_active' ) ) :
	/**
	* Return true if slider is active
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_slider_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'catch_store_slider_option' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected
		return ( 'entire-site' == $enable || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'homepage' == $enable )
			);
	}
endif;


if( ! function_exists( 'catch_store_is_post_slider_active' ) ) :
	/**
	* Return true if page slider is active
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_post_slider_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_slider_type' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is or is not selected type
		return ( catch_store_is_slider_active( $control ) && ( 'post' == $type )
			);
	}
endif;


if( ! function_exists( 'catch_store_is_page_slider_active' ) ) :
	/**
	* Return true if page slider is active
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_page_slider_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_slider_type' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is or is not selected type
		return ( catch_store_is_slider_active( $control ) && ( 'page' == $type )
			);
	}
endif;


if( ! function_exists( 'catch_store_is_category_slider_active' ) ) :
	/**
	* Return true if page slider is active
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_category_slider_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_slider_type' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is or is not selected type
		return ( catch_store_is_slider_active( $control ) && ( 'category' == $type )
			);
	}
endif;


if( ! function_exists( 'catch_store_is_image_slider_active' ) ) :
	/**
	* Return true if page slider is active
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_image_slider_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_slider_type' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is or is not selected type
		return ( catch_store_is_slider_active( $control ) && ( 'image' == $type )
			);
	}
endif;

if( ! function_exists( 'catch_store_is_product_slider_active' ) ) :
	/**
	* Return true if product slider is active
	*
	* @since Catch_Store 1.0
	*/
	function catch_store_is_product_slider_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_slider_type' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is or is not selected type
		return ( catch_store_is_slider_active( $control ) && ( 'product' === $type ) );
	}
endif;


if( ! function_exists( 'catch_store_is_post_category_slider_active' ) ) :
	/**
	* Return true if post/category content is active
	*
	* @since Catch_Store 1.0
	*/
	function catch_store_is_post_category_slider_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_slider_type' )->value();

		return ( catch_store_is_slider_active( $control ) && ( 'category' === $type || 'post' === $type ) );
	}
endif;