<?php
/**
 * Hero Content Options
 *
 * @package Catch_Store
 */

/**
 * Add hero content options to theme options
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function catch_store_hero_content_options( $wp_customize ) {
	$wp_customize->add_section( 'catch_store_hero_content_options', array(
			'title' => esc_html__( 'Hero Content Options', 'catch-store-pro' ),
			'panel' => 'catch_store_theme_options',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_hero_content_visibility',
			'default'           => 'disabled',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'choices'           => catch_store_section_visibility_options(),
			'label'             => esc_html__( 'Enable on', 'catch-store-pro' ),
			'section'           => 'catch_store_hero_content_options',
			'type'              => 'select',
		)
	);

	$types = catch_store_section_type_options();

	// Unset demo as hero content has no demo.
	unset( $types['demo'] );

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_hero_content_type',
			'default'           => 'page',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'active_callback' => 'catch_store_is_hero_content_active',
			'choices'         => $types,
			'label'           => esc_html__( 'Type', 'catch-store-pro' ),
			'section'         => 'catch_store_hero_content_options',
			'type'            => 'select',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_hero_content',
			'default'           => '0',
			'sanitize_callback' => 'catch_store_sanitize_post',
			'active_callback'   => 'catch_store_is_hero_page_content_active',
			'label'             => esc_html__( 'Page', 'catch-store-pro' ),
			'section'           => 'catch_store_hero_content_options',
			'type'              => 'dropdown-pages',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_hero_content_post',
			'default'           => 0,
			'sanitize_callback' => 'catch_store_sanitize_post',
			'active_callback'   => 'catch_store_is_hero_post_content_active',
			'label'             => esc_html__( 'Post', 'catch-store-pro' ),
			'section'           => 'catch_store_hero_content_options',
			'choices'           => catch_store_generate_post_array(),
			'type'              => 'select',
		)
	);

	// Create an empty array.
	$cats = array();

	$cats['0'] = esc_html__( '-- Select --', 'catch-store-pro' );

	// We loop over the categories and set the names and labels we need.
	foreach ( get_categories() as $categories => $category ) {
		$cats[ $category->term_id ] = $category->name;
	}

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_hero_content_category',
			'default'           => '0',
			'sanitize_callback' => 'absint',
			'active_callback'   => 'catch_store_is_hero_category_content_active',
			'label'             => esc_html__( 'Category', 'catch-store-pro' ),
			'type'              => 'select',
			'choices'           => $cats,
			'section'           => 'catch_store_hero_content_options',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_hero_content_product',
			'default'           => '0',
			'sanitize_callback' => 'catch_store_sanitize_post',
			'active_callback'   => 'catch_store_is_hero_product_content_active',
			'label'             => esc_html__( 'Product', 'catch-store-pro' ),
			'section'           => 'catch_store_hero_content_options',
			'choices'           => catch_store_generate_products_array(),
			'type'              => 'select',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_disable_hero_content_title',
			'sanitize_callback' => 'catch_store_sanitize_checkbox',
			'active_callback'   => 'catch_store_is_hero_post_page_category_content_active',
			'label'             => esc_html__( 'Check to disable title', 'catch-store-pro' ),
			'section'           => 'catch_store_hero_content_options',
			'type'              => 'checkbox',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_hero_content_show',
			'default'           => 'full-content',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'active_callback'   => 'catch_store_is_hero_post_page_category_content_active',
			'choices'           => catch_store_content_show(),
			'label'             => esc_html__( 'Display Content', 'catch-store-pro' ),
			'section'           => 'catch_store_hero_content_options',
			'type'              => 'select',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_hero_content_image_alignment',
			'default'           => 'content-align-right',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'active_callback'   => 'catch_store_is_hero_content_active',
			'choices'           => array(
				'content-align-right' => esc_html__( 'Right', 'catch-store-pro' ),
				'content-align-left'  => esc_html__( 'Left', 'catch-store-pro' ),
			),
			'label'             => esc_html__( 'Content Alignment', 'catch-store-pro' ),
			'section'           => 'catch_store_hero_content_options',
			'type'              => 'radio',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_hero_content_title',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'catch_store_is_hero_custom_content_active',
			'label'             => esc_html__( 'Title', 'catch-store-pro' ),
			'section'           => 'catch_store_hero_content_options',
			'type'              => 'text',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_hero_content_content',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'catch_store_is_hero_custom_content_active',
			'label'             => esc_html__( 'Content', 'catch-store-pro' ),
			'section'           => 'catch_store_hero_content_options',
			'type'              => 'textarea',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_hero_content_image',
			'sanitize_callback' => 'catch_store_sanitize_image',
			'custom_control'    => 'WP_Customize_Image_Control',
			'active_callback'   => 'catch_store_is_hero_custom_content_active',
			'label'             => esc_html__( 'Image', 'catch-store-pro' ),
			'section'           => 'catch_store_hero_content_options',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_hero_content_link',
			'sanitize_callback' => 'esc_url_raw',
			'active_callback'   => 'catch_store_is_hero_custom_content_active',
			'label'             => esc_html__( 'Image Link', 'catch-store-pro' ),
			'section'           => 'catch_store_hero_content_options',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_hero_content_target',
			'sanitize_callback' => 'catch_store_sanitize_checkbox',
			'active_callback'   => 'catch_store_is_hero_custom_content_active',
			'label'             => esc_html__( 'Check to Open Link in New Window/Tab', 'catch-store-pro' ),
			'section'           => 'catch_store_hero_content_options',
			'type'              => 'checkbox',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_hero_content_more_text',
			'sanitize_callback' => 'sanitize_text_field',
			'active_callback'   => 'catch_store_is_hero_custom_content_active',
			'label'             => esc_html__( 'Button Text', 'catch-store-pro' ),
			'section'           => 'catch_store_hero_content_options',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_hero_content_more_link',
			'sanitize_callback' => 'esc_url_raw',
			'active_callback'   => 'catch_store_is_hero_custom_content_active',
			'label'             => esc_html__( 'Button Link', 'catch-store-pro' ),
			'section'           => 'catch_store_hero_content_options',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_hero_content_more_target',
			'sanitize_callback' => 'catch_store_sanitize_checkbox',
			'active_callback'   => 'catch_store_is_hero_custom_content_active',
			'label'             => esc_html__( 'Check to Open Button Link in New Window/Tab', 'catch-store-pro' ),
			'section'           => 'catch_store_hero_content_options',
			'type'              => 'checkbox',
		)
	);
}
add_action( 'customize_register', 'catch_store_hero_content_options' );

/** Active Callback Functions **/
if ( ! function_exists( 'catch_store_is_hero_content_active' ) ) :
	/**
	* Return true if hero content is active
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_hero_content_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option( 'page_for_posts' );

		$enable = $control->manager->get_setting( 'catch_store_hero_content_visibility' )->value();

		//return true only if previwed page on customizer matches the type of content option selected
		return ( 'entire-site' == $enable  || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) &&	 'homepage' == $enable )
			);
	}
endif;


if ( ! function_exists( 'catch_store_is_demo_hero_content_inactive' ) ) :
	/**
	* Return true if demo hero content is inactive
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_demo_hero_content_inactive( $control ) {
		$type = $control->manager->get_setting( 'catch_store_hero_content_type' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( catch_store_is_hero_content_active( $control ) && !( 'demo' == $type )
			);
	}
endif;


if ( ! function_exists( 'catch_store_is_hero_post_content_active' ) ) :
	/**
	* Return true if post content is active
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_hero_post_content_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_hero_content_type' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( catch_store_is_hero_content_active( $control ) && 'post' == $type );
	}
endif;


if ( ! function_exists( 'catch_store_is_hero_page_content_active' ) ) :
	/**
	* Return true if hero page content is active
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_hero_page_content_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_hero_content_type' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( catch_store_is_hero_content_active( $control ) && 'page' == $type );
	}
endif;


if ( ! function_exists( 'catch_store_is_hero_category_content_active' ) ) :
	/**
	* Return true if hero category content is active
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_hero_category_content_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_hero_content_type' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( catch_store_is_hero_content_active( $control ) && 'category' == $type );
	}
endif;

if ( ! function_exists( 'catch_store_is_hero_post_page_category_content_active' ) ) :
	/**
	* Return true if hero post/page/category content is active
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_hero_post_page_category_content_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_hero_content_type' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( catch_store_is_hero_content_active( $control ) && ( 'page' == $type || 'post' == $type || 'category' == $type )
			);
	}
endif;


if ( ! function_exists( 'catch_store_is_hero_custom_content_active' ) ) :
	/**
	* Return true if hero custom content is active
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_hero_custom_content_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_hero_content_type' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( catch_store_is_hero_content_active( $control ) && ( 'image' == $type )
			);
	}
endif;

if( ! function_exists( 'catch_store_is_hero_product_content_active' ) ) :
	/**
	* Return true if hero product content is active
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_hero_product_content_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_hero_content_type' )->value();

		return ( catch_store_is_hero_content_active( $control ) && ( 'product' === $type ) );
	}
endif;