<?php
/**
 * Add Portfolio Settings in Customizer
 *
 * @package Catch_Store
 */

/**
 * Add portfolio options to theme options
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function catch_store_portfolio_options( $wp_customize ) {
    // Add note to Jetpack Portfolio Section
    catch_store_register_option( $wp_customize, array(
            'name'              => 'catch_store_jetpack_portfolio_cpt_note',
            'sanitize_callback' => 'sanitize_text_field',
            'custom_control'    => 'catch_store_Note_Control',
            'label'             => sprintf( esc_html__( 'For Portfolio Options for Catch Store Theme, go %1$shere%2$s', 'catch-store-pro' ),
                 '<a href="javascript:wp.customize.section( \'catch_store_portfolio\' ).focus();">',
                 '</a>'
            ),
            'section'           => 'jetpack_portfolio',
            'type'              => 'description',
            'priority'          => 1,
        )
    );

	$wp_customize->add_section( 'catch_store_portfolio', array(
            'panel'    => 'catch_store_theme_options',
            'title'    => esc_html__( 'Portfolio', 'catch-store-pro' ),
        )
    );

    catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_portfolio_option',
			'default'           => 'disabled',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'choices'           => catch_store_section_visibility_options(),
			'label'             => esc_html__( 'Enable on', 'catch-store-pro' ),
			'section'           => 'catch_store_portfolio',
			'type'              => 'select',
		)
	);

    catch_store_register_option( $wp_customize, array(
            'name'              => 'catch_store_portfolio_style',
            'default'           => 'special',
            'sanitize_callback' => 'catch_store_sanitize_select',
            'active_callback'   => 'catch_store_is_portfolio_active',
            'choices'           => array(
                'special' => esc_html__( 'Special layout', 'catch-store-pro' ),
                'classic' => esc_html__( 'Classic layout ( Select Columns )', 'catch-store-pro' ),
            ),
            'label'             => esc_html__( 'Select Layout', 'catch-store-pro' ),
            'section'           => 'catch_store_portfolio',
            'type'              => 'select',
        )
    );

    catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_portfolio_content_layout',
			'default'           => 'layout-three',
			'sanitize_callback' => 'catch_store_sanitize_select',
            'active_callback'   => 'catch_store_is_portfolio_style_two_active',
			'choices'           => catch_store_sections_layout_options(),
			'label'             => esc_html__( 'Select Portfolio Layout', 'catch-store-pro' ),
			'section'           => 'catch_store_portfolio',
			'type'              => 'select',
		)
	);

    $type = catch_store_section_type_options();

    $type['jetpack-portfolio'] = esc_html__( 'Custom Post Type', 'catch-store-pro' );

    catch_store_register_option( $wp_customize, array(
            'name'              => 'catch_store_portfolio_type',
            'default'           => 'demo',
            'sanitize_callback' => 'catch_store_sanitize_select',
            'active_callback'   => 'catch_store_is_portfolio_active',
            'choices'           => $type,
            'description'       => sprintf( esc_html__( 'For Custom Post Type Content, install %1$sEssential Content Types%2$s Plugin with Portfolio Content Type Enabled', 'catch-store-pro' ),
                '<a target="_blank" href="https://wordpress.org/plugins/essential-content-types/">',
                '</a>'
            ),
            'label'             => esc_html__( 'Select Type', 'catch-store-pro' ),
            'section'           => 'catch_store_portfolio',
            'type'              => 'select',
        )
    );

    catch_store_register_option( $wp_customize, array(
            'name'              => 'catch_store_portfolio_cpt_note',
            'sanitize_callback' => 'sanitize_text_field',
            'custom_control'    => 'catch_store_Note_Control',
            'active_callback'   => 'catch_store_is_jetpack_portfolio_active',
            /* translators: 1: <a>/link tag start, 2: </a>/link tag close. */
			'label'             => sprintf( esc_html__( 'For CPT heading and sub-heading, go %1$shere%2$s', 'catch-store-pro' ),
                 '<a href="javascript:wp.customize.control( \'jetpack_portfolio_title\' ).focus();">',
                 '</a>'
            ),
            'section'           => 'catch_store_portfolio',
            'type'              => 'description',
        )
    );

    catch_store_register_option( $wp_customize, array(
            'name'              => 'catch_store_portfolio_headline',
            'default'           => esc_html__( 'Portfolio', 'catch-store-pro' ),
            'sanitize_callback' => 'wp_kses_post',
            'label'             => esc_html__( 'Headline', 'catch-store-pro' ),
            'active_callback'   => 'catch_store_is_demo_cpt_portfolio_inactive',
            'section'           => 'catch_store_portfolio',
            'type'              => 'text',
        )
    );

    catch_store_register_option( $wp_customize, array(
            'name'              => 'catch_store_portfolio_subheadline',
            'sanitize_callback' => 'wp_kses_post',
            'label'             => esc_html__( 'Sub headline', 'catch-store-pro' ),
            'active_callback'   => 'catch_store_is_demo_cpt_portfolio_inactive',
            'section'           => 'catch_store_portfolio',
            'type'              => 'text',
        )
    );

    catch_store_register_option( $wp_customize, array(
            'name'              => 'catch_store_portfolio_number',
            'default'           => '3',
            'sanitize_callback' => 'catch_store_sanitize_number_range',
            'active_callback'   => 'catch_store_is_demo_portfolio_inactive',
            'label'             => esc_html__( 'Number of items to show', 'catch-store-pro' ),
            'section'           => 'catch_store_portfolio',
            'type'              => 'number',
            'input_attrs'       => array(
                'style'             => 'width: 100px;',
                'min'               => 0,
            ),
        )
    );

    $type = catch_store_content_show();

    unset( $type['full-content'] );

    catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_portfolio_content_show',
			'default'           => 'hide-content',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'active_callback'   => 'catch_store_is_post_page_category_cpt_portfolio_active',
			'choices'           => $type,
			'label'             => esc_html__( 'Display Content', 'catch-store-pro' ),
			'section'           => 'catch_store_portfolio',
			'type'              => 'select',
		)
	);

    catch_store_register_option( $wp_customize, array(
            'name'              => 'catch_store_portfolio_select_category',
            'sanitize_callback' => 'catch_store_sanitize_category_list',
            'active_callback'   => 'catch_store_is_category_portfolio_active',
            'custom_control'    => 'catch_store_Multi_Categories_Control',
            'label'             => esc_html__( 'Select Categories', 'catch-store-pro' ),
            'name'              => 'catch_store_portfolio_select_category',
            'section'           => 'catch_store_portfolio',
            'type'              => 'dropdown-categories',
        )
    );

    $number = get_theme_mod( 'catch_store_portfolio_number', 3 );

    for ( $i = 1; $i <= $number ; $i++ ) {
        //for featured post content
        catch_store_register_option( $wp_customize, array(
                'name'              => 'catch_store_portfolio_post_' . $i,
                'sanitize_callback' => 'catch_store_sanitize_post',
                'active_callback'   => 'catch_store_is_post_portfolio_active',
                'input_attrs'       => array(
                'style'             => 'width: 100px;'
                ),
                'label'             => esc_html__( 'Post', 'catch-store-pro' ) . ' ' . $i ,
                'section'           => 'catch_store_portfolio',
                'choices'           => catch_store_generate_post_array(),
                'type'              => 'select',
            )
        );

        //for CPT
        catch_store_register_option( $wp_customize, array(
                'name'              => 'catch_store_portfolio_cpt_' . $i,
                'sanitize_callback' => 'catch_store_sanitize_post',
                'active_callback'   => 'catch_store_is_jetpack_portfolio_active',
                'label'             => esc_html__( 'Portfolio', 'catch-store-pro' ) . ' ' . $i ,
                'section'           => 'catch_store_portfolio',
                'type'              => 'select',
                'choices'           => catch_store_generate_post_array( 'jetpack-portfolio' ),
            )
        );

        catch_store_register_option( $wp_customize, array(
                'name'              => 'catch_store_portfolio_page_' . $i,
                'sanitize_callback' => 'catch_store_sanitize_post',
                'active_callback'   => 'catch_store_is_page_portfolio_active',
                'label'             => esc_html__( 'Page', 'catch-store-pro' ) . ' ' . $i ,
                'section'           => 'catch_store_portfolio',
                'type'              => 'dropdown-pages',
            )
        );

        if ( catch_store_is_woocommerce_activated() ) {
            catch_store_register_option( $wp_customize, array(
                    'name'              => 'catch_store_portfolio_product_' . $i,
                    'sanitize_callback' => 'catch_store_sanitize_post',
                    'active_callback'   => 'catch_store_is_product_portfolio_content_active',
                    'label'             => esc_html__( 'Product', 'catch-store-pro' ) . ' ' . $i ,
                    'section'           => 'catch_store_portfolio',
                    'type'              => 'select',
                    'choices'           => catch_store_generate_products_array(),
                )
            );
        }

        catch_store_register_option( $wp_customize, array(
                'name'              => 'catch_store_portfolio_note_' . $i,
                'sanitize_callback' => 'sanitize_text_field',
                'custom_control'    => 'catch_store_Note_Control',
                'active_callback'   => 'catch_store_is_image_portfolio_active',
                'label'             => esc_html__( 'Portfolio #', 'catch-store-pro' ) .  $i,
                'section'           => 'catch_store_portfolio',
                'type'              => 'description',
            )
        );

        catch_store_register_option( $wp_customize, array(
                'name'              => 'catch_store_portfolio_image_' . $i,
                'custom_control'      => 'WP_Customize_Image_Control',
                'sanitize_callback' => 'catch_store_sanitize_image',
                'active_callback'   => 'catch_store_is_image_portfolio_active',
                'label'             => esc_html__( 'Image', 'catch-store-pro' ),
                'section'           => 'catch_store_portfolio',
            )
        );

        catch_store_register_option( $wp_customize, array(
                'name'              => 'catch_store_portfolio_link_' . $i,
                'sanitize_callback' => 'esc_url_raw',
                'active_callback'   => 'catch_store_is_image_portfolio_active',
                'label'             => esc_html__( 'Link', 'catch-store-pro' ),
                'section'           => 'catch_store_portfolio',
            )
        );

        catch_store_register_option( $wp_customize, array(
                'name'              => 'catch_store_portfolio_target_' . $i,
                'sanitize_callback' => 'catch_store_sanitize_checkbox',
                'active_callback'   => 'catch_store_is_image_portfolio_active',
                'label'             => esc_html__( 'Check to Open Link in New Window/Tab', 'catch-store-pro' ),
                'section'           => 'catch_store_portfolio',
                'type'              => 'checkbox',
            )
        );

        catch_store_register_option( $wp_customize, array(
                'name'              => 'catch_store_portfolio_content_' . $i,
                'sanitize_callback' => 'sanitize_text_field',
                'active_callback'   => 'catch_store_is_image_portfolio_active',
                'label'             => esc_html__( 'Portfolio Text', 'catch-store-pro' ),
                'section'           => 'catch_store_portfolio',
                'type'              => 'textarea',
            )
        );

        catch_store_register_option( $wp_customize, array(
                'name'              => 'catch_store_portfolio_title_' . $i,
                'sanitize_callback' => 'sanitize_text_field',
                'active_callback'   => 'catch_store_is_image_portfolio_active',
                'label'             => esc_html__( 'Name', 'catch-store-pro' ),
                'section'           => 'catch_store_portfolio',
                'type'              => 'text',
            )
        );
    } // End for().

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_portfolio_meta_show',
			'default'           => 'show-meta',
			'active_callback'   => 'catch_store_is_post_page_category_cpt_portfolio_active',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'choices'           => catch_store_meta_show(),
			'label'             => esc_html__( 'Display Meta', 'catch-store-pro' ),
			'section'           => 'catch_store_portfolio',
			'type'              => 'select',
		)
	);
}
add_action( 'customize_register', 'catch_store_portfolio_options' );

/**
 * Active Callback Functions
 */
if ( ! function_exists( 'catch_store_is_portfolio_active' ) ) :
    /**
    * Return true if portfolio is active
    *
    * @since Catch Store Pro 1.0
    */
    function catch_store_is_portfolio_active( $control ) {
        $enable = $control->manager->get_setting( 'catch_store_portfolio_option' )->value();

        //return true only if previwed page on customizer matches the type of content option selected
        return ( catch_store_check_section( $enable ) );
    }
endif;


if ( ! function_exists( 'catch_store_is_demo_portfolio_inactive' ) ) :
    /**
    * Return true if demo portfolio is inactive
    *
    * @since Catch Store Pro 1.0
    */
    function catch_store_is_demo_portfolio_inactive( $control ) {
        $type = $control->manager->get_setting( 'catch_store_portfolio_type' )->value();

        //return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
        return ( catch_store_is_portfolio_active( $control ) && !( 'demo' === $type ) );
    }
endif;


if ( ! function_exists( 'catch_store_is_post_portfolio_active' ) ) :
    /**
    * Return true if page content is active
    *
    * @since Catch Store Pro 1.0
    */
    function catch_store_is_post_portfolio_active( $control ) {
        $type = $control->manager->get_setting( 'catch_store_portfolio_type' )->value();

        //return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
        return ( catch_store_is_portfolio_active( $control ) && 'post' === $type );
    }
endif;


if ( ! function_exists( 'catch_store_is_jetpack_portfolio_active' ) ) :
    /**
    * Return true if jetpack portfolio is active
    *
    * @since Catch Store Pro 1.0
    */
    function catch_store_is_jetpack_portfolio_active( $control ) {
        $type = $control->manager->get_setting( 'catch_store_portfolio_type' )->value();

        //return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
        return ( catch_store_is_portfolio_active( $control ) && 'jetpack-portfolio' === $type );
    }
endif;


if ( ! function_exists( 'catch_store_is_page_portfolio_active' ) ) :
    /**
    * Return true if page content is active
    *
    * @since Catch Store Pro 1.0
    */
    function catch_store_is_page_portfolio_active( $control ) {
        $type = $control->manager->get_setting( 'catch_store_portfolio_type' )->value();

        //return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
        return ( catch_store_is_portfolio_active( $control ) && 'page' === $type );
    }
endif;


if ( ! function_exists( 'catch_store_is_category_portfolio_active' ) ) :
    /**
    * Return true if page content is active
    *
    * @since Catch Store Pro 1.0
    */
    function catch_store_is_category_portfolio_active( $control ) {
        $type = $control->manager->get_setting( 'catch_store_portfolio_type' )->value();

        //return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
        return ( catch_store_is_portfolio_active( $control ) && 'category' === $type );
    }
endif;

if ( ! function_exists( 'catch_store_is_post_page_category_cpt_portfolio_active' ) ) :
    /**
    * Return true if demo and image page is not active
    *
    * @since Catch Store Pro 1.0
    */
    function catch_store_is_post_page_category_cpt_portfolio_active( $control ) {
        $type = $control->manager->get_setting( 'catch_store_portfolio_type' )->value();

        //return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
        return ( catch_store_is_portfolio_active( $control ) && ( 'demo' !== $type && 'image' !== $type  ) );
    }
endif;

if ( ! function_exists( 'catch_store_is_demo_cpt_portfolio_inactive' ) ) :
    /**
    * Return true if demo and image page is not active
    *
    * @since Catch Store Pro 1.0
    */
    function catch_store_is_demo_cpt_portfolio_inactive( $control ) {
        $type = $control->manager->get_setting( 'catch_store_portfolio_type' )->value();

        //return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
        return ( catch_store_is_portfolio_active( $control ) && ( 'demo' !== $type && 'jetpack-portfolio' !== $type  ) );
    }
endif;

if ( ! function_exists( 'catch_store_is_image_portfolio_active' ) ) :
    /**
    * Return true if page content is active
    *
    * @since Catch Store Pro 1.0
    */
    function catch_store_is_image_portfolio_active( $control ) {
        $type = $control->manager->get_setting( 'catch_store_portfolio_type' )->value();

        //return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
        return ( catch_store_is_portfolio_active( $control ) && 'image' === $type );
    }
endif;

if( ! function_exists( 'catch_store_is_product_portfolio_content_active' ) ) :
    /**
    * Return true if product content is active
    *
    * @since Catch Store Pro 1.0
    */
    function catch_store_is_product_portfolio_content_active( $control ) {
        $type = $control->manager->get_setting( 'catch_store_portfolio_type' )->value();

        return ( catch_store_is_portfolio_active( $control ) && ( 'product' === $type ) );
    }
endif;

if ( ! function_exists( 'catch_store_is_portfolio_style_two_active' ) ) :
    /**
    * Return true if services content is active
    *
    * @since Catch Foodmania Pro 1.0
    */
    function catch_store_is_portfolio_style_two_active( $control ) {
        $enable = $control->manager->get_setting( 'catch_store_portfolio_style' )->value();

        //return true only if previewed page on customizer matches the type of content option selected
        return ( catch_store_is_portfolio_active( $control ) && 'classic' ===  $enable );
    }
endif;