<?php
/**
 * Promotion Headline Options
 *
 * @package Catch_Store
 */

/**
 * Add promotion headline options to theme options
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function catch_store_promotion_headline_options( $wp_customize ) {
	$wp_customize->add_section( 'catch_store_promotion_headline', array(
			'title' => esc_html__( 'Promotion Headline', 'catch-store-pro' ),
			'panel' => 'catch_store_theme_options',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_promotion_headline_visibility',
			'default'           => 'disabled',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'choices'           => catch_store_section_visibility_options(),
			'label'             => esc_html__( 'Enable on', 'catch-store-pro' ),
			'section'           => 'catch_store_promotion_headline',
			'type'              => 'select',
		)
	);

	$types = catch_store_section_type_options();

	// Unset demo as promotion headline has no demo.
	unset( $types['demo'] );

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_promotion_headline_type',
			'default'           => 'page',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'active_callback' => 'catch_store_is_promotion_headline_active',
			'choices'         => $types,
			'label'           => esc_html__( 'Type', 'catch-store-pro' ),
			'section'         => 'catch_store_promotion_headline',
			'type'            => 'select',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_promotion_headline_subheadline',
			'default'           => esc_html( 'Save 30%', 'catch-store-pro' ),
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'catch_store_is_demo_promotion_headline_inactive',
			'label'             => esc_html__( 'Sub-headline', 'catch-store-pro' ),
			'section'           => 'catch_store_promotion_headline',
			'type'              => 'textarea',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_promotion_headline_image_position',
			'default'           => 'content-align-center',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'active_callback'   => 'catch_store_is_promotion_headline_active',
			'choices'           => array(
				'content-align-right'  => esc_html__( 'Right Align', 'catch-store-pro' ),
				'content-align-left'   => esc_html__( 'Left Align', 'catch-store-pro' ),
				'content-align-center' => esc_html__( 'Center Align', 'catch-store-pro' ),
			),
			'label'             => esc_html__( 'Content Position', 'catch-store-pro' ),
			'section'           => 'catch_store_promotion_headline',
			'type'              => 'select',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_promotion_headline_wrap_text',
			'default'           => 1,
			'sanitize_callback' => 'catch_store_sanitize_checkbox',
			'active_callback'   => 'catch_store_is_promotion_headline_active',
			'label'             => esc_html__( 'Check to enable box design', 'catch-store-pro' ),
			'description'       => esc_html__( 'Wrap Text With Frame', 'catch-store-pro' ),
			'section'           => 'catch_store_promotion_headline',
			'type'              => 'checkbox',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_promotion_headline_text_color',
			'default'           => 1,
			'sanitize_callback' => 'catch_store_sanitize_checkbox',
			'active_callback'   => 'catch_store_is_promotion_headline_active',
			'label'             => esc_html__( 'Check to change text to white color', 'catch-store-pro' ),
			'section'           => 'catch_store_promotion_headline',
			'type'              => 'checkbox',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_promotion_headline',
			'default'           => '0',
			'sanitize_callback' => 'catch_store_sanitize_post',
			'active_callback'   => 'catch_store_is_promotion_headline_page_content_active',
			'label'             => esc_html__( 'Page', 'catch-store-pro' ),
			'section'           => 'catch_store_promotion_headline',
			'type'              => 'dropdown-pages',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_promotion_headline_post',
			'default'           => 0,
			'sanitize_callback' => 'catch_store_sanitize_post',
			'active_callback'   => 'catch_store_is_promotion_headline_post_content_active',
			'label'             => esc_html__( 'Post', 'catch-store-pro' ),
			'section'           => 'catch_store_promotion_headline',
			'choices'           => catch_store_generate_post_array(),
			'type'              => 'select',
		)
	);

	// create an empty array.
	$cats = array();

	$cats['0'] = esc_html__( '-- Select --', 'catch-store-pro' );

	// we loop over the categories and set the names and
	// labels we need.
	foreach ( get_categories() as $categories => $category ) {
		$cats[ $category->term_id ] = $category->name;
	}

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_promotion_headline_category',
			'default'           => '0',
			'sanitize_callback' => 'absint',
			'active_callback'   => 'catch_store_is_promotion_headline_category_content_active',
			'label'             => esc_html__( 'Category', 'catch-store-pro' ),
			'type'              => 'select',
			'choices'           => $cats,
			'section'           => 'catch_store_promotion_headline',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_promotion_headline_product',
			'default'           => '0',
			'sanitize_callback' => 'catch_store_sanitize_post',
			'active_callback'   => 'catch_store_is_promotion_headline_product_content_active',
			'label'             => esc_html__( 'Product', 'catch-store-pro' ),
			'section'           => 'catch_store_promotion_headline',
			'choices'           => catch_store_generate_products_array(),
			'type'              => 'select',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_disable_promotion_headline_title',
			'sanitize_callback' => 'catch_store_sanitize_checkbox',
			'active_callback'   => 'catch_store_is_promotion_headline_post_page_category_product_content_active',
			'label'             => esc_html__( 'Check to disable title', 'catch-store-pro' ),
			'section'           => 'catch_store_promotion_headline',
			'type'              => 'checkbox',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_promotion_headline_show',
			'default'           => 'full-content',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'active_callback'   => 'catch_store_is_promotion_headline_post_page_category_product_content_active',
			'choices'           => catch_store_content_show(),
			'label'             => esc_html__( 'Display Content', 'catch-store-pro' ),
			'section'           => 'catch_store_promotion_headline',
			'type'              => 'select',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_promotion_headline_title',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'catch_store_is_promotion_headline_custom_content_active',
			'label'             => esc_html__( 'Title', 'catch-store-pro' ),
			'section'           => 'catch_store_promotion_headline',
			'type'              => 'text',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_promotion_headline_content',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'catch_store_is_promotion_headline_custom_content_active',
			'label'             => esc_html__( 'Content', 'catch-store-pro' ),
			'section'           => 'catch_store_promotion_headline',
			'type'              => 'textarea',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_promotion_headline_image',
			'sanitize_callback' => 'catch_store_sanitize_image',
			'custom_control'    => 'WP_Customize_Image_Control',
			'active_callback'   => 'catch_store_is_promotion_headline_custom_content_active',
			'label'             => esc_html__( 'Image', 'catch-store-pro' ),
			'section'           => 'catch_store_promotion_headline',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_promotion_headline_link',
			'sanitize_callback' => 'esc_url_raw',
			'active_callback'   => 'catch_store_is_promotion_headline_custom_content_active',
			'label'             => esc_html__( 'Image Link', 'catch-store-pro' ),
			'section'           => 'catch_store_promotion_headline',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_promotion_headline_target',
			'sanitize_callback' => 'catch_store_sanitize_checkbox',
			'active_callback'   => 'catch_store_is_promotion_headline_custom_content_active',
			'label'             => esc_html__( 'Check to Open Link in New Window/Tab', 'catch-store-pro' ),
			'section'           => 'catch_store_promotion_headline',
			'type'              => 'checkbox',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_promotion_headline_more_text',
			'sanitize_callback' => 'sanitize_text_field',
			'active_callback'   => 'catch_store_is_promotion_headline_custom_content_active',
			'label'             => esc_html__( 'Button Text', 'catch-store-pro' ),
			'section'           => 'catch_store_promotion_headline',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_promotion_headline_more_link',
			'sanitize_callback' => 'esc_url_raw',
			'active_callback'   => 'catch_store_is_promotion_headline_custom_content_active',
			'label'             => esc_html__( 'Button Link', 'catch-store-pro' ),
			'section'           => 'catch_store_promotion_headline',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_promotion_headline_more_target',
			'sanitize_callback' => 'catch_store_sanitize_checkbox',
			'active_callback'   => 'catch_store_is_promotion_headline_custom_content_active',
			'label'             => esc_html__( 'Check to Open Button Link in New Window/Tab', 'catch-store-pro' ),
			'section'           => 'catch_store_promotion_headline',
			'type'              => 'checkbox',
		)
	);
}
add_action( 'customize_register', 'catch_store_promotion_headline_options' );

/** Active Callback Functions **/
if ( ! function_exists( 'catch_store_is_promotion_headline_active' ) ) :
	/**
	* Return true if promotion headline is active
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_promotion_headline_active( $control ) {
		$enable = $control->manager->get_setting( 'catch_store_promotion_headline_visibility' )->value();

		return ( catch_store_check_section( $enable ) );
	}
endif;


if ( ! function_exists( 'catch_store_is_demo_promotion_headline_inactive' ) ) :
	/**
	* Return true if demo promotion headline is inactive
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_demo_promotion_headline_inactive( $control ) {
		$type = $control->manager->get_setting( 'catch_store_promotion_headline_type' )->value();

		return ( catch_store_is_promotion_headline_active( $control ) && 'demo' !== $type );
	}
endif;


if ( ! function_exists( 'catch_store_is_promotion_headline_post_content_active' ) ) :
	/**
	* Return true if post content is active
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_promotion_headline_post_content_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_promotion_headline_type' )->value();

		return ( catch_store_is_promotion_headline_active( $control ) && 'post' === $type );
	}
endif;


if ( ! function_exists( 'catch_store_is_promotion_headline_page_content_active' ) ) :
	/**
	* Return true if promotion headline page content is active
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_promotion_headline_page_content_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_promotion_headline_type' )->value();

		return ( catch_store_is_promotion_headline_active( $control ) && 'page' === $type );
	}
endif;


if ( ! function_exists( 'catch_store_is_promotion_headline_category_content_active' ) ) :
	/**
	* Return true if promotion headline category content is active
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_promotion_headline_category_content_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_promotion_headline_type' )->value();

		return ( catch_store_is_promotion_headline_active( $control ) && 'category' === $type );
	}
endif;

if ( ! function_exists( 'catch_store_is_promotion_headline_post_page_category_product_content_active' ) ) :
	/**
	* Return true if promotion headline post/page/category content is active
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_promotion_headline_post_page_category_product_content_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_promotion_headline_type' )->value();

		return ( catch_store_is_promotion_headline_active( $control ) && ( 'page' === $type || 'post' === $type || 'category' === $type || 'product' === $type ) );
	}
endif;


if ( ! function_exists( 'catch_store_is_promotion_headline_custom_content_active' ) ) :
	/**
	* Return true if promotion headline custom content is active
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_promotion_headline_custom_content_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_promotion_headline_type' )->value();

		return ( catch_store_is_promotion_headline_active( $control ) && ( 'image' === $type ) );
	}
endif;

if( ! function_exists( 'catch_store_is_promotion_headline_product_content_active' ) ) :
	/**
	* Return true if promotion headline product content is active
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_promotion_headline_product_content_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_promotion_headline_type' )->value();

		return ( catch_store_is_promotion_headline_active( $control ) && ( 'product' === $type ) );
	}
endif;

