<?php
/**
 * Stats options
 *
 * @package Catch Store Pro
 */

/**
 * Add stats options to theme options
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function catch_store_stats_options( $wp_customize ) {
	$wp_customize->add_section( 'catch_store_stats', array(
			'title' => esc_html__( 'Stats', 'catch-store-pro' ),
			'panel' => 'catch_store_theme_options',
		)
	);

	// Add color scheme setting and control.
	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_stats_option',
			'default'           => 'disabled',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'choices'           => catch_store_section_visibility_options(),
			'label'             => esc_html__( 'Enable on', 'catch-store-pro' ),
			'section'           => 'catch_store_stats',
			'type'              => 'select',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_stats_layout',
			'default'           => 'layout-four',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'active_callback'   => 'catch_store_is_stats_active',
			'choices'           => catch_store_sections_layout_options(),
			'label'             => esc_html__( 'Layout', 'catch-store-pro' ),
			'section'           => 'catch_store_stats',
			'type'              => 'select',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_stats_title',
			'default'           => esc_html__( 'Stats', 'catch-store-pro' ),
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'catch_store_is_demo_stats_inactive',
			'label'             => esc_html__( 'Title', 'catch-store-pro' ),
			'section'           => 'catch_store_stats',
			'type'              => 'text',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_stats_sub_title',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'catch_store_is_demo_stats_inactive',
			'label'             => esc_html__( 'Sub Title', 'catch-store-pro' ),
			'section'           => 'catch_store_stats',
			'type'              => 'textarea',
		)
	);

	$type = catch_store_section_type_options();

    unset( $type['product'] );

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_stats_type',
			'default'           => 'demo',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'active_callback'   => 'catch_store_is_stats_active',
			'choices'           => $type,
			'label'             => esc_html__( 'Type', 'catch-store-pro' ),
			'section'           => 'catch_store_stats',
			'type'              => 'select',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_stats_number',
			'default'           => 4,
			'sanitize_callback' => 'catch_store_sanitize_number_range',
			'active_callback'   => 'catch_store_is_stats_active',
			'description'       => esc_html__( 'Save and refresh the page if No of items is changed', 'catch-store-pro' ),
			'input_attrs'       => array(
				'style' => 'width: 100px;',
				'min'   => 0,
			),
			'label'             => esc_html__( 'No of Items', 'catch-store-pro' ),
			'section'           => 'catch_store_stats',
			'type'              => 'number',
			'transport'         => 'postMessage',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_stats_show',
			'default'           => 'excerpt',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'active_callback'   => 'catch_store_is_post_category_stat_active',
			'choices'           => catch_store_content_show(),
			'label'             => esc_html__( 'Display Content', 'catch-store-pro' ),
			'section'           => 'catch_store_stats',
			'type'              => 'select',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_stats_select_category',
			'sanitize_callback' => 'catch_store_sanitize_category_list',
			'custom_control'    => 'catch_store_Multi_Categories_Control',
			'active_callback'   => 'catch_store_is_category_stat_active',
			'label'             => esc_html__( 'Select Categories', 'catch-store-pro' ),
			'name'              => 'catch_store_stats_select_category',
			'section'           => 'catch_store_stats',
			'type'              => 'dropdown-categories',
		)
	);

	$number = get_theme_mod( 'catch_store_stats_number', 4 );

	for ( $i = 1; $i <= $number ; $i++ ) {
		catch_store_register_option( $wp_customize, array(
				'name'              => 'catch_store_stats_post_' . $i,
				'sanitize_callback' => 'catch_store_sanitize_post',
				'default'           => 0,
				'active_callback'   => 'catch_store_is_post_stat_active',
				'input_attrs'       => array(
					'style'             => 'width: 40px;'
				),
				'label'             => esc_html__( 'Post', 'catch-store-pro' ) . ' ' . $i ,
				'section'           => 'catch_store_stats',
				'choices'           => catch_store_generate_post_array(),
				'type'              => 'select'
			)
		);

		catch_store_register_option( $wp_customize, array(
				'name'              => 'catch_store_stats_page_' . $i,
				'sanitize_callback' => 'catch_store_sanitize_post',
				'active_callback'   => 'catch_store_is_page_stat_active',
				'label'             => esc_html__( 'Featured Page', 'catch-store-pro' ) . ' ' . $i ,
				'section'           => 'catch_store_stats',
				'type'              => 'dropdown-pages',
			)
		);

		catch_store_register_option( $wp_customize, array(
				'name'              => 'catch_store_stats_note_' . $i,
				'sanitize_callback' => 'sanitize_text_field',
				'custom_control'    => 'catch_store_Note_Control',
				'active_callback'   => 'catch_store_is_image_stat_active',
				'label'             => esc_html__( 'Item #', 'catch-store-pro' ) .  $i,
				'section'           => 'catch_store_stats',
				'type'              => 'description',
			)
		);

		catch_store_register_option( $wp_customize, array(
				'name'              => 'catch_store_stats_image_' . $i,
				'sanitize_callback' => 'catch_store_sanitize_image',
				'custom_control'    => 'WP_Customize_Image_Control',
				'active_callback'   => 'catch_store_is_image_stat_active',
				'label'             => esc_html__( 'Image', 'catch-store-pro' ),
				'section'           => 'catch_store_stats',
			)
		);

		catch_store_register_option( $wp_customize, array(
				'name'              => 'catch_store_stats_link_' . $i,
				'sanitize_callback' => 'esc_url_raw',
				'active_callback'   => 'catch_store_is_image_stat_active',
				'label'             => esc_html__( 'Link', 'catch-store-pro' ),
				'section'           => 'catch_store_stats',
			)
		);

		catch_store_register_option( $wp_customize, array(
				'name'              => 'catch_store_stats_target_' . $i,
				'sanitize_callback' => 'catch_store_sanitize_checkbox',
				'active_callback'   => 'catch_store_is_image_stat_active',
				'label'             => esc_html__( 'Check to Open Link in New Window/Tab', 'catch-store-pro' ),
				'section'           => 'catch_store_stats',
				'type'              => 'checkbox',
			)
		);

		catch_store_register_option( $wp_customize, array(
				'name'              => 'catch_store_stats_title_' . $i,
				'sanitize_callback' => 'wp_kses_post',
				'active_callback'   => 'catch_store_is_image_stat_active',
				'label'             => esc_html__( 'Title', 'catch-store-pro' ),
				'section'           => 'catch_store_stats',
				'type'              => 'text',
			)
		);

		catch_store_register_option( $wp_customize, array(
				'name'              => 'catch_store_stats_content_' . $i,
				'sanitize_callback' => 'wp_kses_post',
				'active_callback'   => 'catch_store_is_image_stat_active',
				'label'             => esc_html__( 'Content', 'catch-store-pro' ),
				'section'           => 'catch_store_stats',
				'type'              => 'textarea',
			)
		);
	} // End for().
}
add_action( 'customize_register', 'catch_store_stats_options', 10 );

/** Active Callback Functions **/
if( ! function_exists( 'catch_store_is_stats_active' ) ) :
	/**
	* Return true if stat is active
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_stats_active( $control ) {
		$enable = $control->manager->get_setting( 'catch_store_stats_option' )->value();

		return ( catch_store_check_section( $enable ) );
	}
endif;


if( ! function_exists( 'catch_store_is_demo_stats_inactive' ) ) :
	/**
	* Return true if demo stat is inactive
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_demo_stats_inactive( $control ) {
		$type = $control->manager->get_setting( 'catch_store_stats_type' )->value();

		return ( catch_store_is_stats_active( $control ) && 'demo' !== $type );
	}
endif;


if( ! function_exists( 'catch_store_is_post_stat_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_post_stat_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_stats_type' )->value();

		return ( catch_store_is_stats_active( $control ) && 'post' === $type );
	}
endif;


if( ! function_exists( 'catch_store_is_page_stat_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_page_stat_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_stats_type' )->value();

		return ( catch_store_is_stats_active( $control ) && 'page' === $type );
	}
endif;


if( ! function_exists( 'catch_store_is_category_stat_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_category_stat_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_stats_type' )->value();

		return ( catch_store_is_stats_active( $control ) && 'category' === $type );
	}
endif;

if( ! function_exists( 'catch_store_is_post_category_stat_active' ) ) :
	/**
	* Return true if page/post/category/image content is active
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_post_category_stat_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_stats_type' )->value();

		return ( catch_store_is_stats_active( $control ) && ( 'category' === $type || 'post' === $type ) );
	}
endif;


if( ! function_exists( 'catch_store_is_image_stat_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_image_stat_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_stats_type' )->value();

		return ( catch_store_is_stats_active( $control ) && 'image' === $type );
	}
endif;
