<?php
/**
 * Team options
 *
 * @package Catch_Store
 */

/**
 * Add team content options to theme options
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function catch_store_team_options( $wp_customize ) {

	$wp_customize->add_section( 'catch_store_team', array(
			'title' => esc_html__( 'Team', 'catch-store-pro' ),
			'panel' => 'catch_store_theme_options',
		)
	);

	// Add color scheme setting and control.
	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_team_option',
			'default'           => 'disabled',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'choices'           => catch_store_section_visibility_options(),
			'label'             => esc_html__( 'Enable on', 'catch-store-pro' ),
			'section'           => 'catch_store_team',
			'type'              => 'select',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_team_layout',
			'default'           => 'layout-four',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'active_callback'   => 'catch_store_is_team_active',
			'choices'           => catch_store_sections_layout_options(),
			'label'             => esc_html__( 'Select Featured Content Layout', 'catch-store-pro' ),
			'section'           => 'catch_store_team',
			'type'              => 'select',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_team_title',
			'default'           => esc_html__( 'Our Team', 'catch-store-pro' ),
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'catch_store_is_team_active',
			'label'             => esc_html__( 'Headline', 'catch-store-pro' ),
			'section'           => 'catch_store_team',
			'type'              => 'text',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_team_sub_title',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'catch_store_is_team_active',
			'label'             => esc_html__( 'Sub headline', 'catch-store-pro' ),
			'section'           => 'catch_store_team',
			'type'              => 'textarea',
		)
	);

	$type = catch_store_section_type_options();

    unset( $type['product'] );
    
	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_team_type',
			'default'           => 'demo',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'active_callback'   => 'catch_store_is_team_active',
			'choices'           => $type,
			'label'             => esc_html__( 'Type', 'catch-store-pro' ),
			'section'           => 'catch_store_team',
			'type'              => 'select',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_team_number',
			'default'           => 4,
			'sanitize_callback' => 'catch_store_sanitize_number_range',
			'active_callback'   => 'catch_store_is_demo_team_inactive',
			'description'       => esc_html__( 'Save and refresh the page if No. of Items is changed', 'catch-store-pro' ),
			'input_attrs'       => array(
				'style' => 'width: 100px;',
				'min'   => 0,
			),
			'label'             => esc_html__( 'No of Items', 'catch-store-pro' ),
			'section'           => 'catch_store_team',
			'type'              => 'number',
			'transport'         => 'postMessage',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_team_show',
			'default'           => 'hide-content',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'active_callback'   => 'catch_store_is_team_post_page_category_content_active',
			'choices'           => catch_store_content_show(),
			'label'             => esc_html__( 'Display Content', 'catch-store-pro' ),
			'section'           => 'catch_store_team',
			'type'              => 'select',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_team_meta_show',
			'default'           => 'hide-meta',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'active_callback'   => 'catch_store_is_team_post_page_category_content_active',
			'choices'           => catch_store_meta_show(),
			'label'             => esc_html__( 'Display Meta', 'catch-store-pro' ),
			'section'           => 'catch_store_team',
			'type'              => 'select',
		)
	);


	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_team_select_category',
			'sanitize_callback' => 'catch_store_sanitize_category_list',
			'custom_control'    => 'catch_store_Multi_Categories_Control',
			'active_callback'   => 'catch_store_is_team_category_content_active',
			'label'             => esc_html__( 'Select Categories', 'catch-store-pro' ),
			'name'              => 'catch_store_team_select_category',
			'section'           => 'catch_store_team',
			'type'              => 'dropdown-categories',
		)
	);

	$number = get_theme_mod( 'catch_store_team_number', 4 );

	//loop for team post content
	for ( $i = 1; $i <= $number ; $i++ ) {
		catch_store_register_option( $wp_customize, array(
				'name'              => 'catch_store_team_post_' . $i,
				'sanitize_callback' => 'catch_store_sanitize_post',
				'default'           => 0,
				'active_callback'   => 'catch_store_is_team_post_content_active',
				'input_attrs'       => array(
					'style'             => 'width: 40px;'
				),
				'label'             => esc_html__( 'Post', 'catch-store-pro' ) . ' ' . $i ,
				'section'           => 'catch_store_team',
				'choices'           => catch_store_generate_post_array(),
				'type'              => 'select'
			)
		);

		catch_store_register_option( $wp_customize, array(
				'name'              => 'catch_store_team_page_' . $i,
				'sanitize_callback' => 'catch_store_sanitize_post',
				'active_callback'   => 'catch_store_is_team_page_content_active',
				'label'             => esc_html__( 'Team Page', 'catch-store-pro' ) . ' ' . $i ,
				'section'           => 'catch_store_team',
				'type'              => 'dropdown-pages',
			)
		);

		catch_store_register_option( $wp_customize, array(
				'name'              => 'catch_store_team_note_' . $i,
				'sanitize_callback' => 'sanitize_text_field',
				'custom_control'    => 'catch_store_Note_Control',
				'active_callback'   => 'catch_store_is_team_image_content_active',
				'label'             => esc_html__( 'Team #', 'catch-store-pro' ) .  $i,
				'section'           => 'catch_store_team',
				'type'              => 'description',
			)
		);

		catch_store_register_option( $wp_customize, array(
				'name'              => 'catch_store_team_image_' . $i,
				'sanitize_callback' => 'catch_store_sanitize_image',
				'custom_control'    => 'WP_Customize_Image_Control',
				'active_callback'   => 'catch_store_is_team_image_content_active',
				'label'             => esc_html__( 'Image', 'catch-store-pro' ),
				'section'           => 'catch_store_team',
			)
		);

		catch_store_register_option( $wp_customize, array(
				'name'              => 'catch_store_team_link_' . $i,
				'sanitize_callback' => 'esc_url_raw',
				'active_callback'   => 'catch_store_is_team_image_content_active',
				'label'             => esc_html__( 'Link', 'catch-store-pro' ),
				'section'           => 'catch_store_team',
			)
		);

		catch_store_register_option( $wp_customize, array(
				'name'              => 'catch_store_team_target_' . $i,
				'sanitize_callback' => 'catch_store_sanitize_checkbox',
				'active_callback'   => 'catch_store_is_team_image_content_active',
				'label'             => esc_html__( 'Check to Open Link in New Window/Tab', 'catch-store-pro' ),
				'section'           => 'catch_store_team',
				'type'              => 'checkbox',
			)
		);

		catch_store_register_option( $wp_customize, array(
				'name'              => 'catch_store_team_title_' . $i,
				'sanitize_callback' => 'sanitize_text_field',
				'active_callback'   => 'catch_store_is_team_image_content_active',
				'label'             => esc_html__( 'Title', 'catch-store-pro' ),
				'section'           => 'catch_store_team',
				'type'              => 'text',
			)
		);

		catch_store_register_option( $wp_customize, array(
				'name'              => 'catch_store_team_position_' . $i,
				'sanitize_callback' => 'sanitize_text_field',
				'active_callback'   => 'catch_store_is_team_image_content_active',
				'label'             => esc_html__( 'Position', 'catch-store-pro' ),
				'section'           => 'catch_store_team',
				'type'              => 'text',
			)
		);

		catch_store_register_option( $wp_customize, array(
				'name'              => 'catch_store_team_content_' . $i,
				'sanitize_callback' => 'wp_kses_post',
				'active_callback'   => 'catch_store_is_team_image_content_active',
				'label'             => esc_html__( 'Content', 'catch-store-pro' ),
				'section'           => 'catch_store_team',
				'type'              => 'textarea',
			)
		);
		catch_store_register_option( $wp_customize, array(
				'name'              => 'catch_store_team_social_link_one_' . $i,
				'sanitize_callback' => 'esc_url_raw',
				'active_callback'   => 'catch_store_is_demo_team_inactive',
				'label'             => esc_html__( 'Team #', 'catch-store-pro' ) .  $i . esc_html__( ': Social Link #1', 'catch-store-pro' ),
				'section'           => 'catch_store_team',
			)
		);

		catch_store_register_option( $wp_customize, array(
				'name'              => 'catch_store_team_social_link_two_' . $i,
				'sanitize_callback' => 'esc_url_raw',
				'active_callback'   => 'catch_store_is_demo_team_inactive',
				'label'             => esc_html__( 'Team #', 'catch-store-pro' ) .  $i . esc_html__( ': Social Link #2', 'catch-store-pro' ),
				'section'           => 'catch_store_team',
			)
		);

		catch_store_register_option( $wp_customize, array(
				'name'              => 'catch_store_team_social_link_three_' . $i,
				'sanitize_callback' => 'esc_url_raw',
				'active_callback'   => 'catch_store_is_demo_team_inactive',
				'label'             => esc_html__( 'Team #', 'catch-store-pro' ) .  $i . esc_html__( ': Social Link #3', 'catch-store-pro' ),
				'section'           => 'catch_store_team',
			)
		);

		catch_store_register_option( $wp_customize, array(
				'name'              => 'catch_store_team_social_link_four_' . $i,
				'sanitize_callback' => 'esc_url_raw',
				'active_callback'   => 'catch_store_is_demo_team_inactive',
				'label'             => esc_html__( 'Team #', 'catch-store-pro' ) .  $i . esc_html__( ': Social Link #4', 'catch-store-pro' ),
				'section'           => 'catch_store_team',
			)
		);
	} // End for().

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_team_text',
			'default'           => esc_html__( 'View All', 'catch-store-pro' ),
			'sanitize_callback' => 'sanitize_text_field',
			'active_callback'   => 'catch_store_is_team_active',
			'label'             => esc_html__( 'Button Text', 'catch-store-pro' ),
			'section'           => 'catch_store_team',
			'type'              => 'text',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_team_link',
			'sanitize_callback' => 'esc_url_raw',
			'active_callback'   => 'catch_store_is_team_active',
			'label'             => esc_html__( 'Button Link', 'catch-store-pro' ),
			'section'           => 'catch_store_team',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_team_target',
			'sanitize_callback' => 'catch_store_sanitize_checkbox',
			'active_callback'   => 'catch_store_is_team_active',
			'label'             => esc_html__( 'Check to Open Link in New Window/Tab', 'catch-store-pro' ),
			'section'           => 'catch_store_team',
			'type'              => 'checkbox',
		)
	);
}
add_action( 'customize_register', 'catch_store_team_options', 10 );

/** Active Callback Functions **/
if ( ! function_exists( 'catch_store_is_team_active' ) ) :
	/**
	* Return true if team content is active
	*
	* @since Solid Construction Pro 1.0
	*/
	function catch_store_is_team_active( $control ) {
		$enable = $control->manager->get_setting( 'catch_store_team_option' )->value();

		//return true only if previewed page on customizer matches the type of content option selected
		return ( catch_store_check_section( $enable ) );
	}
endif;

if ( ! function_exists( 'catch_store_is_demo_team_inactive' ) ) :
	/**
	* Return true if demo team content is inactive
	*
	* @since Adonis Pro 1.0
	*/
	function catch_store_is_demo_team_inactive( $control ) {
		$type = $control->manager->get_setting( 'catch_store_team_type' )->value();

		return ( catch_store_is_team_active( $control ) && 'demo' !== $type );
	}
endif;

if ( ! function_exists( 'catch_store_is_team_post_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Solid Construction Pro 1.0
	*/
	function catch_store_is_team_post_content_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_team_type' )->value();

		//return true only if previewed page on customizer matches the type of content option selected and is or is not selected type
		return ( catch_store_is_team_active( $control ) && ( 'post' === $type ) );
	}
endif;

if ( ! function_exists( 'catch_store_is_team_page_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Solid Construction Pro 1.0
	*/
	function catch_store_is_team_page_content_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_team_type' )->value();

		//return true only if previewed page on customizer matches the type of content option selected and is or is not selected type
		return ( catch_store_is_team_active( $control ) && ( 'page' === $type ) );
	}
endif;

if ( ! function_exists( 'catch_store_is_team_category_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Solid Construction Pro 1.0
	*/
	function catch_store_is_team_category_content_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_team_type' )->value();

		//return true only if previewed page on customizer matches the type of content option selected and is or is not selected type
		return ( catch_store_is_team_active( $control ) && ( 'category' === $type ) );
	}
endif;

if ( ! function_exists( 'catch_store_is_team_post_page_category_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Solid Construction Pro 1.0
	*/
	function catch_store_is_team_post_page_category_content_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_team_type' )->value();

		//return true only if previewed page on customizer matches the type of content option selected and is or is not selected type
		return ( catch_store_is_team_active( $control ) && ( 'category' === $type || 'page' === $type || 'post' === $type ) );
	}
endif;

if ( ! function_exists( 'catch_store_is_team_image_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since Solid Construction Pro 1.0
	*/
	function catch_store_is_team_image_content_active( $control ) {
		$type = $control->manager->get_setting( 'catch_store_team_type' )->value();

		//return true only if previewed page on customizer matches the type of content option selected and is or is not selected type
		return ( catch_store_is_team_active( $control ) && ( 'image' === $type ) );
	}
endif;