<?php
/**
 * Add Testimonial Settings in Customizer
 *
 * @package Catch_Store
*/

/**
 * Add testimonial options to theme options
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function catch_store_testimonial_options( $wp_customize ) {
    // Add note to Jetpack Testimonial Section
    catch_store_register_option( $wp_customize, array(
            'name'              => 'catch_store_jetpack_testimonial_cpt_note',
            'sanitize_callback' => 'sanitize_text_field',
            'custom_control'    => 'catch_store_Note_Control',
            'label'             => sprintf( esc_html__( 'For Testimonial Options for Catch Store Theme, go %1$shere%2$s', 'catch-store-pro' ),
                '<a href="javascript:wp.customize.section( \'catch_store_testimonials\' ).focus();">',
                 '</a>'
            ),
           'section'            => 'jetpack_testimonials',
            'type'              => 'description',
            'priority'          => 1,
        )
    );

    $wp_customize->add_section( 'catch_store_testimonials', array(
            'panel'    => 'catch_store_theme_options',
            'title'    => esc_html__( 'Testimonials', 'catch-store-pro' ),
        )
    );

    catch_store_register_option( $wp_customize, array(
            'name'              => 'catch_store_testimonial_option',
            'default'           => 'disabled',
            'sanitize_callback' => 'catch_store_sanitize_select',
            'choices'           => catch_store_section_visibility_options(),
            'label'             => esc_html__( 'Enable on', 'catch-store-pro' ),
            'section'           => 'catch_store_testimonials',
            'type'              => 'select',
            'priority'          => 1,
        )
    );

    $layouts = catch_store_sections_layout_options();

    unset( $layouts['layout-three'], $layouts['layout-four'] );

     catch_store_register_option( $wp_customize, array(
            'name'              => 'catch_store_testimonial_layout',
            'default'           => 'layout-two',
            'sanitize_callback' => 'catch_store_sanitize_select',
            'active_callback'   => 'catch_store_is_testimonial_active',
            'choices'           => $layouts,
            'label'             => esc_html__( 'Select Testimonial Layout', 'catch-store-pro' ),
            'section'           => 'catch_store_testimonials',
            'type'              => 'select',
        )
    );


    catch_store_register_option( $wp_customize, array(
            'name'              => 'catch_store_testimonial_slider',
            'default'           => 1,
            'sanitize_callback' => 'catch_store_sanitize_checkbox',
            'active_callback'   => 'catch_store_is_testimonial_active',
            'label'             => esc_html__( 'Check to Enable Slider', 'catch-store-pro' ),
            'section'           => 'catch_store_testimonials',
            'type'              => 'checkbox',
        )
    );

    $type = catch_store_section_type_options();

    unset( $type['product'] );

    $type['jetpack-testimonial'] = esc_html__( 'Custom Post Type', 'catch-store-pro' );

    catch_store_register_option( $wp_customize, array(
            'name'              => 'catch_store_testimonial_type',
            'default'           => 'demo',
            'sanitize_callback' => 'catch_store_sanitize_select',
            'active_callback'   => 'catch_store_is_testimonial_active',
            'choices'           => $type,
            'description'       => sprintf( esc_html__( 'For Custom Post Type Content, install %1$sEssential Content Types%2$s Plugin with Testimonial Content Type Enabled', 'catch-store-pro' ),
                '<a target="_blank" href="https://wordpress.org/plugins/essential-content-types/">',
                '</a>'
            ),
            'label'             => esc_html__( 'Select Type', 'catch-store-pro' ),
            'section'           => 'catch_store_testimonials',
            'type'              => 'select',
        )
    );

    catch_store_register_option( $wp_customize, array(
            'name'              => 'catch_store_testimonial_cpt_note',
            'sanitize_callback' => 'sanitize_text_field',
            'custom_control'    => 'catch_store_Note_Control',
            'active_callback'   => 'catch_store_is_jetpack_testimonial_active',
            /* translators: 1: <a>/link tag start, 2: </a>/link tag close. */
			'label'             => sprintf( esc_html__( 'For CPT heading and sub-heading, go %1$shere%2$s', 'catch-store-pro' ),
                '<a href="javascript:wp.customize.section( \'jetpack_testimonials\' ).focus();">',
                '</a>'
            ),
            'section'           => 'catch_store_testimonials',
            'type'              => 'description',
        )
    );

    catch_store_register_option( $wp_customize, array(
            'name'              => 'catch_store_testimonial_headline',
            'default'           => esc_html__( 'Testimonials', 'catch-store-pro' ),
            'sanitize_callback' => 'wp_kses_post',
            'label'             => esc_html__( 'Headline', 'catch-store-pro' ),
            'active_callback'   => 'catch_store_is_demo_cpt_testimonial_inactive',
            'section'           => 'catch_store_testimonials',
            'type'              => 'text',
        )
    );

    catch_store_register_option( $wp_customize, array(
            'name'              => 'catch_store_testimonial_subheadline',
            'sanitize_callback' => 'wp_kses_post',
            'label'             => esc_html__( 'Sub headline', 'catch-store-pro' ),
            'active_callback'   => 'catch_store_is_demo_cpt_testimonial_inactive',
            'section'           => 'catch_store_testimonials',
            'type'              => 'text',
        )
    );

    catch_store_register_option( $wp_customize, array(
            'name'              => 'catch_store_testimonial_number',
            'default'           => '4',
            'sanitize_callback' => 'catch_store_sanitize_number_range',
            'active_callback'   => 'catch_store_is_demo_testimonial_inactive',
            'label'             => esc_html__( 'Number of items to show', 'catch-store-pro' ),
            'section'           => 'catch_store_testimonials',
            'type'              => 'number',
            'input_attrs'       => array(
                'style'             => 'width: 100px;',
                'min'               => 0,
            ),
        )
    );

    catch_store_register_option( $wp_customize, array(
            'name'              => 'catch_store_testimonial_enable_title',
            'default'           => 1,
            'sanitize_callback' => 'catch_store_sanitize_checkbox',
            'active_callback'   => 'catch_store_is_demo_testimonial_inactive',
            'label'             => esc_html__( 'Check to Enable Title', 'catch-store-pro' ),
            'section'           => 'catch_store_testimonials',
            'type'              => 'checkbox',
        )
    );

    catch_store_register_option( $wp_customize, array(
            'name'              => 'catch_store_testimonial_show',
            'default'           => 'full-content',
            'sanitize_callback' => 'catch_store_sanitize_select',
            'active_callback'   => 'catch_store_is_post_page_category_cpt_testimonial_active',
            'choices'           => catch_store_content_show(),
            'label'             => esc_html__( 'Display Content', 'catch-store-pro' ),
            'section'           => 'catch_store_testimonials',
            'type'              => 'select',
        )
    );

    catch_store_register_option( $wp_customize, array(
            'name'              => 'catch_store_testimonial_select_category',
            'sanitize_callback' => 'catch_store_sanitize_category_list',
            'active_callback'   => 'catch_store_is_category_testimonial_active',
            'custom_control'    => 'catch_store_Multi_Categories_Control',
            'label'             => esc_html__( 'Select Categories', 'catch-store-pro' ),
            'name'              => 'catch_store_testimonial_select_category',
            'section'           => 'catch_store_testimonials',
            'type'              => 'dropdown-categories',
        )
    );

    $number = get_theme_mod( 'catch_store_testimonial_number', 4 );

    for ( $i = 1; $i <= $number ; $i++ ) {
        //for featured post content
        catch_store_register_option( $wp_customize, array(
                'name'              => 'catch_store_testimonial_post_' . $i,
                'sanitize_callback' => 'catch_store_sanitize_post',
                'active_callback'   => 'catch_store_is_post_testimonial_active',
                'input_attrs'       => array(
                'style'             => 'width: 100px;'
                ),
                'label'             => esc_html__( 'Post', 'catch-store-pro' ) . ' ' . $i ,
                'section'           => 'catch_store_testimonials',
                'choices'           => catch_store_generate_post_array(),
                'type'              => 'select',
            )
        );

        //for CPT
        catch_store_register_option( $wp_customize, array(
                'name'              => 'catch_store_testimonial_cpt_' . $i,
                'sanitize_callback' => 'catch_store_sanitize_post',
                'active_callback'   => 'catch_store_is_jetpack_testimonial_active',
                'label'             => esc_html__( 'Testimonial', 'catch-store-pro' ) . ' ' . $i ,
                'section'           => 'catch_store_testimonials',
                'type'              => 'select',
                'choices'           => catch_store_generate_post_array( 'jetpack-testimonial' ),
            )
        );

        catch_store_register_option( $wp_customize, array(
                'name'              => 'catch_store_testimonial_page_' . $i,
                'sanitize_callback' => 'catch_store_sanitize_post',
                'active_callback'   => 'catch_store_is_page_testimonial_active',
                'label'             => esc_html__( 'Page', 'catch-store-pro' ) . ' ' . $i ,
                'section'           => 'catch_store_testimonials',
                'type'              => 'dropdown-pages',
            )
        );

        catch_store_register_option( $wp_customize, array(
                'name'              => 'catch_store_testimonial_note_' . $i,
                'sanitize_callback' => 'sanitize_text_field',
                'custom_control'    => 'catch_store_Note_Control',
                'active_callback'   => 'catch_store_is_image_testimonial_active',
                'label'             => esc_html__( 'Testimonial #', 'catch-store-pro' ) .  $i,
                'section'           => 'catch_store_testimonials',
                'type'              => 'description',
            )
        );

        catch_store_register_option( $wp_customize, array(
                'name'              => 'catch_store_testimonial_image_' . $i,
                'custom_control'      => 'WP_Customize_Image_Control',
                'sanitize_callback' => 'catch_store_sanitize_image',
                'active_callback'   => 'catch_store_is_image_testimonial_active',
                'label'             => esc_html__( 'Image', 'catch-store-pro' ),
                'section'           => 'catch_store_testimonials',
            )
        );

        catch_store_register_option( $wp_customize, array(
                'name'              => 'catch_store_testimonial_link_' . $i,
                'sanitize_callback' => 'esc_url_raw',
                'active_callback'   => 'catch_store_is_image_testimonial_active',
                'label'             => esc_html__( 'Link', 'catch-store-pro' ),
                'section'           => 'catch_store_testimonials',
            )
        );

        catch_store_register_option( $wp_customize, array(
                'name'              => 'catch_store_testimonial_target_' . $i,
                'sanitize_callback' => 'catch_store_sanitize_checkbox',
                'active_callback'   => 'catch_store_is_image_testimonial_active',
                'label'             => esc_html__( 'Check to Open Link in New Window/Tab', 'catch-store-pro' ),
                'section'           => 'catch_store_testimonials',
                'type'              => 'checkbox',
            )
        );

        catch_store_register_option( $wp_customize, array(
                'name'              => 'catch_store_testimonial_content_' . $i,
                'sanitize_callback' => 'sanitize_text_field',
                'active_callback'   => 'catch_store_is_image_testimonial_active',
                'label'             => esc_html__( 'Testimonial Text', 'catch-store-pro' ),
                'section'           => 'catch_store_testimonials',
                'type'              => 'textarea',
            )
        );

        catch_store_register_option( $wp_customize, array(
                'name'              => 'catch_store_testimonial_title_' . $i,
                'sanitize_callback' => 'sanitize_text_field',
                'active_callback'   => 'catch_store_is_image_testimonial_active',
                'label'             => esc_html__( 'Name', 'catch-store-pro' ),
                'section'           => 'catch_store_testimonials',
                'type'              => 'text',
            )
        );

        catch_store_register_option( $wp_customize, array(
                'name'              => 'catch_store_testimonial_position_' . $i,
                'sanitize_callback' => 'sanitize_text_field',
                'active_callback'   => 'catch_store_is_image_testimonial_active',
                'label'             => esc_html__( 'Position', 'catch-store-pro' ),
                'section'           => 'catch_store_testimonials',
                'type'              => 'text',
            )
        );
    } // End for().
}
add_action( 'customize_register', 'catch_store_testimonial_options' );

/**
 * Active Callback Functions
 */
if ( ! function_exists( 'catch_store_is_testimonial_active' ) ) :
    /**
    * Return true if testimonial is active
    *
    * @since Catch Store Pro 1.0
    */
    function catch_store_is_testimonial_active( $control ) {
        $enable = $control->manager->get_setting( 'catch_store_testimonial_option' )->value();

        //return true only if previwed page on customizer matches the type of content option selected
        return ( catch_store_check_section( $enable ) );
    }
endif;


if ( ! function_exists( 'catch_store_is_demo_testimonial_inactive' ) ) :
    /**
    * Return true if demo testimonial is inactive
    *
    * @since Catch Store Pro 1.0
    */
    function catch_store_is_demo_testimonial_inactive( $control ) {
        $type = $control->manager->get_setting( 'catch_store_testimonial_type' )->value();

        //return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
        return ( catch_store_is_testimonial_active( $control ) && !( 'demo' === $type ) );
    }
endif;


if ( ! function_exists( 'catch_store_is_post_testimonial_active' ) ) :
    /**
    * Return true if page content is active
    *
    * @since Catch Store Pro 1.0
    */
    function catch_store_is_post_testimonial_active( $control ) {
        $type = $control->manager->get_setting( 'catch_store_testimonial_type' )->value();

        //return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
        return ( catch_store_is_testimonial_active( $control ) && 'post' === $type );
    }
endif;


if ( ! function_exists( 'catch_store_is_jetpack_testimonial_active' ) ) :
    /**
    * Return true if jetpack testimonial is active
    *
    * @since Catch Store Pro 1.0
    */
    function catch_store_is_jetpack_testimonial_active( $control ) {
        $type = $control->manager->get_setting( 'catch_store_testimonial_type' )->value();

        //return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
        return ( catch_store_is_testimonial_active( $control ) && 'jetpack-testimonial' === $type );
    }
endif;


if ( ! function_exists( 'catch_store_is_page_testimonial_active' ) ) :
    /**
    * Return true if page content is active
    *
    * @since Catch Store Pro 1.0
    */
    function catch_store_is_page_testimonial_active( $control ) {
        $type = $control->manager->get_setting( 'catch_store_testimonial_type' )->value();

        //return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
        return ( catch_store_is_testimonial_active( $control ) && 'page' === $type );
    }
endif;


if ( ! function_exists( 'catch_store_is_category_testimonial_active' ) ) :
    /**
    * Return true if page content is active
    *
    * @since Catch Store Pro 1.0
    */
    function catch_store_is_category_testimonial_active( $control ) {
        $type = $control->manager->get_setting( 'catch_store_testimonial_type' )->value();

        //return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
        return ( catch_store_is_testimonial_active( $control ) && 'category' === $type );
    }
endif;

if ( ! function_exists( 'catch_store_is_post_page_category_cpt_testimonial_active' ) ) :
    /**
    * Return true if demo and image page is not active
    *
    * @since Catch Store Pro 1.0
    */
    function catch_store_is_post_page_category_cpt_testimonial_active( $control ) {
        $type = $control->manager->get_setting( 'catch_store_testimonial_type' )->value();

        //return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
        return ( catch_store_is_testimonial_active( $control ) && ( 'demo' !== $type && 'image' !== $type  ) );
    }
endif;

if ( ! function_exists( 'catch_store_is_demo_cpt_testimonial_inactive' ) ) :
    /**
    * Return true if demo and image page is not active
    *
    * @since Catch Store Pro 1.0
    */
    function catch_store_is_demo_cpt_testimonial_inactive( $control ) {
        $type = $control->manager->get_setting( 'catch_store_testimonial_type' )->value();

        //return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
        return ( catch_store_is_testimonial_active( $control ) && ( 'demo' !== $type && 'jetpack-testimonial' !== $type  ) );
    }
endif;

if ( ! function_exists( 'catch_store_is_image_testimonial_active' ) ) :
    /**
    * Return true if page content is active
    *
    * @since Catch Store Pro 1.0
    */
    function catch_store_is_image_testimonial_active( $control ) {
        $type = $control->manager->get_setting( 'catch_store_testimonial_type' )->value();

        //return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
        return ( catch_store_is_testimonial_active( $control ) && 'image' === $type );
    }
endif;
