<?php
/**
 * Theme Options
 *
 * @package Catch_Store
 */

/**
 * Add theme options
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function catch_store_theme_options( $wp_customize ) {
	$wp_customize->add_panel( 'catch_store_theme_options', array(
		'title'    => esc_html__( 'Theme Options', 'catch-store-pro' ),
		'priority' => 130,
	) );

	// Breadcrumb Option.
	$wp_customize->add_section( 'catch_store_breadcrumb_options', array(
		'description'   => esc_html__( 'Breadcrumbs are a great way of letting your visitors find out where they are on your site with just a glance.', 'catch-store-pro' ),
		'panel'         => 'catch_store_theme_options',
		'title'         => esc_html__( 'Breadcrumb', 'catch-store-pro' ),
	) );

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_breadcrumb_option',
			'default'           => 1,
			'sanitize_callback' => 'catch_store_sanitize_checkbox',
			'label'             => esc_html__( 'Check to enable Breadcrumb', 'catch-store-pro' ),
			'section'           => 'catch_store_breadcrumb_options',
			'type'              => 'checkbox',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_breadcrumb_on_homepage',
			'sanitize_callback' => 'catch_store_sanitize_checkbox',
			'label'             => esc_html__( 'Check to enable Breadcrumb on Homepage', 'catch-store-pro' ),
			'section'           => 'catch_store_breadcrumb_options',
			'type'              => 'checkbox',
		)
	);

	// Font Family Options.
	$wp_customize->add_section( 'catch_store_font_family', array(
		'panel' => 'catch_store_theme_options',
		'title' => esc_html__( 'Font Family Options', 'catch-store-pro' ),
	) );

	$avaliable_fonts = catch_store_avaliable_fonts();

	$choices = array();

	foreach ( $avaliable_fonts as $font ) {
		$choices[ $font['value'] ] = str_replace( '"', '', $font['label'] );
	}

	$font_family_options = catch_store_font_family_options();

	foreach ( $font_family_options as $key => $value ) {
		catch_store_register_option( $wp_customize, array(
				'name'              => $key,
				'default'           => $value['default'],
				'sanitize_callback' => 'catch_store_sanitize_select',
				'choices'           => $choices,
				'label'             => $value['label'],
				'section'           => 'catch_store_font_family',
				'type'              => 'select',
			)
		);
	}

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_footer_text_align',
			'default'           => 'left-align',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'label'             => esc_html__( 'Footer Text Alignment', 'catch-store-pro' ),
			'section'           => 'catch_store_footer_editor_options',
			'type'              => 'radio',
			'choices'           => array(
				'left-align' 	=> esc_html__( 'Left Align', 'catch-store-pro' ),
				'right-align' 	=> esc_html__( 'Right Align', 'catch-store-pro' ),
				'center-align' 	=> esc_html__( 'Center Align', 'catch-store-pro' ),
			),
		)
	);	

	// Footer Editor Options.
	$wp_customize->add_section( 'catch_store_footer_editor_options', array(
		'title'       => esc_html__( 'Footer Editor Options', 'catch-store-pro' ),
		'description' => esc_html__( 'You can either add html or plain text or custom shortcodes, which will be automatically inserted into your theme. Some shorcodes: [the-year], [site-link] and [privacy-policy-link] for current year, site link and privacy policy link respectively.', 'catch-store-pro' ),
		'panel'       => 'catch_store_theme_options',
	) );

	$theme_data = wp_get_theme();

	$def_footer_text = sprintf( _x( 'Copyright &copy; %1$s %2$s. All Rights Reserved. %3$s ', '1: Year, 2: Site Title with home URL, 3: Privacy Policy Link', 'catch-store-pro' ), '[the-year]', '[site-link]', '[privacy-policy-link]'. '<span class="sep"> | </span>' . $theme_data->get( 'Name' ) . '&nbsp;' . esc_html__( 'by', 'catch-store-pro' ) . '&nbsp;<a target="_blank" href="' . $theme_data->get( 'AuthorURI' ) . '">' . esc_html( $theme_data->get( 'Author' ) ) . '</a>' );

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_footer_content',
			'default'           => $def_footer_text,
			'sanitize_callback' => 'wp_kses_post',
			'description'       => esc_html__( 'You can add custom shortcodes, which will be automatically inserted into your theme. Some shorcodes: [the-year], [site-link] and [privacy-policy-link] for current year, site link and privacy policy link respectively.', 'catch-store-pro' ),
			'label'             => esc_html__( 'Footer content', 'catch-store-pro' ),
			'section'           => 'catch_store_footer_editor_options',
			'type'              => 'textarea',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_latest_posts_title',
			'default'           => esc_html__( 'News', 'catch-store-pro' ),
			'sanitize_callback' => 'wp_kses_post',
			'label'             => esc_html__( 'Latest Posts Title', 'catch-store-pro' ),
			'section'           => 'catch_store_theme_options',
		)
	);

	// Layout Options
	$wp_customize->add_section( 'catch_store_layout_options', array(
		'title' => esc_html__( 'Layout Options', 'catch-store-pro' ),
		'panel' => 'catch_store_theme_options',
		)
	);

	/* Layout Type */
	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_layout_type',
			'default'           => 'fluid',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'label'             => esc_html__( 'Site Layout', 'catch-store-pro' ),
			'section'           => 'catch_store_layout_options',
			'type'              => 'radio',
			'choices'           => array(
				'fluid' => esc_html__( 'Fluid', 'catch-store-pro' ),
				'boxed' => esc_html__( 'Boxed', 'catch-store-pro' ),
			),
		)
	);

	/* Default Layout */
	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_default_layout',
			'default'           => 'right-sidebar',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'label'             => esc_html__( 'Default Layout', 'catch-store-pro' ),
			'section'           => 'catch_store_layout_options',
			'type'              => 'radio',
			'choices'           => array(
				'right-sidebar'         => esc_html__( 'Right Sidebar ( Content, Primary Sidebar )', 'catch-store-pro' ),
				'left-sidebar'          => esc_html__( 'Left Sidebar ( Primary Sidebar, Content )', 'catch-store-pro' ),
				'no-sidebar'            => esc_html__( 'No Sidebar', 'catch-store-pro' ),
				'no-sidebar-full-width' => esc_html__( 'No Sidebar: Full Width', 'catch-store-pro' ),
			),
		)
	);

	/* Homepage/Archive Layout */
	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_homepage_archive_layout',
			'default'           => 'right-sidebar',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'label'             => esc_html__( 'Homepage/Archive Layout', 'catch-store-pro' ),
			'section'           => 'catch_store_layout_options',
			'type'              => 'radio',
			'choices'           => array(
				'right-sidebar'         => esc_html__( 'Right Sidebar ( Content, Primary Sidebar )', 'catch-store-pro' ),
				'left-sidebar'          => esc_html__( 'Left Sidebar ( Primary Sidebar, Content )', 'catch-store-pro' ),
				'no-sidebar'            => esc_html__( 'No Sidebar', 'catch-store-pro' ),
				'no-sidebar-full-width' => esc_html__( 'No Sidebar: Full Width', 'catch-store-pro' ),
			),
		)
	);

	/* Single Page/Post Image Layout */
	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_single_layout',
			'default'           => 'disabled',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'label'             => esc_html__( 'Single Page/Post Image Layout', 'catch-store-pro' ),
			'section'           => 'catch_store_layout_options',
			'type'              => 'radio',
			'choices'           => array(
				'disabled'              => esc_html__( 'Disabled', 'catch-store-pro' ),
				'post-thumbnail'        => esc_html__( 'Post Thumbnail', 'catch-store-pro' ),
				'catch-store-slider' => esc_html__( 'Slider Image Size (1920x822)', 'catch-store-pro' ),
				'full'                  => esc_html__( 'Original Image Size', 'catch-store-pro' ),
			),
		)
	);

	// Excerpt Options.
	$wp_customize->add_section( 'catch_store_excerpt_options', array(
		'panel'     => 'catch_store_theme_options',
		'title'     => esc_html__( 'Excerpt Options', 'catch-store-pro' ),
	) );

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_excerpt_length',
			'default'           => '20',
			'sanitize_callback' => 'absint',
			'description' => esc_html__( 'Excerpt length. Default is 20 words', 'catch-store-pro' ),
			'input_attrs' => array(
				'min'   => 10,
				'max'   => 200,
				'step'  => 5,
				'style' => 'width: 60px;',
			),
			'label'    => esc_html__( 'Excerpt Length (words)', 'catch-store-pro' ),
			'section'  => 'catch_store_excerpt_options',
			'type'     => 'number',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_excerpt_more_text',
			'default'           => esc_html__( 'Continue Reading', 'catch-store-pro' ),
			'sanitize_callback' => 'sanitize_text_field',
			'label'             => esc_html__( 'Read More Text', 'catch-store-pro' ),
			'section'           => 'catch_store_excerpt_options',
			'type'              => 'text',
		)
	);

	// Excerpt Options.
	$wp_customize->add_section( 'catch_store_search_options', array(
		'panel'     => 'catch_store_theme_options',
		'title'     => esc_html__( 'Search Options', 'catch-store-pro' ),
	) );

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_search_text',
			'default'           => esc_html__( 'Search', 'catch-store-pro' ),
			'sanitize_callback' => 'sanitize_text_field',
			'label'             => esc_html__( 'Search Text', 'catch-store-pro' ),
			'section'           => 'catch_store_search_options',
			'type'              => 'text',
		)
	);

	// Comment Option.
	$wp_customize->add_section( 'catch_store_comment_option', array(
		'description'   => esc_html__( 'Comments can also be disabled on a per post/page basis when creating/editing posts/pages.', 'catch-store-pro' ),
		'panel'         => 'catch_store_theme_options',
		'title'         => esc_html__( 'Comment Options', 'catch-store-pro' ),
	) );

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_comment_option',
			'default'           => 'use-wordpress-setting',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'choices'           => catch_store_comment_options(),
			'label'             => __( 'Comment Option', 'catch-store-pro' ),
			'section'           => 'catch_store_comment_option',
			'type'              => 'select',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_website_field',
			'sanitize_callback' => 'catch_store_sanitize_checkbox',
			'label'             => esc_html__( 'Check to Disable Website Field', 'catch-store-pro' ),
			'section'           => 'catch_store_comment_option',
			'type'              => 'checkbox',
		)
	);

	// Header Top Options
	$wp_customize->add_section( 'catch_store_header_top', array(
		'panel'       => 'catch_store_theme_options',
		'title'       => esc_html__( 'Header Top Options', 'catch-store-pro' ),
	) );

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_disable_header_top',
			'sanitize_callback' => 'catch_store_sanitize_checkbox',
			'label'             => esc_html__( 'Disable Header Top', 'catch-store-pro' ),
			'section'           => 'catch_store_header_top',
			'type'              => 'checkbox',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_enable_header_search',
			'sanitize_callback' => 'catch_store_sanitize_checkbox',
			'active_callback'   => 'catch_store_is_header_top_enabled',
			'label'             => esc_html__( 'Enable Search', 'catch-store-pro' ),
			'section'           => 'catch_store_header_top',
			'type'              => 'checkbox',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_enable_date',
			'sanitize_callback' => 'catch_store_sanitize_checkbox',
			'active_callback'   => 'catch_store_is_header_top_enabled',
			'label'             => esc_html__( 'Enable Date', 'catch-store-pro' ),
			'section'           => 'catch_store_header_top',
			'type'              => 'checkbox',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_email',
			'sanitize_callback' => 'sanitize_email',
			'active_callback'   => 'catch_store_is_header_top_enabled',
			'label'             => esc_html__( 'Email', 'catch-store-pro' ),
			'section'           => 'catch_store_header_top',
			'type'              => 'text',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_phone',
			'sanitize_callback' => 'sanitize_text_field',
			'active_callback'   => 'catch_store_is_header_top_enabled',
			'label'             => esc_html__( 'Phone', 'catch-store-pro' ),
			'section'           => 'catch_store_header_top',
			'type'              => 'text',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_address',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'catch_store_is_header_top_enabled',
			'label'             => esc_html__( 'Address', 'catch-store-pro' ),
			'section'           => 'catch_store_header_top',
			'type'              => 'text',
		)
	);

	// Homepage / Frontpage Options.
	$wp_customize->add_section( 'catch_store_homepage_options', array(
		'description' => esc_html__( 'Only posts that belong to the categories selected here will be displayed on the front page', 'catch-store-pro' ),
		'panel'       => 'catch_store_theme_options',
		'title'       => esc_html__( 'Homepage / Frontpage Options', 'catch-store-pro' ),
	) );

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_disable_homepage_posts',
			'sanitize_callback' => 'catch_store_sanitize_checkbox',
			'label'             => esc_html__( 'Check to disable Recent Posts/Content on homepage', 'catch-store-pro' ),
			'section'           => 'catch_store_homepage_options',
			'type'              => 'checkbox',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_front_page_category',
			'sanitize_callback' => 'catch_store_sanitize_category_list',
			'custom_control'    => 'catch_store_Multi_Categories_Control',
			'active_callback'   => 'catch_store_is_homepage_posts_enabled',
			'label'             => esc_html__( 'Categories', 'catch-store-pro' ),
			'section'           => 'catch_store_homepage_options',
			'type'              => 'dropdown-categories',
		)
	);

	// Disable Recent post in static frontpage
    catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_enable_static_page_posts',
			'sanitize_callback' => 'catch_store_sanitize_checkbox',
			'label'             => esc_html__( 'Check to Enable Recent Posts on Static Page', 'catch-store-pro' ),
			'section'           => 'catch_store_homepage_options',
			'type'              => 'checkbox',
    	)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_recent_posts_heading',
			'sanitize_callback' => 'sanitize_text_field',
			'active_callback'   => 'catch_store_is_recent_posts_on_static_page_enabled',
			'default'           => esc_html__( 'Blog', 'catch-store-pro' ),
			'label'             => esc_html__( 'Recent Posts Heading', 'catch-store-pro' ),
			'section'           => 'catch_store_homepage_options',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_recent_posts_subheading',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'catch_store_is_recent_posts_on_static_page_enabled',
			'label'             => esc_html__( 'Recent Posts Sub Heading', 'catch-store-pro' ),
			'section'           => 'catch_store_homepage_options',
			'type'              => 'textarea'
		)
	);

	//Menu Options
	$wp_customize->add_section( 'catch_store_menu_options', array(
		'description' => esc_html__( 'Extra Menu Options specific to this theme', 'catch-store-pro' ),
		'title'       => esc_html__( 'Menu Options', 'catch-store-pro' ),
		'panel'       => 'catch_store_theme_options',
	) );

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_primary_menu_disable',
			'default'           => 0,
			'sanitize_callback' => 'catch_store_sanitize_checkbox',
			'label'             => esc_html__( 'Check to disable Primary Menu', 'catch-store-pro' ),
			'section'           => 'catch_store_menu_options',
			'type'              => 'checkbox',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_header_right_search_disable',
			'default'           => 0,
			'sanitize_callback' => 'catch_store_sanitize_checkbox',
			'label'             => esc_html__( 'Check to disable search in Header Right Menu', 'catch-store-pro' ),
			'section'           => 'catch_store_menu_options',
			'type'              => 'checkbox',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_header_right_cart_disable',
			'default'           => 0,
			'sanitize_callback' => 'catch_store_sanitize_checkbox',
			'label'             => esc_html__( 'Check to disable Cart in Header Right Menu', 'catch-store-pro' ),
			'section'           => 'catch_store_menu_options',
			'type'              => 'checkbox',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_primary_menu_search_disable',
			'default'           => 0,
			'sanitize_callback' => 'catch_store_sanitize_checkbox',
			'label'             => esc_html__( 'Check to disable search Icon in Primary Menu', 'catch-store-pro' ),
			'section'           => 'catch_store_menu_options',
			'type'              => 'checkbox',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_primary_menu_cart_disable',
			'default'           => 0,
			'sanitize_callback' => 'catch_store_sanitize_checkbox',
			'label'             => esc_html__( 'Check to disable cart Icon in Primary Menu', 'catch-store-pro' ),
			'section'           => 'catch_store_menu_options',
			'type'              => 'checkbox',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_primary_menu_my_account_disable',
			'default'           => 0,
			'sanitize_callback' => 'catch_store_sanitize_checkbox',
			'label'             => esc_html__( 'Check to disable My Account Icon in Primary Menu', 'catch-store-pro' ),
			'section'           => 'catch_store_menu_options',
			'type'              => 'checkbox',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_header_top_menu_label',
			'default'           => esc_html__( 'Top Bar', 'catch-store-pro' ),
			'sanitize_callback' => 'sanitize_text_field',
			'active_callback'   => 'catch_store_is_header_top_enabled',
			'label'             => esc_html__( 'Header Top Mobile Menu Label', 'catch-store-pro' ),
			'section'           => 'catch_store_menu_options',
			'type'              => 'text',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_header_right_menu_label',
			'default'           => esc_html__( 'Menu', 'catch-store-pro' ),
			'sanitize_callback' => 'sanitize_text_field',
			'label'             => esc_html__( 'Header Right Mobile Menu Label', 'catch-store-pro' ),
			'section'           => 'catch_store_menu_options',
			'type'              => 'text',
		)
	);

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_primary_menu_label',
			'default'           => esc_html__( 'Menu', 'catch-store-pro' ),
			'sanitize_callback' => 'sanitize_text_field',
			'label'             => esc_html__( 'Primary Mobile Menu Label', 'catch-store-pro' ),
			'section'           => 'catch_store_menu_options',
			'type'              => 'text',
		)
	);

	//Menu Options End

	// Pagination Options.
	$pagination_type = get_theme_mod( 'catch_store_pagination_type', 'default' );

	$nav_desc = '';

	/**
	* Check if navigation type is Jetpack Infinite Scroll and if it is enabled
	*/
	$nav_desc = sprintf(
		wp_kses(
			__( 'For infinite scrolling, use %1$sCatch Infinite Scroll Plugin%2$s with Infinite Scroll module Enabled.', 'catch-store-pro' ),
			array(
				'a' => array(
					'href' => array(),
					'target' => array(),
				),
				'br'=> array()
			)
		),
		'<a target="_blank" href="https://wordpress.org/plugins/catch-infinite-scroll/">',
		'</a>'
	);

	$wp_customize->add_section( 'catch_store_pagination_options', array(
		'description' => $nav_desc,
		'panel'       => 'catch_store_theme_options',
		'title'       => esc_html__( 'Pagination Options', 'catch-store-pro' ),
	) );

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_pagination_type',
			'default'           => 'default',
			'sanitize_callback' => 'catch_store_sanitize_select',
			'choices'           => catch_store_get_pagination_types(),
			'label'             => esc_html__( 'Pagination type', 'catch-store-pro' ),
			'section'           => 'catch_store_pagination_options',
			'type'              => 'select',
		)
	);

	// For WooCommerce layout: catch_store_woocommerce_layout, check woocommerce-options.php.
	/* Scrollup Options */
	$wp_customize->add_section( 'catch_store_scrollup', array(
		'panel'    => 'catch_store_theme_options',
		'title'    => esc_html__( 'Scrollup Options', 'catch-store-pro' ),
	) );

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_disable_scrollup',
			'sanitize_callback' => 'catch_store_sanitize_checkbox',
			'label'             => esc_html__( 'Disable Scroll Up', 'catch-store-pro' ),
			'section'           => 'catch_store_scrollup',
			'type'              => 'checkbox',
		)
	);

	// Update Notifier.
	$wp_customize->add_section( 'catch_store_update_notifier', array(
		'title'    => esc_html__( 'Update Notifier', 'catch-store-pro' ),
		'panel'    => 'catch_store_theme_options',
	) );

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_update_notifier',
			'sanitize_callback' => 'catch_store_sanitize_checkbox',
			'label'             => esc_html__( 'Check to disable update notifications', 'catch-store-pro' ),
			'section'           => 'catch_store_update_notifier',
			'type'              => 'checkbox',
		)
	);

	// Section Sorter
	$wp_customize->add_section( 'catch_store_sections_sort', array(
		'title'       => esc_html__( 'Sections Sorter', 'catch-store-pro' ),
		'description' => esc_html__( 'Drag and drop to sort your sections', 'catch-store-pro' ),
		'panel'       => 'catch_store_theme_options',
	) );

	catch_store_register_option( $wp_customize, array(
			'name'              => 'catch_store_sections_sort',
			'default'           => catch_store_get_default_sections_value(),
			'label'             => esc_html__( 'Sortable Sections', 'catch-store-pro' ),
			'custom_control'    => 'catch_store_Sortable_Custom_Control',
			'sanitize_callback' => 'sanitize_text_field',
			'section'           => 'catch_store_sections_sort',
			'type'              => 'custom-sortable',
		)
	);
}
add_action( 'customize_register', 'catch_store_theme_options' );

/**
 * Returns an array of avaliable fonts registered for Catch Store
 *
 * @since Catch Store Pro 1.0
 */
function catch_store_avaliable_fonts() {
	$avaliable_fonts = array(
		'arial-black' => array(
			'value' => 'arial-black',
			'label' => '"Arial Black", Gadget, sans-serif',
		),
		'allan' => array(
			'value' => 'allan',
			'label' => '"Allan", sans-serif',
		),
		'allerta' => array(
			'value' => 'allerta',
			'label' => '"Allerta", sans-serif',
		),
		'amaranth' => array(
			'value' => 'amaranth',
			'label' => '"Amaranth", sans-serif',
		),
		'amatic-sc' => array(
			'value' => 'amatic-sc',
			'label' => '"Amatic SC", cursive',
		),
		'arial' => array(
			'value' => 'arial',
			'label' => 'Arial, Helvetica, sans-serif',
		),
		'bitter' => array(
			'value' => 'bitter',
			'label' => '"Bitter", sans-serif',
		),
		'cabin' => array(
			'value' => 'cabin',
			'label' => '"Cabin", sans-serif',
		),
		'cantarell' => array(
			'value' => 'cantarell',
			'label' => '"Cantarell", sans-serif',
		),
		'century-gothic' => array(
			'value' => 'century-gothic',
			'label' => '"Century Gothic", sans-serif',
		),
		'courier-new' => array(
			'value' => 'courier-new',
			'label' => '"Courier New", Courier, monospace',
		),
		'crimson-text' => array(
			'value' => 'crimson-text',
			'label' => '"Crimson Text", sans-serif',
		),
		'cuprum' => array(
			'value' => 'cuprum',
			'label' => '"Cuprum", sans-serif',
		),
		'dancing-script' => array(
			'value' => 'dancing-script',
			'label' => '"Dancing Script", sans-serif',
		),
		'droid-sans' => array(
			'value' => 'droid-sans',
			'label' => '"Droid Sans", sans-serif',
		),
		'droid-serif' => array(
			'value' => 'droid-serif',
			'label' => '"Droid Serif", sans-serif',
		),
		'exo' => array(
			'value' => 'exo',
			'label' => '"Exo", sans-serif',
		),
		'exo-2' => array(
			'value' => 'exo-2',
			'label' => '"Exo 2", sans-serif',
		),
		'georgia' => array(
			'value' => 'georgia',
			'label' => 'Georgia, "Times New Roman", Times, serif',
		),
		'helvetica' => array(
			'value' => 'helvetica',
			'label' => 'Helvetica, "Helvetica Neue", Arial, sans-serif',
		),
		'helvetica-neue' => array(
			'value' => 'helvetica-neue',
			'label' => '"Helvetica Neue", Helvetica, Arial,sans-serif',
		),
		'istok-web' => array(
			'value' => 'istok-web',
			'label' => '"Istok Web", sans-serif',
		),
		'impact' => array(
			'value' => 'impact',
			'label' => 'Impact, Charcoal, sans-serif',
		),
		'josefin-sans' => array(
			'value' => 'josefin-sans',
			'label' => '"Josefin Sans", sans-serif',
		),
		'lato' => array(
			'value' => 'lato',
			'label' => '"Lato", sans-serif',
		),
		'lucida-sans-unicode' => array(
			'value' => 'lucida-sans-unicode',
			'label' => '"Lucida Sans Unicode", "Lucida Grande", sans-serif',
		),
		'lucida-grande' => array(
			'value' => 'lucida-grande',
			'label' => '"Lucida Grande", "Lucida Sans Unicode", sans-serif',
		),
		'lobster' => array(
			'value' => 'lobster',
			'label' => '"Lobster", sans-serif',
		),
		'lora' => array(
			'value' => 'lora',
			'label' => '"Lora", serif',
		),
		'monaco' => array(
			'value' => 'monaco',
			'label' => 'Monaco, Consolas, "Lucida Console", monospace, sans-serif',
		),
		'montserrat' => array(
			'value' => 'montserrat',
			'label' => '"Montserrat", sans-serif',
		),
		'nobile' => array(
			'value' => 'nobile',
			'label' => '"Nobile", sans-serif',
		),
		'noto-serif' => array(
			'value' => 'noto-serif',
			'label' => '"Noto Serif", serif',
		),
		'neuton' => array(
			'value' => 'neuton',
			'label' => '"Neuton", serif',
		),
		'open-sans' => array(
			'value' => 'open-sans',
			'label' => '"Open Sans", sans-serif',
		),
		'oswald' => array(
			'value' => 'oswald',
			'label' => '"Oswald", sans-serif',
		),
		'palatino' => array(
			'value' => 'palatino',
			'label' => 'Palatino, "Palatino Linotype", "Book Antiqua", serif',
		),
		'patua-one' => array(
			'value' => 'patua-one',
			'label' => '"Patua One", sans-serif',
		),
		'playfair-display' => array(
			'value' => 'playfair-display',
			'label' => '"Playfair Display", sans-serif',
		),
		'pt-sans' => array(
			'value' => 'pt-sans',
			'label' => '"PT Sans", sans-serif',
		),
		'pt-serif' => array(
			'value' => 'pt-serif',
			'label' => '"PT Serif", serif',
		),
		'quattrocento-sans' => array(
			'value' => 'quattrocento-sans',
			'label' => '"Quattrocento Sans", sans-serif',
		),
		'roboto' => array(
			'value' => 'roboto',
			'label' => '"Roboto", sans-serif',
		),
		'roboto-slab' => array(
			'value' => 'roboto-slab',
			'label' => '"Roboto Slab", serif',
		),
		'rubik' => array(
			'value' => 'rubik',
			'label' => '"Rubik", serif',
		),
		'sans-serif' => array(
			'value' => 'sans-serif',
			'label' => 'Sans Serif, Arial',
		),
		'source-sans-pro' => array(
			'value' => 'source-sans-pro',
			'label' => '"Source Sans Pro", sans-serif',
		),
		'tahoma' => array(
			'value' => 'tahoma',
			'label' => 'Tahoma, Geneva, sans-serif',
		),
		'trebuchet-ms' => array(
			'value' => 'trebuchet-ms',
			'label' => '"Trebuchet MS", "Helvetica", sans-serif',
		),
		'times-new-roman' => array(
			'value' => 'times-new-roman',
			'label' => '"Times New Roman", Times, serif',
		),
		'ubuntu' => array(
			'value' => 'ubuntu',
			'label' => '"Ubuntu", sans-serif',
		),
		'varela' => array(
			'value' => 'varela',
			'label' => '"Varela", sans-serif',
		),
		'verdana' => array(
			'value' => 'verdana',
			'label' => 'Verdana, Geneva, sans-serif',
		),
		'yanone-kaffeesatz' => array(
			'value' => 'yanone-kaffeesatz',
			'label' => '"Yanone Kaffeesatz", sans-serif',
		),
	);

	return apply_filters( 'catch_store_avaliable_fonts', $avaliable_fonts );
}


/**
 * Returns an array of font family options
 *
 * @since Catch Store Pro 1.0
 */
function catch_store_font_family_options() {
	$options = array(
		'catch_store_body_font'         => array(
			'label'    => esc_html__( 'Default Font Family', 'catch-store-pro' ),
			'default'  => 'montserrat',
			'selector' => 'body, button, input, select, textarea',
		),
		'catch_store_title_font'        => array(
			'label'    => esc_html__( 'Site Title Font Family', 'catch-store-pro' ),
			'default'  => 'montserrat',
			'selector' => '.site-title',
		),
		'catch_store_tagline_font'      => array(
			'label'    => esc_html__( 'Site Tagline Font Family', 'catch-store-pro' ),
			'default'  => 'montserrat',
			'selector' => '.site-description',
		),
		'catch_store_headings_font'     => array(
			'label' => esc_html__( 'Headings Tags from h1 to h6 Font Family', 'catch-store-pro' ),
			'default' => 'montserrat',
			'selector' => 'h1, h2, h3, h4, h5, h6',
		),
		'catch_store_content_title_font' => array(
			'label'    => esc_html__( 'Content Title Font Family', 'catch-store-pro' ),
			'default'  => 'montserrat',
			'selector' => '.page-title, #main .entry-title, #main .entry-subtitle',
		),
		'catch_store_content_font'       => array(
			'label'    => esc_html__( 'Content Body Font Family', 'catch-store-pro' ),
			'default'  => 'montserrat',
			'selector' => '#main .entry-content, #main .entry-summary',
		),
	);

	return apply_filters( 'catch_store_font_family_options', $options );
}

/** Active Callback Functions */

if( ! function_exists( 'catch_store_is_homepage_posts_enabled' ) ) :
	/**
	* Return true if hommepage posts/content is enabled
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_homepage_posts_enabled( $control ) {
		return ( ! $control->manager->get_setting( 'catch_store_disable_homepage_posts' )->value() );
	}
endif;

if( ! function_exists( 'catch_store_is_header_top_enabled' ) ) :
	/**
	* Return true if header top is enabled
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_header_top_enabled( $control ) {
		return ( ! $control->manager->get_setting( 'catch_store_disable_header_top' )->value() );
	}
endif;

if( ! function_exists( 'catch_store_is_recent_posts_on_static_page_enabled' ) ) :
	/**
	* Return true if recent posts on static page enabled
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_recent_posts_on_static_page_enabled( $control ) {

		$enable_static_page_posts = $control->manager->get_setting( 'catch_store_enable_static_page_posts' )->value();

		$is_home_and_blog = is_home() && is_front_page();
		return ( $is_home_and_blog || $enable_static_page_posts );
	}
endif;

if( ! function_exists( 'catch_store_is_header_right_menu_social_enabled' ) ) :
	/**
	* Return true if header right or social menu is enabled
	*
	* @since Catch Store Pro 1.0
	*/
	function catch_store_is_header_right_menu_social_enabled( $control ) {
		return ( has_nav_menu( 'menu-2' ) || has_nav_menu( 'social-header-right' ) );
	}
endif;
