<?php
/**
 * Adding support for WooCommerce Plugin
 */

if ( ! class_exists( 'WooCommerce' ) ) {
    // Bail if WooCommerce is not installed
    return;
}


if ( ! function_exists( 'catch_store_woocommerce_setup' ) ) :
    /**
     * Sets up support for various WooCommerce features.
     */
    function catch_store_woocommerce_setup() {
        add_theme_support( 'woocommerce', array(
            'thumbnail_image_width'  => 640,
            'thumbnail_image_height' => 800,
        ) );

        if ( ! get_theme_mod( 'catch_store_product_gallery_zoom' ) ) {
            add_theme_support('wc-product-gallery-zoom');
        }

        if ( ! get_theme_mod( 'catch_store_product_gallery_lightbox' ) ) {
            add_theme_support('wc-product-gallery-lightbox');
        }

        if ( ! get_theme_mod( 'catch_store_product_gallery_slider' ) ) {
            add_theme_support('wc-product-gallery-slider');
        }
    }
endif; //catch-catch_store_woocommerce_setup
add_action( 'after_setup_theme', 'catch_store_woocommerce_setup' );


/**
 * Add WooCommerce Options to customizer
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function catch_store_woocommerce_options( $wp_customize ) {
    catch_store_register_option( $wp_customize, array(
            'name'              => 'catch_store_woocommerce_layout',
            'default'           => 'no-sidebar-full-width',
            'sanitize_callback' => 'catch_store_sanitize_select',
            'description'       => esc_html__( 'Layout for WooCommerce Pages', 'catch-store-pro' ),
            'label'             => esc_html__( 'WooCommerce Layout', 'catch-store-pro' ),
            'section'           => 'catch_store_layout_options',
            'type'              => 'radio',
            'choices'           => array(
                'right-sidebar'         => esc_html__( 'Right Sidebar ( Content, Primary Sidebar )', 'catch-store-pro' ),
                'left-sidebar'          => esc_html__( 'Left Sidebar ( Primary Sidebar, Content )', 'catch-store-pro' ),
                'no-sidebar'            => esc_html__( 'No Sidebar', 'catch-store-pro' ),
                'no-sidebar-full-width' => esc_html__( 'No Sidebar: Full Width', 'catch-store-pro' ),
            ),
        )
    );

    // WooCommerce Options
    $wp_customize->add_section( 'catch_store_woocommerce_options', array(
        'title'       => esc_html__( 'WooCommerce Options', 'catch-store-pro' ),
        'panel'       => 'catch_store_theme_options',
        'description' => esc_html__( 'Since these options are added via theme support, you will need to save and refresh the customizer to view the full effect.', 'catch-store-pro' ),
    ) );

    catch_store_register_option( $wp_customize, array(
            'name'              => 'catch_store_product_gallery_zoom',
            'sanitize_callback' => 'catch_store_sanitize_checkbox',
            'label'             => esc_html__( 'Check to disable Product Gallery Zoom', 'catch-store-pro' ),
            'section'           => 'catch_store_woocommerce_options',
            'type'              => 'checkbox',
        )
    );

    catch_store_register_option( $wp_customize, array(
            'name'              => 'catch_store_product_gallery_lightbox',
            'sanitize_callback' => 'catch_store_sanitize_checkbox',
            'label'             => esc_html__( 'Check to disable Product Gallery Lightbox', 'catch-store-pro' ),
            'section'           => 'catch_store_woocommerce_options',
            'type'              => 'checkbox',
        )
    );

    catch_store_register_option( $wp_customize, array(
            'name'              => 'catch_store_product_gallery_slider',
            'sanitize_callback' => 'catch_store_sanitize_checkbox',
            'label'             => esc_html__( 'Check to disable Product Gallery Slider', 'catch-store-pro' ),
            'section'           => 'catch_store_woocommerce_options',
            'type'              => 'checkbox',
        )
    );

        // WooCommerce Excerpt Options.
    catch_store_register_option( $wp_customize, array(
            'name'              => 'catch_store_woo_excerpt_length',
            'default'           => '10',
            'sanitize_callback' => 'absint',
            'input_attrs' => array(
                'min'   => 5,
                'max'   => 200,
                'step'  => 5,
                'style' => 'width: 60px;',
            ),
            'label'    => esc_html__( 'WooCommerce Product Excerpt Length (words)', 'catch-store-pro' ),
            'section'  => 'catch_store_excerpt_options',
            'type'     => 'number',
        )
    );

    catch_store_register_option( $wp_customize, array(
            'name'              => 'catch_store_woo_excerpt_more_text',
            'default'           => esc_html__( 'Buy Now', 'catch-store-pro' ),
            'sanitize_callback' => 'sanitize_text_field',
            'label'             => esc_html__( 'WooCommerce Product Read More Text', 'catch-store-pro' ),
            'section'           => 'catch_store_excerpt_options',
            'type'              => 'text',
        )
    );
}
add_action( 'customize_register', 'catch_store_woocommerce_options' );


/**
 * uses remove_action to remove the WooCommerce Wrapper and add_action to add Main Wrapper
 */
remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10 );
remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10 );


if ( ! function_exists( 'catch_store_woocommerce_start' ) ) :
    function catch_store_woocommerce_start() {
    	echo '<div id="primary" class="content-area"><main role="main" class="site-main woocommerce" id="main"><div class="woocommerce-posts-wrapper">';
    }
endif; //catch-catch_store_woocommerce_start
add_action( 'woocommerce_before_main_content', 'catch_store_woocommerce_start', 15 );


if ( ! function_exists( 'catch_store_woocommerce_end' ) ) :
    function catch_store_woocommerce_end() {
    	echo '</div><!-- .woocommerce-posts-wrapper --></main><!-- #main --></div><!-- #primary -->';
    }
endif; //catch-catch_store_woocommerce_end
add_action( 'woocommerce_after_main_content', 'catch_store_woocommerce_end', 15 );


function catch_store_woocommerce_shorting_start() {
	echo '<div class="woocommerce-shorting-wrapper">';
}
add_action( 'woocommerce_before_shop_loop', 'catch_store_woocommerce_shorting_start', 10 );


function catch_store_woocommerce_shorting_end() {
	echo '</div><!-- .woocommerce-shorting-wrapper -->';
}
add_action( 'woocommerce_before_shop_loop', 'catch_store_woocommerce_shorting_end', 40 );


function catch_store_woocommerce_product_container_start() {
	echo '<div class="product-container">';
}
add_action( 'woocommerce_before_shop_loop_item_title', 'catch_store_woocommerce_product_container_start', 20 );


function catch_store_woocommerce_product_container_end() {
	echo '</div><!-- .product-container -->';
}
add_action( 'woocommerce_after_shop_loop_item', 'catch_store_woocommerce_product_container_end', 20 );

/**
 * Remove breadcrumb from default position
 * Check template-parts/header/breadcrumb.php
 */
function catch_store_remove_wc_breadcrumbs() {
    remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20, 0 );
}
add_action( 'init', 'catch_store_remove_wc_breadcrumbs' );


if ( ! function_exists( 'catch_store_header_cart' ) ) {
    /**
     * Display Header Cart
     *
     * @since  1.0.0
     * @uses  catch_store_catch_store_is_woocommerce_activated() check if WooCommerce is activated
     * @return void
     */
    function catch_store_header_cart() {
        //account class
        if ( is_account_page() ) {
            $accountclass = 'menu-inline current-menu-item';
        } else {
            $accountclass = 'menu-inline';
        }
        //cart class
        if ( is_cart() ) {
            $cartclass = 'menu-inline site-cart current-menu-item';
        } else {
            $cartclass = 'menu-inline site-cart';
        }
        ?>

        <ul id="site-header-cart" class="site-header-cart menu">
        <?php $disable_primary_menu_my_account = get_theme_mod( 'catch_store_primary_menu_my_account_disable', 0 );

            if ( ! $disable_primary_menu_my_account ) : ?>
                <li class="<?php echo esc_attr( $accountclass ); ?>">
                    <?php catch_store_myaccount_icon_link(); ?>
                </li>
             <?php endif; ?>

            <?php $disable_primary_menu_search = get_theme_mod( 'catch_store_primary_menu_search_disable', 0 );

            if ( ! $disable_primary_menu_search ) : ?>
                <li class="menu-inline search-product">
                    <a href="#" id="site-search-toggle" class="menu-search-toggle" title="Click to view Search Form"><span class="screen-reader-text"><?php esc_html_e( 'Search', 'catch-store-pro' ); ?></span><?php echo catch_store_get_svg( array( 'icon' => 'search' ) ); echo catch_store_get_svg( array( 'icon' => 'close' ) ); ?></a>
                    <ul id="site-product-search" class="site-product-search">
                        <li><?php the_widget( 'WC_Widget_Product_Search', 'title=' ); ?></li>
                    </ul>
                </li>
            <?php endif; ?>

            <?php $disable_primary_menu_cart = get_theme_mod( 'catch_store_primary_menu_cart_disable', 0 ); ?>

            <?php if ( ! $disable_primary_menu_cart ) : ?>
                <li class="<?php echo esc_attr( $cartclass ); ?>">
                    <?php catch_store_cart_link(); ?>

                    <ul id="site-cart-contents-items">
                        <?php the_widget( 'WC_Widget_Cart', 'title=' ); ?>
                    </ul>
                </li>
        <?php endif; ?>
        </ul>

        <?php
    }
}

if ( ! function_exists( 'catch_store_myaccount_icon_link' ) ) {
    /**
     * The account callback function
     */
    function catch_store_myaccount_icon_link() {
        echo '<a class="my-account" href="' . esc_url( get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ) ) . '" title="' . esc_attr__( 'Go to My Account', 'catch-store-pro' ) . '"><span class="screen-reader-text">' . esc_attr__( 'My Account', 'catch-store-pro' ) . '</span>' . catch_store_get_svg( array( 'icon' => 'user' ) ) . '</a>';
    }
}

if ( ! function_exists( 'catch_store_cart_link' ) ) {
    /**
     * Cart Link
     * Displayed a link to the cart including the number of items present and the cart total
     *
     * @return void
     * @since  1.0.0
     */
    function catch_store_cart_link() {
        ?>
            <a class="site-cart-contents" href="<?php echo esc_url( wc_get_cart_url() ); ?>" title="<?php esc_attr_e( 'View your shopping cart', 'catch-store-pro' ); ?>">
                <?php echo catch_store_get_svg( array( 'icon' => 'shopping-bag', 'title' => esc_html__( 'View your shopping cart', 'catch-store-pro' ) ) ); ?>
                <?php /* translators: number of items in the mini cart. */ ?>
                <span class="count"><?php echo wp_kses_data( sprintf( _n( '%d item', '%d items', WC()->cart->get_cart_contents_count(), 'catch-store-pro' ), WC()->cart->get_cart_contents_count() ) );?></span><span class="sep"> / </span><span class="amount"><?php echo wp_kses_data( WC()->cart->get_cart_subtotal() ); ?></span>
            </a>
        <?php
    }
}

/**
 * Disable the default WooCommerce stylesheet.
 *
 * Removing the default WooCommerce stylesheet and enqueing your own will
 * protect you during WooCommerce core updates.
 *
 * @link https://docs.woocommerce.com/document/disable-the-default-stylesheet/
 */
add_filter( 'woocommerce_enqueue_styles', '__return_empty_array' );

/**
 * Add 'woocommerce-active' class to the body tag.
 *
 * @param  array $classes CSS classes applied to the body tag.
 * @return array $classes modified to include 'woocommerce-active' class.
 */
function catch_store_woocommerce_active_body_class( $classes ) {
    $classes[] = 'woocommerce-active';

    return $classes;
}
add_filter( 'body_class', 'catch_store_woocommerce_active_body_class' );

/**
 * WooCommerce specific scripts & stylesheets.
 *
 * @return void
 */
function catch_store_woocommerce_scripts() {
    $font_path   = WC()->plugin_url() . '/assets/fonts/';
    $inline_font = '@font-face {
            font-family: "star";
            src: url("' . $font_path . 'star.eot");
            src: url("' . $font_path . 'star.eot?#iefix") format("embedded-opentype"),
                url("' . $font_path . 'star.woff") format("woff"),
                url("' . $font_path . 'star.ttf") format("truetype"),
                url("' . $font_path . 'star.svg#star") format("svg");
            font-weight: normal;
            font-style: normal;
        }';

    wp_add_inline_style( 'catch-store-style', $inline_font );
}
add_action( 'wp_enqueue_scripts', 'catch_store_woocommerce_scripts' );


if ( ! function_exists( 'catch_store_woocommerce_product_columns_wrapper' ) ) {
    /**
     * Product columns wrapper.
     *
     * @return  void
     */
    function catch_store_woocommerce_product_columns_wrapper() {
        // Get option from Customizer=> WooCommerce=> Product Catlog=> Products per row.
        echo '<div class="columns-' . absint( get_option( 'woocommerce_catalog_columns', 3 ) ) . '">';
    }
}
add_action( 'woocommerce_before_shop_loop', 'catch_store_woocommerce_product_columns_wrapper', 40 );

if ( ! function_exists( 'catch_store_woocommerce_product_columns_wrapper_close' ) ) {
    /**
     * Product columns wrapper close.
     *
     * @return  void
     */
    function catch_store_woocommerce_product_columns_wrapper_close() {
        echo '</div>';
    }
}
add_action( 'woocommerce_after_shop_loop', 'catch_store_woocommerce_product_columns_wrapper_close', 40 );

if ( ! function_exists( 'catch_store_remove_default_woo_store_notice' ) ) {
    /**
     * Remove default Store Notice from footer, added in header.php
     *
     * @return  void
     */
    function catch_store_remove_default_woo_store_notice() {
        remove_action( 'wp_footer', 'woocommerce_demo_store' );
    }
}
add_action( 'after_setup_theme', 'catch_store_remove_default_woo_store_notice', 40 );
