<?php
/**
 * Customizer functionality
 *
 * @package Catch_Store
 */

/**
 * Sets up the WordPress core custom header and custom background features.
 *
 * @since Catch Store Pro 1.0
 *
 * @see catch_store_header_style()
 */
function catch_store_custom_header_and_background() {
	$color_scheme             = catch_store_get_color_scheme();
	$default_background_color = trim( $color_scheme[0], '#' );
	$default_text_color       = trim( $color_scheme[1], '#' );

	/**
	 * Filter the arguments used when adding 'custom-background' support in Persona.
	 *
	 * @since Catch Store Pro 1.0
	 *
	 * @param array $args {
	 *     An array of custom-background support arguments.
	 *
	 *     @type string $default-color Default color of the background.
	 * }
	 */
	add_theme_support( 'custom-background', apply_filters( 'catch_store_custom_background_args', array(
		'default-color' => $default_background_color,
	) ) );

	/**
	 * Filter the arguments used when adding 'custom-header' support in Persona.
	 *
	 * @since Catch Store Pro 1.0
	 *
	 * @param array $args {
	 *     An array of custom-header support arguments.
	 *
	 *     @type string $default-text-color Default color of the header text.
	 *     @type int      $width            Width in pixels of the custom header image. Default 1200.
	 *     @type int      $height           Height in pixels of the custom header image. Default 280.
	 *     @type bool     $flex-height      Whether to allow flexible-height header images. Default true.
	 *     @type callable $wp-head-callback Callback function used to style the header image and text
	 *                                      displayed on the blog.
	 * }
	 */
	add_theme_support( 'custom-header', apply_filters( 'catch_store_custom_header_args', array(
		'default-image'      	 => get_parent_theme_file_uri( '/assets/images/header-image.jpg' ),
		'default-text-color'     => $default_text_color,
		'width'                  => 1920,
		'height'                 => 835,
		'flex-height'            => true,
		'flex-height'            => true,
		'wp-head-callback'       => 'catch_store_header_style',
		'video'                  => true,
	) ) );

	register_default_headers( array(
		'default-image' => array(
			'url'           => '%s/assets/images/header-image.jpg',
			'thumbnail_url' => '%s/assets/images/header-image-275x155.jpg',
			'description'   => esc_html__( 'Default Header Image', 'catch-store-pro' ),
		),
	) );
}
add_action( 'after_setup_theme', 'catch_store_custom_header_and_background' );

function catch_store_color_options() {
	//Color Scheme
	$default_color = catch_store_get_color_scheme();

	// We do not add Background Color and Header Text Color here as if comes from WordPress Core
	return apply_filters( 'catch_store_color_options', array(
			'page_background_color' => array(
				'label'   => esc_html__( 'Page Background Color', 'catch-store-pro' ),
				'default' => $default_color[2],
			),
			'secondary_background_color' => array(
				'label'   => esc_html__( 'Secondary Background Color', 'catch-store-pro' ),
				'default' => $default_color[3],
			),
			'main_text_color' => array(
				'label'   => esc_html__( 'Main Text Color', 'catch-store-pro' ),
				'default' => $default_color[4],
			),
			'button_text_color' => array(
				'label'   => esc_html__( 'Button Text Color', 'catch-store-pro' ),
				'default' => $default_color[5],
			),
			'button_hover_text_color' => array(
				'label'   => esc_html__( 'Button Hover Text Color', 'catch-store-pro' ),
				'default' => $default_color[6],
			),
			'button_background_color' => array(
				'label'   => esc_html__( 'Button Background Color', 'catch-store-pro' ),
				'default' => $default_color[7],
			),
			'button_hover_background_color' => array(
				'label'   => esc_html__( 'Button Hover Background Color', 'catch-store-pro' ),
				'default' => $default_color[8],
			),
			'link_color' => array(
				'label'   => esc_html__( 'Link Color', 'catch-store-pro' ),
				'default' => $default_color[9],
			),
			'link_hover_color' => array(
				'label'   => esc_html__( 'Link Hover Color', 'catch-store-pro' ),
				'default' => $default_color[10],
			),
			'heading_text_color' => array(
				'label'   => esc_html__( 'Heading Text Color', 'catch-store-pro' ),
				'default' => $default_color[11],
			),
			'tertiary_background_color' => array(
				'label'   => esc_html__( 'Tertiary Background Color', 'catch-store-pro' ),
				'default' => $default_color[12],
			),
			'text_color_with_background' => array(
				'label'   => esc_html__( 'Text Color With Background', 'catch-store-pro' ),
				'default' => $default_color[13],
			),
			'border_color' => array(
				'label'   => esc_html__( 'Border Color', 'catch-store-pro' ),
				'default' => $default_color[14],
			),
			'tertiary_text_color' => array(
				'label'   => esc_html__( 'Tertiary Text Color', 'catch-store-pro' ),
				'default' => $default_color[15],
			),
			'tertiary_text_hover_color' => array(
				'label'   => esc_html__( 'Tertiary Text Hover Color', 'catch-store-pro' ),
				'default' => $default_color[16],
			),
			'secondary_button_text_color' => array(
				'label'   => esc_html__( 'Secondary Button Text Color', 'catch-store-pro' ),
				'default' => $default_color[17],
			),
			'secondary_button_border_color' => array(
				'label'   => esc_html__( 'Secondary Button Border Color', 'catch-store-pro' ),
				'default' => $default_color[18],
			),
			'secondary_button_hover_background_color' => array(
				'label'   => esc_html__( 'Secondary Button Hover Background Color', 'catch-store-pro' ),
				'default' => $default_color[19],
			),
			'secondary_button_hover_text_color' => array(
				'label'   => esc_html__( 'Secondary Button Hover Text Color', 'catch-store-pro' ),
				'default' => $default_color[20],
			),
			'button_text_color_with_background' => array(
				'label'   => esc_html__( 'Button Text Color With Background', 'catch-store-pro' ),
				'default' => $default_color[21],
			),
			'button_background_color_with_background' => array(
				'label'   => esc_html__( 'Button Background Color With Background', 'catch-store-pro' ),
				'default' => $default_color[22],
			),
		)
	);
}

if ( ! function_exists( 'catch_store_header_style' ) ) :
	/**
	 * Styles the header text displayed on the site.
	 *
	 * Create your own catch_store_header_style() function to override in a child theme.
	 *
	 * @since Catch Store Pro 1.0
	 *
	 * @see catch_store_custom_header_and_background().
	 */
	function catch_store_header_style() {

	$header_image = catch_store_featured_overall_image();

	    if ( 'disable' !== $header_image ) : ?>
	        <style type="text/css" rel="header-image">
	            .custom-header:before {
	                background-image: url( <?php echo esc_url( $header_image ); ?>);
					background-position: center top;
					background-repeat: no-repeat;
					background-size: cover;
					content: "";
					display: block;
					position: absolute;
					top: 0;
					left: 0;
					width: 100%;
					height: 100%;
					z-index: -1;
	            }
	        </style>
	    <?php
	    endif;
	// If the header text has been hidden.
	?>
	<?php
	// If the header text option is untouched, let's bail.
	if ( display_header_text() ) {
		$header_text_color = get_header_textcolor();
		$color_scheme      = catch_store_get_color_scheme();
		$default_color     = trim( $color_scheme[1] , '#' );

		if ( $default_color !== $header_text_color ) :
		?>
		<style type="text/css" id="catch-store-header-css">
		.site-title a,
		.site-description {
			color: #<?php echo esc_attr( $header_text_color ); ?>;
		}
		</style>
	<?php
		endif;
	} else {
		?>
		<style type="text/css" id="catch-store-header-css">
		.site-branding {
			margin: 0 auto 0 0;
		}

		.site-identity {
			clip: rect(1px, 1px, 1px, 1px);
			position: absolute;
		}
		</style>
	<?php
	}
}
endif; // catch_store_header_style

/**
 * Customize video play/pause button in the custom header.
 *
 * @param array $settings header video settings.
 */
function catch_store_video_controls( $settings ) {
	$settings['l10n']['play'] = '<span class="screen-reader-text">' . esc_html__( 'Play background video', 'catch-store-pro' ) . '</span>' . catch_store_get_svg( array(
		'icon' => 'play',
	) );
	$settings['l10n']['pause'] = '<span class="screen-reader-text">' . esc_html__( 'Pause background video', 'catch-store-pro' ) . '</span>' . catch_store_get_svg( array(
		'icon' => 'pause',
	) );

	$enable = get_theme_mod( 'catch_store_header_enable_media_on_mobile' );

    // Enable header video on mobile devices
    if ( $enable ) {
		$settings['minWidth']  = 100;
		$settings['minHeight'] = 100;
    }

	return $settings;
}
add_filter( 'header_video_settings', 'catch_store_video_controls' );

/**
 * Registers color schemes for Persona.
 *
 * Can be filtered with {@see 'catch_store_color_schemes'}.
 *
 * The order of colors in a colors array:
 * 1. Background Color
 * 2. Header Text Color
 * 3. Page Background Color
 * 4. Secondary Background Color
 * 5. Main Text Color
 * 6. Button Text Color
 * 7. Button Hover Text Color
 * 8. Button Background Color
 * 9. Button Background Hover Color
 * 10. Link Color
 * 11. Link Hover Color
 * 12. Heading Text Color
 * 13. Tertiary Background Color
 * 14. Text Color With Background
 * 15. Border Color
 * 16. Tertiary Text Color
 * 17. Tertiary Text Hover Color
 * 18. Secondary Button Text color
 * 19. Secondary Button Border color
 * 20. Secondary Button Hover Background Color
 * 21. Secondary Button Hover Text Color
 * 22. Button Text Color With Background
 * 23. Button Background Color With Background

 * @since Catch Store Pro 1.0
 *
 * @return array An associative array of color scheme options.
 */
function catch_store_get_color_schemes() {
	/**
	 * Filter the color schemes registered for use with Persona.
	 *
	 * The default schemes include 'default', 'dark', 'gray', 'red', and 'yellow'.
	 *
	 * @since Catch Store Pro 1.0
	 *
	 * @param array $schemes {
	 *     Associative array of color schemes data.
	 *
	 *     @type array $slug {
	 *         Associative array of information for setting up the color scheme.
	 *
	 *         @type string $label  Color scheme label.
	 *         @type array  $colors HEX codes for default colors prepended with a hash symbol ('#').
	 *                              Colors are defined in the following order: Main background, page
	 *                              background, link, main text, secondary text.
	 *     }
	 * }
	 */
	return apply_filters( 'catch_store_color_schemes', array(
		'default' => array(
			'label'  => esc_html__( 'Default', 'catch-store-pro' ),
			'colors' => array(
				'#f0f0f0', /* Background Color */
				'#000000', /* Header Text Color */
				'#ffffff', /* Page Background Color */
				'#f7f7f7', /* Secondary Background Color */
				'#333333', /* Main Text Color */
				'#ffffff', /* Button Text Color */
				'#ffffff', /* Button Hover Text Color */
				'#111111', /* Button Background Color */
				'#e5ae4a', /* Button Background Hover Color */
				'#111111', /* Link Color */
				'#e5ae4a', /* Link Hover Color */
				'#111111', /* Heading Text Color */
				'#111111', /* Tertiary Background Color */
				'#ffffff', /* Text color with background */
				'#ececec', /* Border Color */
				'#8b8b8b', /* Tertiary Text Color */
				'#ffffff', /* Tertiary Text Hover Color */
				'#c6c6c6', /* Secondary Button Text color */
				'#c6c6c6', /* Secondary Button Border color */
				'#111111', /* Secondary Button Hover Background Color */
				'#ffffff', /* Secondary Button Hover Text Color */
				'#111111', /* Button Text Color With Background */
				'#ffffff', /* Button Background Color With Background */
			),
		),
		'dark' => array(
			'label'  => esc_html__( 'Dark', 'catch-store-pro' ),
			'colors' => array(
				'#181818', /* Background Color */
				'#ffffff', /* Header Text Color */
				'#1d1d1d', /* Page Background Color */
				'#111111', /* Secondary Background Color */
				'#808080', /* Main Text Color */
				'#111111', /* Button Text Color */
				'#ffffff', /* Button Hover Text Color */
				'#ffffff', /* Button Background Color */
				'#e5ae4a', /* Button Background Hover Color */
				'#ffffff', /* Link Color */
				'#e5ae4a', /* Link Hover Color */
				'#ffffff', /* Heading Text Color */
				'#000000', /* Tertiary Background Color */
				'#ffffff', /* Text color with background */
				'#323232', /* Border Color */
				'#808080', /* Tertiary Text Color */
				'#ffffff', /* Tertiary Text Hover Color */
				'#ffffff', /* Secondary Button Text color */
				'#e5ae4a', /* Secondary Button Border color */
				'#e5ae4a', /* Secondary Button Hover Background Color */
				'#111111', /* Secondary Button Hover Text Color */
				'#111111', /* Button Text Color With Background */
				'#ffffff', /* Button Background Color With Background */
			),
		),

		'red' => array(
			'label'  => esc_html__( 'Red', 'catch-store-pro' ),
			'colors' => array(
				'#7a0000', /* Background Color */
				'#ffffff', /* Header Text Color */
				'#960000', /* Page Background Color */
				'#801919', /* Secondary Background Color */
				'#f2f2f2', /* Main Text Color */
				'#ffffff', /* Button Text Color */
				'#ffffff', /* Button Hover Text Color */
				'#510000', /* Button Background Color */
				'#2f0000', /* Button Background Hover Color */
				'#c7c7c7', /* Link Color */
				'#f2f2f2', /* Link Hover Color */
				'#ffffff', /* Heading Text Color */
				'#721616', /* Tertiary Background Color */
				'#ffffff', /* Text color with background */
				'#721616', /* Border Color */
				'#c7c7c7', /* Tertiary Text Color */
				'#ffffff', /* Tertiary Text Hover Color */
				'#c7c7c7', /* Secondary Button Text color */
				'#c7c7c7', /* Secondary Button Border color */
				'#510000', /* Secondary Button Hover Background Color */
				'#ffffff', /* Secondary Button Hover Text Color */
				'#111111', /* Button Text Color With Background */
				'#ffffff', /* Button Background Color With Background */
			),
		),
		'gray' => array(
			'label'  => esc_html__( 'Gray', 'catch-store-pro' ),
			'colors' => array(
				'#9199a2', /* Background Color */
				'#ffffff', /* Header Text Color */
				'#616a73', /* Page Background Color */
				'#4d545c', /* Secondary Background Color */
				'#f2f2f2', /* Main Text Color */
				'#ffffff', /* Button Text Color */
				'#ffffff', /* Button Hover Text Color */
				'#30363d', /* Button Background Color */
				'#232629', /* Button Background Hover Color */
				'#e9e9e9', /* Link Color */
				'#ffffff', /* Link Hover Color */
				'#ffffff', /* Heading Text Color */
				'#444a51', /* Tertiary Background Color */
				'#ffffff', /* Text color with background */
				'#727c7f', /* Border Color */
				'#8b8b8b', /* Tertiary Text Color */
				'#ffffff', /* Tertiary Text Hover Color */
				'#30363d', /* Secondary Button Text color */
				'#30363d', /* Secondary Button Border color */
				'#30363d', /* Secondary Button Hover Background Color */
				'#ffffff', /* Secondary Button Hover Text Color */
				'#111111', /* Button Text Color With Background */
				'#ffffff', /* Button Background Color With Background */
			),
		),
		'yellow' => array(
			'label'  => esc_html__( 'Yellow', 'catch-store-pro' ),
			'colors' => array(
				'#3b3721', /* Background Color */
				'#774e24', /* Header Text Color */
				'#fff2a5', /* Page Background Color */
				'#ffee85', /* Secondary Background Color */
				'#3b3721', /* Main Text Color */
				'#ffffff', /* Button Text Color */
				'#ffffff', /* Button Hover Text Color */
				'#774e24', /* Button Background Color */
				'#503418', /* Button Background Hover Color */
				'#774e24', /* Link Color */
				'#3b3721', /* Link Hover Color */
				'#774e24', /* Heading Text Color */
				'#ffdf60', /* Tertiary Background Color */
				'#ffffff', /* Text color with background */
				'#ffe95e', /* Border Color */
				'#8b8b8b', /* Tertiary Text Color */
				'#ffffff', /* Tertiary Text Hover Color */
				'#774e24', /* Secondary Button Text color */
				'#774e24', /* Secondary Button Border color */
				'#774e24', /* Secondary Button Hover Background Color */
				'#ffffff', /* Secondary Button Hover Text Color */
				'#111111', /* Button Text Color With Background */
				'#ffffff', /* Button Background Color With Background */
			),
		),
		'clean' => array(
			'label'  => esc_html__( 'Clean', 'catch-store-pro' ),
			'colors' => array(
				'#f0f0f0', /* Background Color */
				'#000000', /* Header Text Color */
				'#ffffff', /* Page Background Color */
				'#fbfbfb', /* Secondary Background Color */
				'#333333', /* Main Text Color */
				'#ffffff', /* Button Text Color */
				'#ffffff', /* Button Hover Text Color */
				'#96588a', /* Button Background Color */
				'#7d3f71', /* Button Background Hover Color */
				'#111111', /* Link Color */
				'#7d3f71', /* Link Hover Color */
				'#111111', /* Heading Text Color */
				'#111111', /* Tertiary Background Color */
				'#ffffff', /* Text color with background */
				'#ececec', /* Border Color */
				'#8b8b8b', /* Tertiary Text Color */
				'#ffffff', /* Tertiary Text Hover Color */
				'#c6c6c6', /* Secondary Button Text color */
				'#c6c6c6', /* Secondary Button Border color */
				'#96588a', /* Secondary Button Hover Background Color */
				'#ffffff', /* Secondary Button Hover Text Color */
				'#111111', /* Button Text Color With Background */
				'#ffffff', /* Button Background Color With Background */
			),
		),
	) );
}

if ( ! function_exists( 'catch_store_get_color_scheme' ) ) :
	/**
	 * Retrieves the current Persona color scheme.
	 *
	 * Create your own catch_store_get_color_scheme() function to override in a child theme.
	 *
	 * @since Catch Store Pro 1.0
	 *
	 * @return array An associative array of either the current or default color scheme HEX values.
	 */
	function catch_store_get_color_scheme() {
		$color_scheme_option = get_theme_mod( 'color_scheme', 'default' );
		$color_schemes       = catch_store_get_color_schemes();

		if ( array_key_exists( $color_scheme_option, $color_schemes ) ) {
			return $color_schemes[ $color_scheme_option ]['colors'];
		}

		return $color_schemes['default']['colors'];
	}
endif; // catch_store_get_color_scheme

if ( ! function_exists( 'catch_store_get_color_scheme_choices' ) ) :
	/**
	 * Retrieves an array of color scheme choices registered for Persona.
	 *
	 * Create your own catch_store_get_color_scheme_choices() function to override
	 * in a child theme.
	 *
	 * @since Catch Store Pro 1.0
	 *
	 * @return array Array of color schemes.
	 */
	function catch_store_get_color_scheme_choices() {
		$color_schemes                = catch_store_get_color_schemes();
		$color_scheme_control_options = array();

		foreach ( $color_schemes as $color_scheme => $value ) {
			$color_scheme_control_options[ $color_scheme ] = $value['label'];
		}

		return $color_scheme_control_options;
	}
endif; // catch_store_get_color_scheme_choices

/**
 * Enqueues front-end CSS for color scheme.
 *
 * @since Catch Store Pro 1.0
 *
 * @see wp_add_inline_style()
 */
function catch_store_color_scheme_css() {
	$color_scheme_option = get_theme_mod( 'color_scheme', 'default' );

	// Don't do anything if the default color scheme is selected.
	if ( 'default' === $color_scheme_option ) {
		return;
	}

	$color_scheme = catch_store_get_color_scheme();

	// Convert main text hex color to rgba.
	$main_text_color_rgb = catch_store_hex2rgb( $color_scheme[4] );

	// Convert tertiary hex color to rgba.
	$tertiary_background_color_rgb = catch_store_hex2rgb( $color_scheme[12] );

	// If the rgba values are empty return early.

    if ( empty( $main_text_color_rgb ) && empty( $tertiary_background_color_rgb ) ) {
        return;
    }

	// If we get this far, we have a custom color scheme.
	$colors = array(
		'background_color'                        => $color_scheme[0],
		'header_text_color'                       => $color_scheme[1],
		'page_background_color'                   => $color_scheme[2],
		'secondary_background_color'              => $color_scheme[3],
		'main_text_color'                         => $color_scheme[4],
		'main_text_fourty_color'                  => vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.4)', $main_text_color_rgb ),
		'button_text_color'                       => $color_scheme[5],
		'button_hover_text_color'                 => $color_scheme[6],
		'button_background_color'                 => $color_scheme[7],
		'button_hover_background_color'           => $color_scheme[8],
		'link_color'                              => $color_scheme[9],
		'link_hover_color'                        => $color_scheme[10],
		'heading_text_color'                      => $color_scheme[11],
		'tertiary_background_color'               => $color_scheme[12],
		'tertiary_background_fourty_color'        => vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.4 )', $tertiary_background_color_rgb ),
		'text_color_with_background'              => $color_scheme[13],
		'border_color'                            => $color_scheme[14],
		'tertiary_text_color'                     => $color_scheme[15],
		'tertiary_text_hover_color'               => $color_scheme[16],
		'secondary_button_text_color'             => $color_scheme[17],
		'secondary_button_border_color'           => $color_scheme[18],
		'secondary_button_hover_background_color' => $color_scheme[19],
		'secondary_button_hover_text_color'       => $color_scheme[20],
		'button_text_color_with_background'       => $color_scheme[21],
		'button_background_color_with_background' => $color_scheme[22],
	);

	$color_scheme_css = catch_store_get_color_scheme_css( $colors );

	wp_add_inline_style( 'catch-store-block-style', $color_scheme_css );
}
add_action( 'wp_enqueue_scripts', 'catch_store_color_scheme_css' );

/**
 * Binds the JS listener to make Customizer color_scheme control.
 *
 * Passes color scheme data as colorScheme global.
 *
 * @since Catch Store Pro 1.0
 */
function catch_store_customize_control_js() {
	wp_enqueue_script( 'catch-store-color-scheme-control', trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'assets/js/color-scheme-control.min.js', array( 'customize-controls', 'iris', 'underscore', 'wp-util' ), '20170816', true );

	$colors['colorScheme'] = catch_store_get_color_schemes();

	$color_options = catch_store_color_options();

	// Add background color and header text color index values
	$color_options = array_merge( array( 'background_color', 'header_textcolor' ), array_keys( $color_options ) );

	$colors['colorOptions'] = $color_options;

	wp_localize_script( 'catch-store-color-scheme-control', 'catchStoreColorMain', $colors );

	wp_enqueue_script( 'catch-store-custom-controls', trailingslashit( esc_url( get_template_directory_uri() ) ) . 'assets/js/customize-custom-controls.min.js', array( 'jquery-ui-sortable' ), '20180802', true );

	/*section Sorter css*/
	wp_enqueue_style( 'catch-store-custom-controls-css', trailingslashit( esc_url( get_template_directory_uri() ) ) . 'assets/css/customizer.css' );
}
add_action( 'customize_controls_enqueue_scripts', 'catch_store_customize_control_js' );

/**
 * Returns CSS for the color schemes.
 *
 * @since Catch Store Pro 1.0
 *
 * @param array $colors Color scheme colors.
 * @return string Color scheme CSS.
 */
function catch_store_get_color_scheme_css( $colors ) {
	$colors = wp_parse_args( $colors, array(
		'background_color'                        => '',
		'header_text_color'                       => '',
		'page_background_color'                   => '',
		'secondary_background_color'              => '',
		'main_text_color'                         => '',
		'main_text_fourty_color'                  => '',
		'button_text_color'                       => '',
		'button_hover_text_color'                 => '',
		'button_background_color'                 => '',
		'button_hover_background_color'           => '',
		'link_color'                              => '',
		'link_hover_color'                        => '',
		'heading_text_color'                      => '',
		'tertiary_background_color'               => '',
		'tertiary_background_fourty_color'        => '',
		'text_color_with_background'              => '',
		'border_color'                            => '',
		'tertiary_text_color'                     => '',
		'tertiary_text_hover_color'               => '',
		'secondary_button_text_color'             => '',
		'secondary_button_border_color'           => '',
		'secondary_button_hover_background_color' => '',
		'secondary_button_hover_text_color'       => '',
		'button_text_color_with_background'       => '',
		'button_background_color_with_background' => '',
	) );

	return <<<CSS
	/* Color Scheme */

	/* Background Color */
	body {
		background-color: {$colors['background_color']};
	}

	/* Header Text Color */
	.site-title a,
	.site-description {
	    color: {$colors['header_text_color']};
	}

	/* Page Background Color */
	#page,
	#colophon hr,
	#colophon pre,
	#colophon thead th,
	#colophon blockquote,
	#promotion-section.content-frame .entry-container-frame,
	.portfolio-content-wrapper .entry-container .inner-wrap,
	#footer-newsletter .has-background-image .widget-inner-wrap,
	.section:nth-child(2n) .hero-content-wrapper .entry-container,
	.section:nth-child(2n).testimonial-content-section .entry-container,
	#footer-newsletter .ewnewsletter .ew-newsletter-wrap .ew-newsletter-subbox,
	.testimonial-content-section .cycle-prev,
	.testimonial-content-section .cycle-next {
		background-color: {$colors['page_background_color']};
	}

	.section:nth-child(2n).testimonial-content-section .entry-container:after {
		border-color: {$colors['page_background_color']} transparent;
	}

	#promotion-section.content-frame .entry-container {
		border-color: {$colors['page_background_color']};
	}

	@media screen and (min-width: 64em) {
		#site-product-search,
		#site-cart-contents-items {
			background-color: {$colors['page_background_color']};
		}

		#header-menu-social,
		.search-container {
			background-color: {$colors['page_background_color']};
		}

		.site-navigation ul ul,
		.site-navigation ul ul li {
			background-color: {$colors['page_background_color']};
		}

		.site-secondary-menu ul ul:after,
		.site-secondary-menu #header-menu-social.toggled-on::after {
			border-color: {$colors['page_background_color']} transparent;
		}
	}

	/* Page Background Color Woocommerce */
	.woocommerce-shorting-wrapper .woocommerce-ordering select,
	.woocommerce-account .woocommerce-MyAccount-navigation a {
		background-color: {$colors['page_background_color']};
	}

	/* Secondary Background Color */
	hr,
	pre,
	thead th,
	blockquote,
	.site-footer,
	.pagination,
	.post-navigation,
	.site .skip-link,
	.no-comments,
	.header-top-bar,
	.header-top-button-wrap,
	.section:nth-child(2n),
	.wp-caption .wp-caption-text,
	.hero-content-wrapper .entry-container,
	.testimonial-content-section .entry-container,
	[class^="wp-block-"]:not(.wp-block-gallery) figcaption,
	.wp-block-table thead th  {
		background-color: {$colors['secondary_background_color']};
	}

	.testimonial-content-section .entry-container:after {
		border-color: {$colors['secondary_background_color']} transparent;
	}

	@media screen and (min-width: 64em) {
		.site-secondary-menu ul ul:before,
		#header-menu-social.toggled-on:before  {
			border-color: {$colors['secondary_background_color']} transparent;
		}
	}

	/* Secondary Background Color Woocommerce */
	.woocommerce-message,
	.woocommerce-info,
	.woocommerce-error,
	.woocommerce-noreviews,
	p.no-comments,
	.woocommerce-shorting-wrapper,
	.woocommerce-tabs .panel,
	ul.wc_payment_methods .payment_box,
	.woocommerce-tabs ul.tabs li.active a,
	.woocommerce-account .woocommerce-MyAccount-navigation a:hover,
	.woocommerce-account .woocommerce-MyAccount-navigation a:focus,
	.woocommerce-account .woocommerce-MyAccount-navigation .is-active a {
		background-color: {$colors['secondary_background_color']};
	}

	@media screen and (min-width: 48em) {
		table.shop_table .cart-subtotal th,
		table.shop_table .order-total th {
		    background-color: {$colors['secondary_background_color']};
		}
	}

	@media screen and (min-width: 64em) {
		.site-header-cart .widget_shopping_cart {
		    background-color: {$colors['secondary_background_color']};
		}
	}

	/* Main Text Color */
	body,
	button,
	input,
	select,
	textarea,
	span.price ins,
	p.price ins,
	#footer-newsletter .ewnewsletter .widget-inner-wrap,
	.testimonial-content-section .cycle-prev,
	.testimonial-content-section .cycle-next,
	.wp-block-pullquote__citation,
	.wp-block-pullquote cite,
	.wp-block-pullquote {
		color: {$colors['main_text_color']};
	}

	#hero-section .entry-title:after,
	.section-title:after,
	#footer-instagram .widget-title:after,
	.testimonial-content-section .cycle-prev,
	.testimonial-content-section .cycle-next {
		border-color: {$colors['main_text_color']};
	}

	/* Secondary Link Color */
	.entry-meta,
	.entry-meta a,
	.post-navigation .nav-subtitle,
	.testimonial-content-section .cycle-pager span,
	.widget_recent_entries .post-date,
	.widget_rss .rss-date,
	.widget_rss cite,
	#search-toggle-top,
	#search-toggle-right,
	#search-toggle,
	.entry-caption,
	.wp-caption .wp-caption-text,
	.site-description,
	.social-navigation a,
	.ctsocialwidget a,
	.entry-breadcrumbs,
	.woocommerce-breadcrumb,
	.comment-metadata,
	.pingback .edit-link,
	.comment-metadata a,
	.pingback .comment-edit-link,
	.comment-notes,
	.comment-awaiting-moderation,
	.logged-in-as,
	.form-allowed-tags,
	.entry-meta .icon,
	.site-info,
	.site-info a,
	.search-submit,
	input[type="date"],
	input[type="time"],
	input[type="datetime-local"],
	input[type="week"],
	input[type="month"],
	input[type="text"],
	input[type="email"],
	input[type="url"],
	input[type="password"],
	input[type="search"],
	input[type="tel"],
	input[type="number"],
	textarea,
	.wp-block-latest-posts__post-date, 
	.wp-block-latest-comments__comment-date,
	[class^="wp-block-"]:not(.wp-block-gallery) figcaption {
		color: {$colors['main_text_fourty_color']};
	}

	.entry-breadcrumbs a:after {
		border-left-color: {$colors['main_text_fourty_color']};
	}

	/* Secondary Link Color Woocommerce */
	p.stars a:before,
	p.stars a:hover ~ a:before,
	p.stars.selected a.active ~ a:before,
	.woocommerce-tabs ul.tabs li a {
		color: {$colors['main_text_fourty_color']};
	}

	/* Button Text Color */
	#scrollup,
	.widget_calendar tbody a,
	#promotion-section .more-link .more-button,
	.catch-instagram-feed-gallery-widget-wrapper .button,
	#feature-slider-section .cycle-pager .cycle-pager-active,
	.page-links a,
	.posts-navigation a,
	.site-main #infinite-handle span,
	.pagination .page-numbers.current,
	.sticky-post,
	mark,
	ins,
	button,
	.button,
	input[type="button"],
	input[type="reset"],
	input[type="submit"],
	.testimonial-content-section .cycle-prev:hover,
	.testimonial-content-section .cycle-prev:focus,
	.testimonial-content-section .cycle-next:hover,
	.testimonial-content-section .cycle-next:focus,
	.wp-block-file .wp-block-file__button,
	.wp-block-button .wp-block-button__link  {
		color: {$colors['button_text_color']};
	}

	/* Button Text Color Woocommerce */
	.woocommerce #respond input#submit,
	.woocommerce a.button,
	.woocommerce button.button,
	.woocommerce button.button.alt,
	.woocommerce input.button,
	.woocommerce input.button.alt,
	.woocommerce .product-container .wc-forward,
	.woocommerce-pagination ul li span.current,
	.woocommerce-pagination ul li a:hover,
	.woocommerce-pagination ul li a:focus {
		color: {$colors['button_text_color']};
	}

	/* Button Hover Text Color */
	#scrollup:hover,
	#scrollup:focus,
	.widget_calendar tbody a:hover,
	.widget_calendar tbody a:focus,
	.header-media .more-link .more-button:hover,
	.header-media .more-link .more-button:focus,
	#feature-slider-section .more-link span:hover,
	#feature-slider-section .more-link span:focus,
	#promotion-section .more-link .more-button:hover,
	#promotion-section .more-link .more-button:focus,
	.tagcloud a:hover,
	.tagcloud a:focus,
	.page-links a:hover,
	.page-links a:focus,
	.posts-navigation a:hover,
	.posts-navigation a:focus,
	.site-main #infinite-handle span:hover,
	.site-main #infinite-handle span:focus,
	button:hover,
	button:focus,
	button[disabled]:hover,
	button[disabled]:focus,
	.button:hover,
	.button:focus,
	input[type="button"][disabled]:hover,
	input[type="button"][disabled]:focus,
	input[type="reset"][disabled]:hover,
	input[type="reset"][disabled]:focus,
	input[type="submit"][disabled]:hover,
	input[type="submit"][disabled]:focus,
	#feature-slider-section .cycle-prev:hover,
	#feature-slider-section .cycle-prev:focus,
	#feature-slider-section .cycle-next:hover,
	#feature-slider-section .cycle-next:focus,
	.wp-block-file .wp-block-file__button:hover,
	.wp-block-file .wp-block-file__button:focus,
	.wp-block-button .wp-block-button__link:hover,
	.wp-block-button .wp-block-button__link:focus {
		color: {$colors['button_hover_text_color']};
	}

	/* Button Hover Text Color Woocommerce */
	.onsale,
	.woocommerce #respond input#submit:hover,
	.woocommerce #respond input#submit:focus,
	.woocommerce a.button:hover,
	.woocommerce a.button:focus,
	.woocommerce button.button:hover,
	.woocommerce button.button:focus,
	.woocommerce button.button.alt:hover,
	.woocommerce button.button.alt:focus,
	.woocommerce input.button:hover,
	.woocommerce input.button:focus,
	.woocommerce input.button.alt:hover,
	.woocommerce input.button.alt:focus,
	.woocommerce .product-container .added,
	.woocommerce .product-container .wc-forward:hover,
	.woocommerce .product-container .wc-forward:focus {
		color: {$colors['button_hover_text_color']};
	}

	/* Button Background Color */
	#scrollup,
	.widget_calendar tbody a,
	button,
	button[disabled]:hover,
	button[disabled]:focus,
	.button,
	input[type="button"],
	input[type="button"][disabled]:hover,
	input[type="button"][disabled]:focus,
	input[type="reset"],
	input[type="reset"][disabled]:hover,
	input[type="reset"][disabled]:focus,
	input[type="submit"],
	input[type="submit"][disabled]:hover,
	input[type="submit"][disabled]:focus,
	.sticky-post,
	.page-links a,
	.site-main #infinite-handle span,
	.posts-navigation a,
	.pagination .page-numbers.current,
	#promotion-section .more-link .more-button,
	.catch-instagram-feed-gallery-widget-wrapper .button,
	.testimonial-content-section .cycle-prev:hover,
	.testimonial-content-section .cycle-prev:focus,
	.testimonial-content-section .cycle-next:hover,
	.testimonial-content-section .cycle-next:focus,
	.wp-block-file .wp-block-file__button,
	.wp-block-button .wp-block-button__link {
		background-color: {$colors['button_background_color']};
	}

	.testimonial-content-section .cycle-prev:hover,
	.testimonial-content-section .cycle-prev:focus,
	.testimonial-content-section .cycle-next:hover,
	.testimonial-content-section .cycle-next:focus {
		border-color: {$colors['button_background_color']};
	}

	/* Button Background Color Woocommerce */
	.woocommerce #respond input#submit,
	.woocommerce a.button,
	.woocommerce button.button,
	.woocommerce button.button.alt,
	.woocommerce input.button,
	.woocommerce input.button.alt,
	.woocommerce .product-container .wc-forward,
	.woocommerce .product-container .wc-forward,
	.woocommerce-pagination ul li span.current,
	.woocommerce-pagination ul li a:hover,
	.woocommerce-pagination ul li a:focus {
		background-color: {$colors['button_background_color']};
	}

	.woocommerce-tabs ul.tabs li.active a {
		border-color: {$colors['button_background_color']};
	}

	/* Button Hover Background Color */
	#scrollup:hover,
	#scrollup:focus,
	.widget_calendar tbody a:hover,
	.widget_calendar tbody a:focus,
	.header-media .more-link .more-button:hover,
	.header-media .more-link .more-button:focus,
	#feature-slider-section .more-link span:hover,
	#feature-slider-section .more-link span:hover,
	.custom-header-media .wp-custom-header-video-button.wp-custom-header-video-pause,
	.custom-header-media .wp-custom-header-video-button:hover,
	.custom-header-media .wp-custom-header-video-button:focus,
	button:hover,
	button:focus,
	.button:hover,
	.button:focus,
	input[type="button"]:hover,
	input[type="button"]:focus,
	input[type="reset"]:hover,
	input[type="reset"]:focus,
	input[type="submit"]:hover,
	input[type="submit"]:focus,
	.page-links a:hover,
	.page-links a:focus,
	.site-main #infinite-handle span:hover,
	.site-main #infinite-handle span:focus,
	.posts-navigation a:hover,
	.posts-navigation a:focus,
	#promotion-section .more-link .more-button:hover,
	#promotion-section .more-link .more-button:focus,
	.catch-instagram-feed-gallery-widget-wrapper .instagram-button .button:hover,
	.catch-instagram-feed-gallery-widget-wrapper .instagram-button .button:focus,
	.tagcloud a:hover,
	.tagcloud a:focus,
	#feature-slider-section .cycle-prev:hover,
	#feature-slider-section .cycle-prev:focus,
	#feature-slider-section .cycle-next:hover,
	#feature-slider-section .cycle-next:focus,
	.wp-block-file .wp-block-file__button:hover,
	.wp-block-file .wp-block-file__button:focus,
	.wp-block-button .wp-block-button__link:hover,
	.wp-block-button .wp-block-button__link:focus {
		background-color: {$colors['button_hover_background_color']};
	}

	.tagcloud a:hover,
	.tagcloud a:focus,
	#feature-slider-section .cycle-prev:hover,
	#feature-slider-section .cycle-prev:focus,
	#feature-slider-section .cycle-next:hover,
	#feature-slider-section .cycle-next:focus,
	.custom-header-media .wp-custom-header-video-button.wp-custom-header-video-pause,
	.custom-header-media .wp-custom-header-video-button:hover,
	.custom-header-media .wp-custom-header-video-button:focus {
		border-color: {$colors['button_hover_background_color']};
	}

	/* Button Hover Background Color Woocommerce */
	.onsale,
	.woocommerce #respond input#submit:hover,
	.woocommerce #respond input#submit:focus,
	.woocommerce a.button:hover,
	.woocommerce a.button:focus,
	.woocommerce button.button:hover,
	.woocommerce button.button:focus,
	.woocommerce button.button.alt:hover,
	.woocommerce button.button.alt:focus,
	.woocommerce input.button:hover,
	.woocommerce input.button:focus,
	.woocommerce input.button.alt:hover,
	.woocommerce input.button.alt:focus,
	.woocommerce .product-container .added,
	.woocommerce .product-container .wc-forward:hover,
	.woocommerce .product-container .wc-forward:focus {
		background-color: {$colors['button_hover_background_color']};
	}

	/* Link Color */
	a,
	.menu-toggle,
	.dropdown-toggle,
	input[type="date"]:focus,
	input[type="time"]:focus,
	input[type="datetime-local"]:focus,
	input[type="week"]:focus,
	input[type="month"]:focus,
	input[type="text"]:focus,
	input[type="email"]:focus,
	input[type="url"]:focus,
	input[type="password"]:focus,
	input[type="search"]:focus,
	input[type="tel"]:focus,
	input[type="number"]:focus,
	textarea:focus,
	.comment-metadata .comment-reply-link,
	.site-footer-menu .social-navigation a,
	.tagcloud a,
	.entry-breadcrumbs a,
	.woocommerce-breadcrumb a {
		color: {$colors['link_color']};
	}

	mark,
	ins {
		background-color: {$colors['link_color']};
	}

	input[type="date"]:focus,
	input[type="time"]:focus,
	input[type="datetime-local"]:focus,
	input[type="week"]:focus,
	input[type="month"]:focus,
	input[type="text"]:focus,
	input[type="email"]:focus,
	input[type="url"]:focus,
	input[type="password"]:focus,
	input[type="search"]:focus,
	input[type="tel"]:focus,
	input[type="number"]:focus,
	textarea:focus,
	.tagcloud a {
		border-color: {$colors['link_color']};
	}

	/* Link Color Woocommerce */
	.woocommerce-tabs ul.tabs li.active a,
	.single-product div.product .woocommerce-product-rating .woocommerce-review-link:hover,
	.single-product div.product .woocommerce-product-rating .woocommerce-review-link:focus,
	.single-product .product_meta a:hover,
	.single-product .product_meta a:focus,
	.woocommerce-info a:hover,
	.woocommerce-info a:focus,
	.variations .reset_variations:hover,
	.variations .reset_variations:focus {
		color: {$colors['link_color']};
	}

	/* Link Hover Color */
	a:hover,
	a:focus,
	a:active,
	.menu-toggle:hover,
	.menu-toggle:focus,
	.menu-toggle.toggled-on,
	.menu-toggle.toggled-on:hover,
	.menu-toggle.toggled-on:focus,
	#search-toggle-top:hover,
	#search-toggle-right:hover,
	#search-toggle:hover,
	#search-toggle-top:focus,
	#search-toggle-right:focus,
	#search-toggle:focus,
	.search-submit:hover,
	.search-submit:focus,
	.dropdown-toggle:hover,
	.dropdown-toggle:focus,
	.required,
	.entry-title a:hover,
	.entry-title a:focus,
	.entry-meta a:hover,
	.entry-meta a:focus,
	.entry-meta .icon:hover,
	.entry-meta .icon:focus,
	.site-info a:hover,
	.site-info a:focus,
	.comment-metadata a:hover,
	.comment-metadata a:focus,
	.pingback .comment-edit-link:hover,
	.pingback .comment-edit-link:focus,
	#feature-slider-section .entry-title a:hover,
	#feature-slider-section .entry-title a:focus,
	#feature-slider-section .entry-meta a:hover,
	#feature-slider-section .entry-meta a:focus,
	#feature-slider-section .entry-meta .icon:hover,
	#feature-slider-section .entry-meta .icon:focus,
	.testimonial-content-section .cycle-pager span.cycle-pager-active,
	.social-navigation a:hover,
	.social-navigation a:focus,
	.site-footer-menu .social-navigation a:hover,
	.site-footer-menu .social-navigation a:focus,
	.site .skip-link,
	.entry-breadcrumbs a:hover,
	.entry-breadcrumbs a:focus,
	.woocommerce-breadcrumb a:hover,
	.woocommerce-breadcrumb a:focus,
	.comment-metadata .comment-reply-link:hover,
	.comment-metadata .comment-reply-link:focus,
	.custom-header-content .entry-title a:hover,
	.custom-header-content .entry-title a:focus,
	.custom-header-content .entry-meta a:hover,
	.custom-header-content .entry-meta a:focus {
		color: {$colors['link_hover_color']};
	}

	blockquote,
	.no-comments,
	.menu-toggle:hover,
	.menu-toggle:focus,
	.site-main .more-link .more-button,
	.wp-block-pullquote,
	.wp-block-quote:not(.is-large):not(.is-style-large) {
		border-color: {$colors['link_hover_color']};
	}

	/* Link Hover Color Woocommerce */
	.single-product div.product .woocommerce-product-rating .woocommerce-review-link,
	.single-product .product_meta a,
	.woocommerce-info a,
	.variations .reset_variations,
	.star-rating span:before,
	p.stars:hover a:before,
	p.stars.selected a.active:before,
	p.stars.selected a:not(.active):before,
	.woocommerce-tabs ul.tabs li a:hover,
	.woocommerce-tabs ul.tabs li a:focus {
		color: {$colors['link_hover_color']};
	}

	.woocommerce-info,
	.woocommerce-message,
	.rtl .woocommerce-info,
	.rtl .woocommerce-message {
		border-color: {$colors['link_hover_color']};
	}

	/* Heading Text Color */
	h1,
	h2,
	h3,
	h4,
	h5,
	h6,
	.entry-title a,
	.widget-title a,
	.page-links > .page-links-title,
	.singular-content-wrap .entry-footer span span {
		color: {$colors['heading_text_color']};
	}

	/* Tertiary Background Color */
	.header-media,
	#site-generator,
	#feature-slider-section .hentry {
		background-color: {$colors['tertiary_background_color']};
	}

	/* Tertiary Background Color Woocommerce */
	.demo_store {
		background-color: {$colors['tertiary_background_color']};
	}

	/* 40% Tertiary Background Color */
	.site-footer-menu + .site-info {
		border-color: {$colors['tertiary_background_fourty_color']};
	}

	/* Text color with background */
	#feature-slider-section .entry-container a,
	#feature-slider-section .entry-summary,
	#feature-slider-section .entry-content,
	#promotion-section.content-color-white .entry-title,
	#promotion-section.content-color-white .entry-title a,
	#promotion-section.content-color-white .entry-container,
	#promotion-section.content-color-white .entry-container a,
	.custom-header-content .entry-title,
	.custom-header-content .site-header-text,
	.custom-header-content .site-header-text a,
	.custom-header-media .wp-custom-header-video-button,
	.custom-header-media .wp-custom-header-video-button.wp-custom-header-video-pause,
	.custom-header-media .wp-custom-header-video-button:hover,
	.custom-header-media .wp-custom-header-video-button:focus,
	.custom-header-content .entry-meta,
	.custom-header-content .entry-meta a,
	#feature-slider-section .cycle-prev,
	#feature-slider-section .cycle-next {
		color: {$colors['text_color_with_background']};
	}

	#feature-slider-section .cycle-pager .cycle-pager-active {
		background-color: {$colors['text_color_with_background']};
	}

	#feature-slider-section .cycle-prev,
	#feature-slider-section .cycle-next,
	#feature-slider-section .cycle-pager span,
	#feature-slider-section .cycle-pager .cycle-pager-active {
		border-color: {$colors['text_color_with_background']};
	}

	/* Text color with background Woocommerce */
	.demo_store {
		color: {$colors['text_color_with_background']};
	}

	/* Border Color */
	table,
	tr,
	input[type="date"],
	input[type="time"],
	input[type="datetime-local"],
	input[type="week"],
	input[type="month"],
	input[type="text"],
	input[type="email"],
	input[type="url"],
	input[type="password"],
	input[type="search"],
	input[type="tel"],
	input[type="number"],
	textarea,
	fieldset,
	select,
	.author-info,
	#header-navigation-area,
	.site-footer-menu,
	.section-content-wrapper .post-wrapper,
	.page-links a,
	.page-links > span,
	.comment-respond,
	.comment-list article,
	.comment-list .pingback,
	.comment-list .trackback,
	.image-navigation,
	.comment-navigation,
	#search-top-container,
	.team-content-wrapper .post-thumbnail img,
	.featured-content-wrapper .post-thumbnail img,
	.wp-block-table,
	.wp-block-table caption,
	.wp-block-table tr,
	.wp-block-latest-comments__comment {
		border-color: {$colors['border_color']};
	}

	@media screen and (min-width: 64em) {
		.site-secondary-menu ul ul,
		#header-menu-social.toggled-on,
		.primary-search-wrapper .social-navigation,
		.secondary-search-wrapper .social-navigation {
			border-color: {$colors['border_color']};
		}
	}

	/* Border Color Woocommerce */
	table.cart .product-thumbnail img,
	.single-product .product_meta,
	#site-product-search .widget,
	.product_list_widget li img,
	#reviews .comment-respond,
	ul.products li.product img,
	.woocommerce ul.cart_list li,
	.woocommerce ul.product_list_widget li,
	.woocommerce-account .woocommerce-MyAccount-navigation,
	.woocommerce-account .woocommerce-MyAccount-navigation li,
	.single-product div.product .woocommerce-product-gallery__image,
	.single-product div.product .woocommerce-product-gallery .flex-control-thumbs li img,
	.product-review-section .entry-content .attachment-woocommerce_thumbnail img {
		border-color: {$colors['border_color']};
	}

	@media screen and (min-width: 64em) {
		#site-product-search .widget {
			border-color: {$colors['border_color']};
		}
	}

	/* Tertiary Text Color */
	.site-info,
	.site-info a:hover,
	.site-info a:focus,
	#site-generator .menu-toggle,
	#site-generator .site-navigation a,
	#site-generator .social-navigation a {
		color: {$colors['tertiary_text_color']};
	}

	/* Tertiary Text Color Woocommerce */
	.demo_store .woocommerce-store-notice__dismiss-link:hover,
	.demo_store .woocommerce-store-notice__dismiss-link:focus {
		color: {$colors['tertiary_text_color']};
	}

	/* Tertiary Text Hover Color */
	.site-info a,
	#site-generator .menu-toggle:hover,
	#site-generator .menu-toggle:focus,
	#site-generator .site-navigation a:hover,
	#site-generator .site-navigation a:focus,
	#site-generator .social-navigation a:hover,
	#site-generator .social-navigation a:focus {
		color: {$colors['tertiary_text_hover_color']};
	}

	/* Tertiary Text Hover Color Woocommerce*/
	.demo_store .woocommerce-store-notice__dismiss-link {
		color: {$colors['tertiary_text_hover_color']};
	}

	/* Secondary Button Text color */
	.woocommerce .product-container .button {
		color: {$colors['secondary_button_text_color']};
	}

	/* Secondary Button Border color */
	.woocommerce .product-container .button {
		border-color: {$colors['secondary_button_border_color']};
	}

	/* Secondary Button Hover Background color */
	.woocommerce .product-container a.button:hover,
	.woocommerce .product-container a.button:focus {
		background-color: {$colors['secondary_button_hover_background_color']};
	}

	.woocommerce .product-container a.button:hover,
	.woocommerce .product-container a.button:focus {
		border-color: {$colors['secondary_button_hover_background_color']};
	}

	/* Secondary Button Hover Text color */
	.woocommerce .product-container a.button:hover,
	.woocommerce .product-container a.button:focus {
		color: {$colors['secondary_button_hover_text_color']};
	}

	/* Button Text Color With Background */
	.header-media .more-link .more-button,
	#feature-slider-section .more-link span {
		color: {$colors['button_text_color_with_background']};
	}

	/* Button Background Color With Background */
	.header-media .more-link .more-button,
	#feature-slider-section .more-link span {
		background-color: {$colors['button_background_color_with_background']};
	}
CSS;
}


/**
 * Outputs an Underscore template for generating CSS for the color scheme.
 *
 * The template generates the css dynamically for instant display in the
 * Customizer preview.
 *
 * @since Catch Store Pro 1.0
 */
function catch_store_color_scheme_css_template() {
	$colors = array(
		'background_color'                        => '{{ data.background_color }}',
		'header_text_color'                       => '{{ data.header_text_color }}',
		'page_background_color'                   => '{{ data.page_background_color }}',
		'secondary_background_color'              => '{{ data.secondary_background_color }}',
		'main_text_color'                         => '{{ data.main_text_color }}',
		'main_text_fourty_color'                  => '{{ data.main_text_fourty_color }}',
		'button_text_color'                       => '{{ data.button_text_color }}',
		'button_hover_text_color'                 => '{{ data.button_hover_text_color }}',
		'button_background_color'                 => '{{ data.button_background_color }}',
		'button_hover_background_color'           => '{{ data.button_hover_background_color }}',
		'link_color'                              => '{{ data.link_color }}',
		'link_hover_color'                        => '{{ data.link_hover_color }}',
		'heading_text_color'                      => '{{ data.heading_text_color }}',
		'tertiary_background_color'               => '{{ data.tertiary_background_color }}',
		'tertiary_background_fourty_color'        => '{{ data.tertiary_background_fourty_color }}',
		'text_color_with_background'              => '{{ data.text_color_with_background }}',
		'border_color'                            => '{{ data.border_color }}',
		'tertiary_text_color'                     => '{{ data.tertiary_text_color }}',
		'tertiary_text_hover_color'               => '{{ data.tertiary_text_hover_color }}',
		'secondary_button_text_color'             => '{{ data.secondary_button_text_color }}',
		'secondary_button_border_color'           => '{{ data.secondary_button_border_color }}',
		'secondary_button_hover_background_color' => '{{ data.secondary_button_hover_background_color }}',
		'secondary_button_hover_text_color'       => '{{ data.secondary_button_hover_text_color }}',
		'button_text_color_with_background'       => '{{ data.button_text_color_with_background }}',
		'button_background_color_with_background' => '{{ data.button_background_color_with_background }}',
	);

	?>
	<script type="text/html" id="tmpl-catch-store-color-scheme">
		<?php echo catch_store_get_color_scheme_css( $colors ); ?>
	</script>
	<?php
}
add_action( 'customize_controls_print_footer_scripts', 'catch_store_color_scheme_css_template' );

/**
 * Enqueues front-end CSS for the page background color.
 *
 * @since Catch Store Pro 1.0
 *
 * @see wp_add_inline_style()
 */
function catch_store_page_background_color_css() {
	$color_scheme          = catch_store_get_color_scheme();
	$default_color         = $color_scheme[2];
	$page_background_color = get_theme_mod( 'page_background_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $page_background_color === $default_color ) {
		return;
	}

	$css = '
		/* Page Background Color */
		#page,
		#colophon hr,
		#colophon pre,
		#colophon thead th,
		#colophon blockquote,
		#promotion-section.content-frame .entry-container-frame,
		.portfolio-content-wrapper .entry-container .inner-wrap,
		#footer-newsletter .has-background-image .widget-inner-wrap,
		.section:nth-child(2n) .hero-content-wrapper .entry-container,
		.section:nth-child(2n).testimonial-content-section .entry-container,
		#footer-newsletter .ewnewsletter .ew-newsletter-wrap .ew-newsletter-subbox,
		.testimonial-content-section .cycle-prev,
		.testimonial-content-section .cycle-next {
			background-color: %1$s;
		}

		#promotion-section.content-frame .entry-container {
			border-color: %1$s;
		}

		.section:nth-child(2n).testimonial-content-section .entry-container:after {
			border-color: %1$s transparent;
		}

		@media screen and (min-width: 64em) {
			#site-product-search,
			#site-cart-contents-items {
				background-color: %1$s;
			}

			#header-menu-social,
			.search-container {
				background-color: %1$s;
			}

			.site-navigation ul ul,
			.site-navigation ul ul li {
				background-color: %1$s;
			}

			.site-secondary-menu ul ul:after,
			.site-secondary-menu #header-menu-social.toggled-on::after {
				border-color: %1$s transparent;
			}
		}

		/* Page Background Color Woocommerce */
		.woocommerce-shorting-wrapper .woocommerce-ordering select,
		.woocommerce-account .woocommerce-MyAccount-navigation a {
			background-color: %1$s;
		}
	';

	wp_add_inline_style( 'catch-store-block-style', sprintf( $css, $page_background_color ) );
}
add_action( 'wp_enqueue_scripts', 'catch_store_page_background_color_css', 11 );


/**
 * Enqueues front-end CSS for the secondary background color.
 *
 * @since Catch Store Pro 1.0
 *
 * @see wp_add_inline_style()
 */
function catch_store_secondary_background_color_css() {
	$color_scheme          			= catch_store_get_color_scheme();
	$default_color         			= $color_scheme[3];
	$secondary_background_color 	= get_theme_mod( 'secondary_background_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $secondary_background_color === $default_color ) {
		return;
	}

	$css = '
		/* Secondary Background Color */
		hr,
		pre,
		thead th,
		blockquote,
		.site-footer,
		.pagination,
		.post-navigation,
		.site .skip-link,
		.no-comments,
		.header-top-bar,
		.header-top-button-wrap,
		.section:nth-child(2n),
		.wp-caption .wp-caption-text,
		.hero-content-wrapper .entry-container,
		.testimonial-content-section .entry-container,
		[class^="wp-block-"]:not(.wp-block-gallery) figcaption,
		.wp-block-table thead th  {
			background-color: %1$s;
		}

		.testimonial-content-section .entry-container:after {
			border-color: %1$s transparent;
		}

		@media screen and (min-width: 64em) {
			.site-secondary-menu ul ul:before,
			#header-menu-social.toggled-on:before {
				border-color: %1$s transparent;
			}
		}

		/* Secondary Background Color Woocommerce */
		.woocommerce-message,
		.woocommerce-info,
		.woocommerce-error,
		.woocommerce-noreviews,
		p.no-comments,
		.woocommerce-shorting-wrapper,
		.woocommerce-tabs .panel,
		ul.wc_payment_methods .payment_box,
		.woocommerce-tabs ul.tabs li.active a,
		.woocommerce-account .woocommerce-MyAccount-navigation a:hover,
		.woocommerce-account .woocommerce-MyAccount-navigation a:focus,
		.woocommerce-account .woocommerce-MyAccount-navigation .is-active a {
			background-color: %1$s;
		}

		@media screen and (min-width: 48em) {
			table.shop_table .cart-subtotal th,
			table.shop_table .order-total th,
			.site-header-cart .widget_shopping_cart {
			    background-color: %1$s;
			}
		}

		@media screen and (min-width: 64em) {
			.site-header-cart .widget_shopping_cart {
			    background-color: %1$s;
			}
		}
	';

	wp_add_inline_style( 'catch-store-block-style', sprintf( $css, $secondary_background_color ) );
}
add_action( 'wp_enqueue_scripts', 'catch_store_secondary_background_color_css', 11 );


/**
 * Enqueues front-end CSS for the main text color.
 *
 * @since Catch Store Pro 1.0
 *
 * @see wp_add_inline_style()
 */
function catch_store_main_text_color_css() {
	$color_scheme    = catch_store_get_color_scheme();
	$default_color   = $color_scheme[4];
	$main_text_color = get_theme_mod( 'main_text_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $main_text_color === $default_color ) {
		return;
	}

	// Convert main text hex color to rgba.
	$main_text_color_rgb = catch_store_hex2rgb( $color_scheme[4] );

	// If the rgba values are empty return early.
	if ( empty( $main_text_color_rgb ) ) {
		return;
	}

	$main_text_fourty_color	= vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.4 )', $main_text_color_rgb );

	$css = '
		/* Main Text Color */
		body,
		button,
		input,
		select,
		textarea,
		span.price ins,
		p.price ins,
		#footer-newsletter .ewnewsletter .widget-inner-wrap,
		.testimonial-content-section .cycle-prev,
		.testimonial-content-section .cycle-next,
		.wp-block-pullquote__citation,
		.wp-block-pullquote cite,
		.wp-block-pullquote {
			color: %1$s;
		}

		#hero-section .entry-title:after,
		.section-title:after,
		#footer-instagram .widget-title:after,
		.testimonial-content-section .cycle-prev,
		.testimonial-content-section .cycle-next {
			border-color: %1$s;
		}

		/* Secondary Link Color */
		.entry-meta,
		.entry-meta a,
		.post-navigation .nav-subtitle,
		.testimonial-content-section .cycle-pager span,
		.widget_recent_entries .post-date,
		.widget_rss .rss-date,
		.widget_rss cite,
		#search-toggle-top,
		#search-toggle-right,
		#search-toggle,
		.entry-caption,
		.wp-caption .wp-caption-text,
		.site-description,
		.social-navigation a,
		.ctsocialwidget a,
		.entry-breadcrumbs,
		.woocommerce-breadcrumb,
		.comment-metadata,
		.pingback .edit-link,
		.comment-metadata a,
		.pingback .comment-edit-link,
		.comment-notes,
		.comment-awaiting-moderation,
		.logged-in-as,
		.form-allowed-tags,
		.entry-meta .icon,
		.site-info,
		.site-info a,
		.search-submit,
		input[type="date"],
		input[type="time"],
		input[type="datetime-local"],
		input[type="week"],
		input[type="month"],
		input[type="text"],
		input[type="email"],
		input[type="url"],
		input[type="password"],
		input[type="search"],
		input[type="tel"],
		input[type="number"],
		textarea,
		.wp-block-latest-posts__post-date, 
		.wp-block-latest-comments__comment-date,
		[class^="wp-block-"]:not(.wp-block-gallery) figcaption {
			color: %2$s;
		}

		.entry-breadcrumbs a:after {
			border-left-color: %2$s;
		}

		/* Secondary Link Color Woocommerce */
		p.stars a:before,
		p.stars a:hover ~ a:before,
		p.stars.selected a.active ~ a:before,
		.woocommerce-tabs ul.tabs li a {
			color: %2$s;
		}
	';

	wp_add_inline_style( 'catch-store-block-style', sprintf( $css, $main_text_color, $main_text_fourty_color ) );
}
add_action( 'wp_enqueue_scripts', 'catch_store_main_text_color_css', 11 );


/**
 * Enqueues front-end CSS for the button text color.
 *
 * @since Catch Store Pro 1.0
 *
 * @see wp_add_inline_style()
 */
function catch_store_button_text_color_css() {
	$color_scheme    = catch_store_get_color_scheme();
	$default_color   = $color_scheme[5];
	$button_text_color = get_theme_mod( 'button_text_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $button_text_color === $default_color ) {
		return;
	}

	$css = '
		/* Button Text Color */
		#scrollup,
		.widget_calendar tbody a,
		#promotion-section .more-link .more-button,
		.catch-instagram-feed-gallery-widget-wrapper .button,
		.page-links a,
		.posts-navigation a,
		.site-main #infinite-handle span,
		.pagination .page-numbers.current,
		.sticky-post,
		mark,
		ins,
		button,
		.button,
		input[type="button"],
		input[type="reset"],
		input[type="submit"],
		.testimonial-content-section .cycle-prev:hover,
		.testimonial-content-section .cycle-prev:focus,
		.testimonial-content-section .cycle-next:hover,
		.testimonial-content-section .cycle-next:focus,
		.wp-block-file .wp-block-file__button,
		.wp-block-button .wp-block-button__link {
			color: %1$s;
		}

		/* Button Text Color Woocommerce */
		.woocommerce #respond input#submit,
		.woocommerce a.button,
		.woocommerce button.button,
		.woocommerce button.button.alt,
		.woocommerce input.button,
		.woocommerce input.button.alt,
		.woocommerce .product-container .wc-forward,
		.woocommerce-pagination ul li span.current,
		.woocommerce-pagination ul li a:hover,
		.woocommerce-pagination ul li a:focus {
			color: %1$s;
		}
	';

	wp_add_inline_style( 'catch-store-block-style', sprintf( $css, $button_text_color) );
}
add_action( 'wp_enqueue_scripts', 'catch_store_button_text_color_css', 11 );


/**
 * Enqueues front-end CSS for the button hover text color.
 *
 * @since Catch Store Pro 1.0
 *
 * @see wp_add_inline_style()
 */
function catch_store_button_hover_text_color_css() {
	$color_scheme    		 = catch_store_get_color_scheme();
	$default_color   		 = $color_scheme[6];
	$button_hover_text_color = get_theme_mod( 'button_hover_text_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $button_hover_text_color === $default_color ) {
		return;
	}

	$css = '
		/* Button Hover Text Color */
		#scrollup:hover,
		#scrollup:focus,
		.widget_calendar tbody a:hover,
		.widget_calendar tbody a:focus,
		.header-media .more-link .more-button:hover,
		.header-media .more-link .more-button:focus,
		.header-media .more-link .more-button:hover,
		.header-media .more-link .more-button:focus,
		#feature-slider-section .more-link span:hover,
		#feature-slider-section .more-link span:focus,
		#promotion-section .more-link .more-button:hover,
		#promotion-section .more-link .more-button:focus,
		.tagcloud a:hover,
		.tagcloud a:focus,
		.page-links a:hover,
		.page-links a:focus,
		.posts-navigation a:hover,
		.posts-navigation a:focus,
		.site-main #infinite-handle span:hover,
		.site-main #infinite-handle span:focus,
		button:hover,
		button:focus,
		button[disabled]:hover,
		button[disabled]:focus,
		.button:hover,
		.button:focus,
		input[type="button"][disabled]:hover,
		input[type="button"][disabled]:focus,
		input[type="reset"][disabled]:hover,
		input[type="reset"][disabled]:focus,
		input[type="submit"][disabled]:hover,
		input[type="submit"][disabled]:focus,
		#feature-slider-section .cycle-prev:hover,
		#feature-slider-section .cycle-prev:focus,
		#feature-slider-section .cycle-next:hover,
		#feature-slider-section .cycle-next:focus,
		.wp-block-file .wp-block-file__button:hover,
		.wp-block-file .wp-block-file__button:focus,
		.wp-block-button .wp-block-button__link:hover,
		.wp-block-button .wp-block-button__link:focus {
			color: %1$s;
		}

		/* Button Hover Text Color Woocommerce */
		.onsale,
		.woocommerce #respond input#submit:hover,
		.woocommerce #respond input#submit:focus,
		.woocommerce a.button:hover,
		.woocommerce a.button:focus,
		.woocommerce button.button:hover,
		.woocommerce button.button:focus,
		.woocommerce button.button.alt:hover,
		.woocommerce button.button.alt:focus,
		.woocommerce input.button:hover,
		.woocommerce input.button:focus,
		.woocommerce input.button.alt:hover,
		.woocommerce input.button.alt:focus,
		.woocommerce .product-container .added,
		.woocommerce .product-container .wc-forward:hover,
		.woocommerce .product-container .wc-forward:focus {
			color: %1$s;
		}
	';

	wp_add_inline_style( 'catch-store-block-style', sprintf( $css, $button_hover_text_color) );
}
add_action( 'wp_enqueue_scripts', 'catch_store_button_hover_text_color_css', 11 );


/**
 * Enqueues front-end CSS for the button background color.
 *
 * @since Catch Store Pro 1.0
 *
 * @see wp_add_inline_style()
 */
function catch_store_button_background_color_css() {
	$color_scheme    		 = catch_store_get_color_scheme();
	$default_color   		 = $color_scheme[7];
	$button_background_color = get_theme_mod( 'button_background_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $button_background_color === $default_color ) {
		return;
	}

	$css = '
		/* Button Background Color */
		#scrollup,
		.widget_calendar tbody a,
		button,
		button[disabled]:hover,
		button[disabled]:focus,
		.button,
		input[type="button"],
		input[type="button"][disabled]:hover,
		input[type="button"][disabled]:focus,
		input[type="reset"],
		input[type="reset"][disabled]:hover,
		input[type="reset"][disabled]:focus,
		input[type="submit"],
		input[type="submit"][disabled]:hover,
		input[type="submit"][disabled]:focus,
		.sticky-post,
		.page-links a,
		.site-main #infinite-handle span,
		.posts-navigation a,
		.pagination .page-numbers.current,
		#promotion-section .more-link .more-button,
		.catch-instagram-feed-gallery-widget-wrapper .button,
		.testimonial-content-section .cycle-prev:hover,
		.testimonial-content-section .cycle-prev:focus,
		.testimonial-content-section .cycle-next:hover,
		.testimonial-content-section .cycle-next:focus,
		.wp-block-file .wp-block-file__button,
		.wp-block-button .wp-block-button__link {
			background-color: %1$s;
		}

		.testimonial-content-section .cycle-prev,
		.testimonial-content-section .cycle-next,
		.testimonial-content-section .cycle-prev:hover,
		.testimonial-content-section .cycle-prev:focus,
		.testimonial-content-section .cycle-next:hover,
		.testimonial-content-section .cycle-next:focus {
			border-color: %1$s;
		}

		/* Button Background Color Woocommerce */
		.woocommerce #respond input#submit,
		.woocommerce a.button,
		.woocommerce button.button,
		.woocommerce button.button.alt,
		.woocommerce input.button,
		.woocommerce input.button.alt,
		.woocommerce .product-container .wc-forward,
		.woocommerce .product-container .wc-forward,
		.woocommerce-pagination ul li span.current,
		.woocommerce-pagination ul li a:hover,
		.woocommerce-pagination ul li a:focus {
			background-color: %1$s;
		}

		.woocommerce-tabs ul.tabs li.active a {
			border-color: %1$s;
		}
	';

	wp_add_inline_style( 'catch-store-block-style', sprintf( $css, $button_background_color) );
}
add_action( 'wp_enqueue_scripts', 'catch_store_button_background_color_css', 11 );


/**
 * Enqueues front-end CSS for the button background hover color.
 *
 * @since Catch Store Pro 1.0
 *
 * @see wp_add_inline_style()
 */
function catch_store_button_hover_background_color_css() {
	$color_scheme   			   = catch_store_get_color_scheme();
	$default_color   			   = $color_scheme[8];
	$button_hover_background_color = get_theme_mod( 'button_hover_background_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $button_hover_background_color === $default_color ) {
		return;
	}

	$css = '
		/* Button Hover Background Color */
		#scrollup:hover,
		#scrollup:focus,
		.widget_calendar tbody a:hover,
		.widget_calendar tbody a:focus,
		.header-media .more-link .more-button:hover,
		.header-media .more-link .more-button:focus,
		#feature-slider-section .more-link span:hover,
		#feature-slider-section .more-link span:hover,
		.custom-header-media .wp-custom-header-video-button.wp-custom-header-video-pause,
		.custom-header-media .wp-custom-header-video-button:hover,
		.custom-header-media .wp-custom-header-video-button:focus,
		button:hover,
		button:focus,
		.button:hover,
		.button:focus,
		input[type="button"]:hover,
		input[type="button"]:focus,
		input[type="reset"]:hover,
		input[type="reset"]:focus,
		input[type="submit"]:hover,
		input[type="submit"]:focus,
		.page-links a:hover,
		.page-links a:focus,
		.site-main #infinite-handle span:hover,
		.site-main #infinite-handle span:focus,
		.posts-navigation a:hover,
		.posts-navigation a:focus,
		#promotion-section .more-link .more-button:hover,
		#promotion-section .more-link .more-button:focus,
		.catch-instagram-feed-gallery-widget-wrapper .instagram-button .button:hover,
		.catch-instagram-feed-gallery-widget-wrapper .instagram-button .button:focus,
		.tagcloud a:hover,
		.tagcloud a:focus,
		#feature-slider-section .cycle-prev:hover,
		#feature-slider-section .cycle-prev:focus,
		#feature-slider-section .cycle-next:hover,
		#feature-slider-section .cycle-next:focus,
		.wp-block-file .wp-block-file__button:hover,
		.wp-block-file .wp-block-file__button:focus,
		.wp-block-button .wp-block-button__link:hover,
		.wp-block-button .wp-block-button__link:focus {
			background-color: %1$s;
		}

		.tagcloud a:hover,
		.tagcloud a:focus,
		#feature-slider-section .cycle-prev:hover,
		#feature-slider-section .cycle-prev:focus,
		#feature-slider-section .cycle-next:hover,
		#feature-slider-section .cycle-next:focus,
		.custom-header-media .wp-custom-header-video-button.wp-custom-header-video-pause,
		.custom-header-media .wp-custom-header-video-button:hover,
		.custom-header-media .wp-custom-header-video-button:focus {
			border-color: %1$s;
		}

		/* Button Hover Background Color Woocommerce */
		.onsale,
		.woocommerce #respond input#submit:hover,
		.woocommerce #respond input#submit:focus,
		.woocommerce a.button:hover,
		.woocommerce a.button:focus,
		.woocommerce button.button:hover,
		.woocommerce button.button:focus,
		.woocommerce button.button.alt:hover,
		.woocommerce button.button.alt:focus,
		.woocommerce input.button:hover,
		.woocommerce input.button:focus,
		.woocommerce input.button.alt:hover,
		.woocommerce input.button.alt:focus,
		.woocommerce .product-container .added,
		.woocommerce .product-container .wc-forward:hover,
		.woocommerce .product-container .wc-forward:focus {
			background-color: %1$s;
		}
	';

	wp_add_inline_style( 'catch-store-block-style', sprintf( $css, $button_hover_background_color) );
}
add_action( 'wp_enqueue_scripts', 'catch_store_button_hover_background_color_css', 11 );


/**
 * Enqueues front-end CSS for the link color
 *
 * @since Catch Store Pro 1.0
 *
 * @see wp_add_inline_style()
 */
function catch_store_link_color_css() {
	$color_scheme    = catch_store_get_color_scheme();
	$default_color   = $color_scheme[9];
	$link_color = get_theme_mod( 'link_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $link_color === $default_color ) {
		return;
	}

	$css = '
		/* Link Color */
		a,
		.menu-toggle,
		.dropdown-toggle,
		input[type="date"]:focus,
		input[type="time"]:focus,
		input[type="datetime-local"]:focus,
		input[type="week"]:focus,
		input[type="month"]:focus,
		input[type="text"]:focus,
		input[type="email"]:focus,
		input[type="url"]:focus,
		input[type="password"]:focus,
		input[type="search"]:focus,
		input[type="tel"]:focus,
		input[type="number"]:focus,
		textarea:focus,
		.comment-metadata .comment-reply-link,
		.site-footer-menu .social-navigation a,
		.tagcloud a,
		.entry-breadcrumbs a,
		.woocommerce-breadcrumb a {
			color: %1$s;
		}

		mark,
		ins {
			background-color: %1$s;
		}

		input[type="date"]:focus,
		input[type="time"]:focus,
		input[type="datetime-local"]:focus,
		input[type="week"]:focus,
		input[type="month"]:focus,
		input[type="text"]:focus,
		input[type="email"]:focus,
		input[type="url"]:focus,
		input[type="password"]:focus,
		input[type="search"]:focus,
		input[type="tel"]:focus,
		input[type="number"]:focus,
		textarea:focus,
		.tagcloud a {
			border-color: %1$s;
		}

		/* Link Color Woocommerce */
		.woocommerce-tabs ul.tabs li.active a,
		.single-product div.product .woocommerce-product-rating .woocommerce-review-link:hover,
		.single-product div.product .woocommerce-product-rating .woocommerce-review-link:focus,
		.single-product .product_meta a:hover,
		.single-product .product_meta a:focus,
		.woocommerce-info a:hover,
		.woocommerce-info a:focus,
		.variations .reset_variations:hover,
		.variations .reset_variations:focus {
			color:  %1$s;
		}
	';

	wp_add_inline_style( 'catch-store-block-style', sprintf( $css, $link_color) );
}
add_action( 'wp_enqueue_scripts', 'catch_store_link_color_css', 11 );


/**
 * Enqueues front-end CSS for the link hover color.
 *
 * @since Catch Store Pro 1.0
 *
 * @see wp_add_inline_style()
 */
function catch_store_link_hover_color_css() {
	$color_scheme    = catch_store_get_color_scheme();
	$default_color   = $color_scheme[10];
	$link_hover_color = get_theme_mod( 'link_hover_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $link_hover_color === $default_color ) {
		return;
	}

	$css = '
		/* Link Hover Color */
		a:hover,
		a:focus,
		a:active,
		.menu-toggle:hover,
		.menu-toggle:focus,
		.menu-toggle.toggled-on,
		.menu-toggle.toggled-on:hover,
		.menu-toggle.toggled-on:focus,
		#search-toggle-top:hover,
		#search-toggle-right:hover,
		#search-toggle:hover,
		#search-toggle-top:focus,
		#search-toggle-right:focus,
		#search-toggle:focus,
		.search-submit:hover,
		.search-submit:focus,
		.dropdown-toggle:hover,
		.dropdown-toggle:focus,
		.required,
		.entry-title a:hover,
		.entry-title a:focus,
		.entry-meta a:hover,
		.entry-meta a:focus,
		.entry-meta .icon:hover,
		.entry-meta .icon:focus,
		.site-info a:hover,
		.site-info a:focus,
		.comment-metadata a:hover,
		.comment-metadata a:focus,
		.pingback .comment-edit-link:hover,
		.pingback .comment-edit-link:focus,
		#feature-slider-section .entry-title a:hover,
		#feature-slider-section .entry-title a:focus,
		#feature-slider-section .entry-meta a:hover,
		#feature-slider-section .entry-meta a:focus,
		#feature-slider-section .entry-meta .icon:hover,
		#feature-slider-section .entry-meta .icon:focus,
		.testimonial-content-section .cycle-pager span.cycle-pager-active,
		.social-navigation a:hover,
		.social-navigation a:focus,
		.site-footer-menu .social-navigation a:hover,
		.site-footer-menu .social-navigation a:focus,
		.site .skip-link,
		.entry-breadcrumbs a:hover,
		.entry-breadcrumbs a:focus,
		.woocommerce-breadcrumb a:hover,
		.woocommerce-breadcrumb a:focus,
		.comment-metadata .comment-reply-link:hover,
		.comment-metadata .comment-reply-link:focus,
		.custom-header-content .entry-title a:hover,
		.custom-header-content .entry-title a:focus,
		.custom-header-content .entry-meta a:hover,
		.custom-header-content .entry-meta a:focus {
			color: %1$s;
		}

		blockquote,
		.no-comments,
		.menu-toggle:hover,
		.menu-toggle:focus,
		.site-main .more-link .more-button,
		.wp-block-pullquote,
		.wp-block-quote:not(.is-large):not(.is-style-large) {
			border-color: %1$s;
		}

		/* Link Hover Color Woocommerce */
		.single-product div.product .woocommerce-product-rating .woocommerce-review-link,
		.single-product .product_meta a,
		.woocommerce-info a,
		.variations .reset_variations,
		.star-rating span:before,
		p.stars:hover a:before,
		p.stars.selected a.active:before,
		p.stars.selected a:not(.active):before,
		.woocommerce-tabs ul.tabs li a:hover,
		.woocommerce-tabs ul.tabs li a:focus {
			color: %1$s;
		}

		.woocommerce-info,
		.woocommerce-message,
		.rtl .woocommerce-info,
		.rtl .woocommerce-message {
			border-color: %1$s;
		}
	';

	wp_add_inline_style( 'catch-store-block-style', sprintf( $css, $link_hover_color) );
}
add_action( 'wp_enqueue_scripts', 'catch_store_link_hover_color_css', 11 );

/**
 * Enqueues front-end CSS for the heading text color.
 *
 * @since Catch Store Pro 1.0
 *
 * @see wp_add_inline_style()
 */
function catch_store_heading_text_color_css() {
	$color_scheme    = catch_store_get_color_scheme();
	$default_color   = $color_scheme[11];
	$heading_text_color = get_theme_mod( 'heading_text_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $heading_text_color === $default_color ) {
		return;
	}

	$css = '
		/* Heading Text Color */
		h1,
		h2,
		h3,
		h4,
		h5,
		h6,
		.entry-title a,
		.widget-title a,
		.page-links > .page-links-title,
		.singular-content-wrap .entry-footer span span {
			color: %1$s;
		}
	';

	wp_add_inline_style( 'catch-store-block-style', sprintf( $css, $heading_text_color) );
}
add_action( 'wp_enqueue_scripts', 'catch_store_heading_text_color_css', 11 );


/**
 * Enqueues front-end CSS for the Tertiary background color.
 *
 * @since Catch Store Pro 1.0
 *
 * @see wp_add_inline_style()
 */
function catch_store_tertiary_background_color_css() {
	$color_scheme              = catch_store_get_color_scheme();
	$default_color             = $color_scheme[12];
	$tertiary_background_color = get_theme_mod( 'tertiary_background_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $tertiary_background_color === $default_color ) {
		return;
	}

	// Convert main text hex color to rgba.
	$tertiary_background_color_rgb = catch_store_hex2rgb( $color_scheme[12] );

	// If the rgba values are empty return early.
	if ( empty( $tertiary_background_color_rgb ) ) {
		return;
	}

	$tertiary_background_fourty_color	= vsprintf( 'rgba( %1$s, %2$s, %3$s, 0.4 )', $tertiary_background_color_rgb );

	$css = '
		/* Tertiary Background Color */
		.header-media,
		#site-generator,
		#feature-slider-section .hentry {
			background-color: %1$s;
		}

		/* Tertiary Background Color Woocommerce */
		.demo_store {
			background-color: %1$s;
		}

		/* 40% Tertiary Background Color */
		.site-footer-menu + .site-info {
			border-color: %2$s;
		}
	';

	wp_add_inline_style( 'catch-store-block-style', sprintf( $css, $tertiary_background_color, $tertiary_background_fourty_color ) );
}
add_action( 'wp_enqueue_scripts', 'catch_store_tertiary_background_color_css', 11 );


/**
 * Enqueues front-end CSS for the text color with background
 *
 * @since Catch Store Pro 1.0
 *
 * @see wp_add_inline_style()
 */
function catch_store_text_color_with_background_css() {
	$color_scheme               = catch_store_get_color_scheme();
	$default_color              = $color_scheme[13];
	$text_color_with_background = get_theme_mod( 'text_color_with_background', $default_color );

	// Don't do anything if the current color is the default.
	if ( $text_color_with_background === $default_color ) {
		return;
	}

	$css = '
		/* Text color with background */
		#feature-slider-section .entry-container a,
		#feature-slider-section .entry-summary,
		#feature-slider-section .entry-content,
		#promotion-section.content-color-white .entry-title,
		#promotion-section.content-color-white .entry-title a,
		#promotion-section.content-color-white .entry-container,
		#promotion-section.content-color-white .entry-container a,
		.custom-header-content .entry-title,
		.custom-header-content .site-header-text,
		.custom-header-content .site-header-text a,
		.custom-header-media .wp-custom-header-video-button,
		.custom-header-media .wp-custom-header-video-button.wp-custom-header-video-pause,
		.custom-header-media .wp-custom-header-video-button:hover,
		.custom-header-media .wp-custom-header-video-button:focus,
		.custom-header-content .entry-meta,
		.custom-header-content .entry-meta a,
		#feature-slider-section .cycle-prev,
		#feature-slider-section .cycle-next {
			color: %1$s;
		}

		#feature-slider-section .cycle-pager .cycle-pager-active {
			background-color: 1$s;
		}

		#feature-slider-section .cycle-prev,
		#feature-slider-section .cycle-next,
		#feature-slider-section .cycle-pager span,
		#feature-slider-section .cycle-pager .cycle-pager-active {
			border-color: %1$s;
		}

		/* Text color with background Woocommerce */
		.demo_store {
			color: %1$s;
		}
	';

	wp_add_inline_style( 'catch-store-block-style', sprintf( $css, $text_color_with_background ) );
}
add_action( 'wp_enqueue_scripts', 'catch_store_text_color_with_background_css', 11 );


/**
 * Enqueues front-end CSS for the border color.
 *
 * @since Catch Store Pro 1.0
 *
 * @see wp_add_inline_style()
 */
function catch_store_border_color_css() {
	$color_scheme  = catch_store_get_color_scheme();
	$default_color = $color_scheme[14];
	$border_color  = get_theme_mod( 'border_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $border_color === $default_color ) {
		return;
	}

	$css = '
		/* Border Color */
		table,
		tr,
		input[type="date"],
		input[type="time"],
		input[type="datetime-local"],
		input[type="week"],
		input[type="month"],
		input[type="text"],
		input[type="email"],
		input[type="url"],
		input[type="password"],
		input[type="search"],
		input[type="tel"],
		input[type="number"],
		textarea,
		fieldset,
		select,
		.author-info,
		#header-navigation-area,
		.site-footer-menu,
		.section-content-wrapper .post-wrapper,
		.page-links a,
		.page-links > span,
		.comment-respond,
		.comment-list article,
		.comment-list .pingback,
		.comment-list .trackback,
		.image-navigation,
		.comment-navigation,
		#search-top-container,
		.team-content-wrapper .post-thumbnail img,
		.featured-content-wrapper .post-thumbnail img,
		.wp-block-table,
		.wp-block-table caption,
		.wp-block-table tr,
		.wp-block-latest-comments__comment {
			border-color: %1$s;
		}

		@media screen and (min-width: 64em) {
			.site-secondary-menu ul ul,
			#header-menu-social.toggled-on,
			.primary-search-wrapper .social-navigation,
			.secondary-search-wrapper .social-navigation {
				border-color: %1$s;
			}
		}

		/* Border Color Woocommerce */
		table.cart .product-thumbnail img,
		.single-product .product_meta,
		.product_list_widget li img,
		#reviews .comment-respond,
		ul.products li.product img,
		.woocommerce ul.cart_list li,
		.woocommerce ul.product_list_widget li,
		.woocommerce-account .woocommerce-MyAccount-navigation,
		.woocommerce-account .woocommerce-MyAccount-navigation li,
		.single-product div.product .woocommerce-product-gallery__image,
		.single-product div.product .woocommerce-product-gallery .flex-control-thumbs li img,
		.product-review-section .entry-content .attachment-woocommerce_thumbnail img {
			border-color: %1$s;
		}

		@media screen and (min-width: 64em) {
			#site-product-search .widget {
				border-color: %1$s;
			}
		}
	';

	wp_add_inline_style( 'catch-store-block-style', sprintf( $css, $border_color ) );
}
add_action( 'wp_enqueue_scripts', 'catch_store_border_color_css', 11 );


/**
 * Enqueues front-end CSS for the Tertiary text color.
 *
 * @since Catch Store Pro 1.0
 *
 * @see wp_add_inline_style()
 */
function catch_store_tertiary_text_color_css() {
	$color_scheme        = catch_store_get_color_scheme();
	$default_color       = $color_scheme[15];
	$tertiary_text_color = get_theme_mod( 'tertiary_text_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $tertiary_text_color === $default_color ) {
		return;
	}

	$css = '
		/* Tertiary Text Color */
		.site-info,
		.site-info a:hover,
		.site-info a:focus,
		#site-generator .menu-toggle,
		#site-generator .site-navigation a,
		#site-generator .social-navigation a {
			color: %1$s;
		}

		/* Tertiary Text Color Woocommerce */
		.demo_store .woocommerce-store-notice__dismiss-link:hover,
		.demo_store .woocommerce-store-notice__dismiss-link:focus {
			color: %1$s;
		}
	';

	wp_add_inline_style( 'catch-store-block-style', sprintf( $css, $tertiary_text_color ) );
}
add_action( 'wp_enqueue_scripts', 'catch_store_tertiary_text_color_css', 11 );


/**
 * Enqueues front-end CSS for the border color.
 *
 * @since Catch Store Pro 1.0
 *
 * @see wp_add_inline_style()
 */
function catch_store_tertiary_text_hover_color_css() {
	$color_scheme  = catch_store_get_color_scheme();
	$default_color = $color_scheme[16];
	$tertiary_text_hover_color  = get_theme_mod( 'tertiary_text_hover_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $tertiary_text_hover_color === $default_color ) {
		return;
	}

	$css = '
		/* Tertiary Text Hover Color */
		.site-info a,
		#site-generator .menu-toggle:hover,
		#site-generator .menu-toggle:focus,
		#site-generator .site-navigation a:hover,
		#site-generator .site-navigation a:focus,
		#site-generator .social-navigation a:hover,
		#site-generator .social-navigation a:focus {
			color: %1$s;
		}

		/* Tertiary Text Hover Color Woocommerce */
		.demo_store .woocommerce-store-notice__dismiss-link {
			color: %1$s;
		}
	';

	wp_add_inline_style( 'catch-store-block-style', sprintf( $css, $tertiary_text_hover_color ) );
}
add_action( 'wp_enqueue_scripts', 'catch_store_tertiary_text_hover_color_css', 11 );


/**
 * Enqueues front-end CSS for the secondary button text color
 *
 * @since Catch Store Pro 1.0
 *
 * @see wp_add_inline_style()
 */
function catch_store_secondary_button_text_color_css() {
	$color_scheme          = catch_store_get_color_scheme();
	$default_color         = $color_scheme[17];
	$secondary_button_text_color = get_theme_mod( 'secondary_button_text_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $secondary_button_text_color === $default_color ) {
		return;
	}

	$css = '
		/* Secondary Button Text color */
		.woocommerce .product-container .button {
			color: %1$s;
		}
	';

	wp_add_inline_style( 'catch-store-block-style', sprintf( $css, $secondary_button_text_color ) );
}
add_action( 'wp_enqueue_scripts', 'catch_store_secondary_button_text_color_css', 11 );


/**
 * Enqueues front-end CSS for the secondary border color
 *
 * @since Catch Store Pro 1.0
 *
 * @see wp_add_inline_style()
 */
function catch_store_secondary_button_border_color_css() {
	$color_scheme                  = catch_store_get_color_scheme();
	$default_color                 = $color_scheme[18];
	$secondary_button_border_color = get_theme_mod( 'secondary_button_border_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $secondary_button_border_color === $default_color ) {
		return;
	}

	$css = '
		/* Secondary Button Border color */
		.woocommerce .product-container .button {
			border-color: %1$s;
		}
	';

	wp_add_inline_style( 'catch-store-block-style', sprintf( $css, $secondary_button_border_color ) );
}
add_action( 'wp_enqueue_scripts', 'catch_store_secondary_button_border_color_css', 11 );


/**
 * Enqueues front-end CSS for the secondary button hover background color
 *
 * @since Catch Store Pro 1.0
 *
 * @see wp_add_inline_style()
 */
function catch_store_secondary_button_hover_background_color_css() {
	$color_scheme                            = catch_store_get_color_scheme();
	$default_color                           = $color_scheme[19];
	$secondary_button_hover_background_color = get_theme_mod( 'secondary_button_hover_background_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $secondary_button_hover_background_color === $default_color ) {
		return;
	}

	$css = '
		/* Secondary Button Hover Background color */
		.woocommerce .product-container a.button:hover,
		.woocommerce .product-container a.button:focus {
			background-color: %1$s;
			border-color: %1$s;
		}
	';

	wp_add_inline_style( 'catch-store-block-style', sprintf( $css, $secondary_button_hover_background_color ) );
}
add_action( 'wp_enqueue_scripts', 'catch_store_secondary_button_hover_background_color_css', 11 );


/**
 * Enqueues front-end CSS for the secondary button hover text color
 *
 * @since Catch Store Pro 1.0
 *
 * @see wp_add_inline_style()
 */
function catch_store_secondary_button_hover_text_color_css() {
	$color_scheme                      = catch_store_get_color_scheme();
	$default_color                     = $color_scheme[20];
	$secondary_button_hover_text_color = get_theme_mod( 'secondary_button_hover_text_color', $default_color );

	// Don't do anything if the current color is the default.
	if ( $secondary_button_hover_text_color === $default_color ) {
		return;
	}

	$css = '
		/* Secondary Button Hover Text color */
		.woocommerce .product-container a.button:hover,
		.woocommerce .product-container a.button:focus {
			color: %1$s;
		}
	';

	wp_add_inline_style( 'catch-store-block-style', sprintf( $css, $secondary_button_hover_text_color ) );
}
add_action( 'wp_enqueue_scripts', 'catch_store_secondary_button_hover_text_color_css', 11 );



/**
 * Enqueues front-end CSS for the button text color with background
 *
 * @since Catch Store Pro 1.0
 *
 * @see wp_add_inline_style()
 */
function catch_store_button_text_color_with_background_css() {
	$color_scheme                      = catch_store_get_color_scheme();
	$default_color                     = $color_scheme[21];
	$button_text_color_with_background = get_theme_mod( 'button_text_color_with_background', $default_color );

	// Don't do anything if the current color is the default.
	if ( $button_text_color_with_background === $default_color ) {
		return;
	}

	$css = '
		/* Button Text Color With Background */
		.header-media .more-link .more-button,
		#feature-slider-section .more-link span {
			color: %1$s;
		}
	';

	wp_add_inline_style( 'catch-store-block-style', sprintf( $css, $button_text_color_with_background ) );
}
add_action( 'wp_enqueue_scripts', 'catch_store_button_text_color_with_background_css', 11 );


/**
 * Enqueues front-end CSS for the button background color with background
 *
 * @since Catch Store Pro 1.0
 *
 * @see wp_add_inline_style()
 */
function catch_store_button_background_color_with_background_css() {
	$color_scheme                      = catch_store_get_color_scheme();
	$default_color                     = $color_scheme[21];
	$button_background_color_with_background = get_theme_mod( 'button_background_color_with_background', $default_color );

	// Don't do anything if the current color is the default.
	if ( $button_background_color_with_background === $default_color ) {
		return;
	}

	$css = '
		/* Button Background Color With Background */
		.header-media .more-link .more-button,
		#feature-slider-section .more-link span {
			background-color: %1$s;
		}
	';

	wp_add_inline_style( 'catch-store-block-style', sprintf( $css, $button_background_color_with_background ) );
}
add_action( 'wp_enqueue_scripts', 'catch_store_button_background_color_with_background_css', 11 );


/**
 * Converts a HEX value to RGB.
 *
 * @since Catch Store Pro 1.0
 *
 * @param string $color The original color, in 3- or 6-digit hexadecimal form.
 * @return array Array containing RGB (red, green, and blue) values for the given
 *               HEX code, empty array otherwise.
 */
function catch_store_hex2rgb( $color ) {
	$color = trim( $color, '#' );

	if ( strlen( $color ) === 3 ) {
		$r = hexdec( substr( $color, 0, 1 ).substr( $color, 0, 1 ) );
		$g = hexdec( substr( $color, 1, 1 ).substr( $color, 1, 1 ) );
		$b = hexdec( substr( $color, 2, 1 ).substr( $color, 2, 1 ) );
	} else if ( strlen( $color ) === 6 ) {
		$r = hexdec( substr( $color, 0, 2 ) );
		$g = hexdec( substr( $color, 2, 2 ) );
		$b = hexdec( substr( $color, 4, 2 ) );
	} else {
		return array();
	}

	return array( 'red' => $r, 'green' => $g, 'blue' => $b );
}