<?php
/**
 * The template used for displaying hero content
 *
 * @package Catch_Store
 */
?>

<?php

$type = get_theme_mod( 'catch_store_hero_content_type', 'page' );

if ( 'page' === $type && $id = get_theme_mod( 'catch_store_hero_content' ) ) {
	$args['page_id'] = absint( $id );
} elseif ( 'post' === $type && $id = get_theme_mod( 'catch_store_hero_content_post' ) ) {
	$args['p'] = absint( $id );
} elseif ( 'product' === $type && $id = get_theme_mod( 'catch_store_hero_content_product' ) ) {
	$args['post_type'] = 'product';
	$args['p'] = absint( $id );
} elseif ( 'category' === $type && $cat = get_theme_mod( 'catch_store_hero_content_category' ) ) {
	$args['cat']            = absint( $cat );
	$args['posts_per_page'] = 1;
}

$img_alig = get_theme_mod( 'catch_store_hero_content_image_alignment', 'content-align-right' );

// If $args is empty return false
if ( empty( $args ) ) {
	return;
}

// Create a new WP_Query using the argument previously created
$hero_query = new WP_Query( $args );
if ( $hero_query->have_posts() ) :
	while ( $hero_query->have_posts() ) :
		$hero_query->the_post();

		$thumb = get_the_post_thumbnail_url( get_the_ID(), 'catch-store-hero-content' );

		?>
		<div id="hero-section" class="section <?php echo esc_attr( $img_alig ); ?>">
			<div class="wrapper section-content-wrapper hero-content-wrapper">
				<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
					<?php if ( has_post_thumbnail() ) : ?>
						<div class="post-thumbnail" style="background-image: url( '<?php echo esc_url( $thumb ); ?>' )">
							<a class="cover-link" href="<?php the_permalink(); ?>"></a>
						</div><!-- .post-thumbnail -->
						<div class="entry-container">
					<?php else : ?>
						<div class="entry-container full-width">
					<?php endif; ?>
						<?php if ( ! get_theme_mod( 'catch_store_disable_hero_content_title' ) ) : ?>
						<header class="entry-header section-title-wrapper">
							<?php the_title( '<h2 class="entry-title section-title">', '</h2>' ); ?>
						</header><!-- .entry-header -->
						<?php endif; ?>

						<div class="entry-content">
							<?php

								$show_content = get_theme_mod( 'catch_store_hero_content_show', 'full-content' );

								if ( 'full-content' === $show_content ) {
									the_content();
									 if ( catch_store_is_woocommerce_activated() &&  'product' === $type ) { ?>
										<div class="product-footer-meta">
											<?php woocommerce_template_loop_add_to_cart(); ?>
										</div>
									<?php }

								} elseif ( 'excerpt' === $show_content ) {
									the_excerpt();
									if ( catch_store_is_woocommerce_activated() &&  'product' === $type ) { ?>
									<div class="product-footer-meta">
										<?php woocommerce_template_loop_add_to_cart(); ?>
									</div>
								<?php }
								}

								wp_link_pages( array(
									'before'      => '<div class="page-links"><span class="page-links-title">' . __( 'Pages:', 'catch-store-pro' ) . '</span>',
									'after'       => '</div>',
									'link_before' => '<span class="page-number">',
									'link_after'  => '</span>',
									'pagelink'    => '<span class="screen-reader-text">' . __( 'Page', 'catch-store-pro' ) . ' </span>%',
									'separator'   => '<span class="screen-reader-text">, </span>',
								) );
							?>
						</div><!-- .entry-content -->

						<?php if ( get_edit_post_link() ) : ?>
							<footer class="entry-footer">
								<div class="entry-meta">
									<?php
										edit_post_link(
											sprintf(
												/* translators: %s: Name of current post */
												esc_html__( 'Edit %s', 'catch-store-pro' ),
												the_title( '<span class="screen-reader-text">"', '"</span>', false )
											),
											'<span class="edit-link">',
											'</span>'
										);
									?>
								</div>
							</footer><!-- .entry-footer -->
						<?php endif; ?>
					</div><!-- .entry-container -->
				</article><!-- #post-## -->
			</div><!-- .wrapper -->
		</div><!-- .section -->
	<?php
	endwhile;

	wp_reset_postdata();
endif;
