<?php
/**
 * The template for displaying Woo Products Review
 *
 * @package Catch Store
 */

if ( ! class_exists( 'WooCommerce' ) ) {
    // Bail if WooCommerce is not installed
    return;
}

$enable_content = get_theme_mod( 'catch_store_products_review_option', 'disabled' );

$number = get_theme_mod( 'catch_store_products_review_number', 4 );

if ( ! catch_store_check_section( $enable_content ) ) {
	// Bail if featured content is disabled.
	return;
}

	$headline = get_theme_mod( 'catch_store_products_review_headline', esc_html__( 'Testimonials', 'catch-store-pro' ) );

	$subheadline = get_theme_mod( 'catch_store_products_review_subheadline' );

	$layouts = 1;

if ( 'layout-two' === get_theme_mod( 'catch_store_products_review_layout', 'layout-two' ) ) {
	$layouts = 2;
}

$classes[] = 'section product-review-section testimonial-content-section';

$classes[] = get_theme_mod( 'catch_store_testimonial_layout', 'layout-two' );

if ( ! $headline && ! $subheadline ) {
	$classes[] = 'no-headline';
}

?>

<div id="product-review-section" class="<?php echo esc_attr( implode( ' ', $classes ) ); ?>">
	<div class="wrapper">
		<?php if ( $headline || $subheadline ) : ?>
			<div class="section-heading-wrapper product-review-section-headline">
			<?php if ( $headline ) : ?>
				<div class="section-title-wrapper">
					<h2 class="section-title"><?php echo wp_kses_post( $headline ); ?></h2>
				</div><!-- .section-title-wrapper -->
			<?php endif; ?>

			<?php if ( $subheadline ) : ?>
				<div class="taxonomy-description-wrapper section-subtitle">
					<?php
		            $subheadline = apply_filters( 'the_content', $subheadline );
		            echo str_replace( ']]>', ']]&gt;', $subheadline );
	                ?>
				</div><!-- .taxonomy-description-wrapper -->
			<?php endif; ?>
			</div><!-- .section-heading-wrapper -->
		<?php endif; ?>

		<div class="section-content-wrapper product-review-content-wrapper">
			<?php $slider_select = get_theme_mod( 'catch_store_products_review_slider', 1 );

			if ( $slider_select ) : ?>

			<!-- prev/next links -->
			<button id="product-review-slider-prev" class="cycle-prev" aria-label="Previous">
				<span class="screen-reader-text"><?php esc_html_e( 'Previous Slide', 'catch-store-pro' ); ?></span><?php echo catch_store_get_svg( array( 'icon' => 'angle-down' ) ); ?>
			</button>

			<button id="product-review-slider-next" class="cycle-next" aria-label="Next">
				<span class="screen-reader-text"><?php esc_html_e( 'Next Slide', 'catch-store-pro' ); ?></span><?php echo catch_store_get_svg( array( 'icon' => 'angle-down' ) ); ?>
			</button>	

			<!-- empty element for pager links -->
			<div id="product-review-slider-pager" class="cycle-pager"></div>

			<div class="cycle-slideshow"
				data-cycle-log="false"
				data-cycle-pause-on-hover="true"
				data-cycle-swipe="true"
				data-cycle-auto-height=container
				data-cycle-loader=false
				data-cycle-slides=".product_review_slider_wrap"
				data-cycle-pager="#product-review-slider-pager"
				data-cycle-prev="#product-review-slider-prev"
				data-cycle-next="#product-review-slider-next"
				>

				<div class="product_review_slider_wrap">
			<?php endif; ?>

			<?php
				$review_sort = get_theme_mod( 'catch_store_products_review_sort', 'highest-to-lowest' );
			
				$args = array(
				    'status'   		=> 'approve',
				    'post_status' 	=> 'publish',
				    'post_type'   	=> 'product',
				    'number'     	=> $number,
				    
			  	);

				if( 'highest-to-lowest' == $review_sort ) {
					$args['orderby'] = 'meta_value_num';
					$args['meta_key'] = 'rating';
					$args['order'] = 'DESC';
				}
				elseif('lowest-to-highest' == $review_sort) {
					$args['orderby'] = 'meta_value_num';
					$args['meta_key'] = 'rating';
					$args['order'] = 'ASC';
				}
				elseif( 'oldest' == $review_sort ) {
					$args['order'] = 'ASC';
				}
				else {
					$args['order'] = 'DESC';
				}

			$comment_query = new WP_Comment_Query;
				$comments = $comment_query->query( $args );
				$i = 1;
			foreach ($comments as $comment) {
				get_template_part( 'template-parts/product-review/content', 'review' );
				//end and start testimonial_slider_wrap div based on logic
				if ( 0 === ( $i % $layouts ) && $i < $number && $slider_select ) : ?>
					</div><!-- .product_review_slider_wrap -->

					<div class="product_review_slider_wrap">
				<?php
				endif;
				$i++;
				}

			wp_reset_postdata();
			?>

			<?php if ( $slider_select ) : ?>
				</div><!-- .product_review_slider_wrap -->
			</div><!-- .cycle-slideshow -->
			<?php endif; ?>
		</div><!-- .section-content-wrapper -->
	</div><!-- .wrapper -->
</div><!-- .product-review-section -->