<?php
/**
 * The template for displaying team content
 *
 * @package Catch_Store
 */
?>

<?php
$enable_content = get_theme_mod( 'catch_store_team_option', 'disabled' );
$show_meta    = get_theme_mod( 'catch_store_team_meta_show', 'hide-meta' );
$show_content = get_theme_mod( 'catch_store_team_show', 'hide-content' );

if ( ! catch_store_check_section( $enable_content ) ) {
	// Bail if team content is disabled.
	return;
}

$type = get_theme_mod( 'catch_store_team_type', 'demo' );

if ( 'image' !== $type && 'demo' !== $type ) {
	$team_posts = catch_store_get_posts( 'team' );

	if ( empty( $team_posts ) ) {
		return;
	}
}

$title     = get_theme_mod( 'catch_store_team_title', esc_html__( 'Our Team', 'catch-store-pro' ) );
$sub_title = get_theme_mod( 'catch_store_team_sub_title' );

$layout = get_theme_mod( 'catch_store_team_layout', 'layout-four' );
?>

<div id="team-content-section" class="section">
	<div class="wrapper">
		<?php if ( '' !== $title || '' !== $sub_title ) : ?>
			<div class="section-heading-wrapper">
				<?php if ( '' !== $title ) : ?>
					<div class="section-title-wrapper">
						<h2 class="section-title"><?php echo wp_kses_post( $title ); ?></h2>
					</div><!-- .page-title-wrapper -->
				<?php endif; ?>

				<?php if ( $sub_title ) : ?>
					<div class="taxonomy-description-wrapper section-subtitle">
							<?php
			                $sub_title = apply_filters( 'the_content', $sub_title );
			                echo wp_kses_post( str_replace( ']]>', ']]&gt;', $sub_title ) );
			                ?>
					</div><!-- .taxonomy-description-wrapper -->
				<?php endif; ?>
			</div><!-- .section-heading-wrapper -->
		<?php endif; ?>

		<div class="team-content-wrapper section-content-wrapper <?php echo esc_attr( $layout ); ?>">

			<?php
			if ( 'demo' === $type ) {
					get_template_part( 'template-parts/team/demo', 'team' );
				}
			elseif ( 'image' === $type ) {
				get_template_part( 'template-parts/team/content', 'image' );
			} else {
				$i =1;
				foreach ( $team_posts as $post ) {
					setup_postdata( $post ); ?>
					<article id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
						<div class="hentry-inner">
							<div class="artist-image-container has-social-profile">
								<?php
								if ( has_post_thumbnail() ) : ?>
									<div class="post-thumbnail">
										<a href="<?php the_permalink(); ?>">
										<?php the_post_thumbnail( 'catch-store-featured' ); ?></a>
									</div>
								<?php endif; ?>
								<div class="entry-container">
									<header class="entry-header">
										<?php if ( 'show-meta' === $show_meta  && 'image' !== $type ) : ?>
										<div class="entry-meta">
											<?php catch_store_team_entry_meta(); ?>
										</div><!-- .entry-meta -->
										<?php endif; ?>

										<?php the_title( '<h2 class="entry-title"><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">','</a></h2>' ); ?>
									</header>

									<?php
									if ( 'excerpt' === $show_content ) {
										$excerpt = get_the_excerpt();

										echo '<div class="entry-summary"><p>' . $excerpt . '</p></div><!-- .entry-summary -->';
										} elseif ( 'full-content' === $show_content ) {
										$content = apply_filters( 'the_content', get_the_content() );
										$content = str_replace( ']]>', ']]&gt;', $content );
										echo '<div class="entry-content">' . wp_kses_post( $content ) . '</div><!-- .entry-content -->';
										} ?>
									<?php catch_store_team_social_links( $i ); ?>
								</div><!-- .entry-container -->
							</div><!-- .artist-image-container -->
						</div> <!-- .hentry-inner -->
					</article> <!-- .article -->

					<?php
					$i++;
				}

				wp_reset_postdata();
			}
			?>

			<?php
				$target = get_theme_mod( 'catch_store_team_target' ) ? '_blank': '_self';
				$link   = get_theme_mod( 'catch_store_team_link', '#' );
				$text   = get_theme_mod( 'catch_store_team_text', esc_html__( 'View All', 'catch-store-pro' ) );

				if ( $text ) :
			?>

			<p class="view-more">
				<a class="button" target="<?php echo $target; ?>" href="<?php echo esc_url( $link ); ?>"><?php echo esc_html( $text ); ?></a>
			</p>
			<?php endif; ?>

		</div><!-- .team-wrapper -->
	</div><!-- .wrapper -->
</div><!-- #team-section -->
