<?php
/**
 * The template for displaying Woo Products Showcase
 *
 * @package Audioman
 */

if ( ! class_exists( 'WooCommerce' ) ) {
    // Bail if WooCommerce is not installed
    return;
}

$enable_content = get_theme_mod( 'catch_store_recent_products_showcase_option', 'disabled' );

if ( ! catch_store_check_section( $enable_content ) ) {
	// Bail if featured content is disabled.
	return;
}

$number         = get_theme_mod( 'catch_store_recent_products_showcase_number', 4 );
$columns        = get_theme_mod( 'catch_store_recent_products_showcase_columns', 4 );
$paginate       = get_theme_mod( 'catch_store_recent_products_showcase_paginate' );
$orderby        = isset( $_GET['orderby'] ) ? $_GET['orderby'] : get_theme_mod( 'catch_store_recent_products_showcase_orderby' );
$product_filter = get_theme_mod( 'catch_store_recent_products_showcase_products_filter' );
$featured       = get_theme_mod( 'catch_store_recent_products_showcase_featured' );
$order          = get_theme_mod( 'catch_store_recent_products_showcase_order' );
$skus           = get_theme_mod( 'catch_store_recent_products_showcase_skus' );
$category       = get_theme_mod( 'catch_store_recent_products_showcase_category' );

$shortcode = '[products';

if ( $number ) {
	$shortcode .= ' limit="' . esc_attr( $number ) . '"';
}

if ( $columns ) {
	$shortcode .= ' columns="' . absint( $columns ) . '"';
}

if ( $paginate ) {
	$shortcode .= ' paginate="' . esc_attr( $paginate ) . '"';
}

if ( $orderby ) {
	$shortcode .= ' orderby="' . esc_attr( $orderby ) . '"';
}

if ( $order ) {
	$shortcode .= ' order="' . esc_attr( $order ) . '"';
}

if ( $product_filter && 'none' !== $product_filter ) {
	$shortcode .= ' ' . esc_attr( $product_filter ) . '="true"';
}

if ( $skus ) {
	$shortcode .= ' skus="' . esc_attr( $skus ) . '"';
}

if ( $category ) {
	$shortcode .= ' category="' . esc_attr( $category ) . '"';
}

if ( $featured ) {
	$shortcode .= ' visibility="featured"';
}

$shortcode .= ']';

$title     = get_theme_mod( 'catch_store_recent_products_showcase_headline', esc_html__( 'Recent Products', 'catch-store-pro' ) );
$sub_title = get_theme_mod( 'catch_store_recent_products_showcase_subheadline', esc_html__( 'Trending Fashion in this Season', 'catch-store-pro' ) );
?>

<div id="product-content-section" class="section">
	<div class="wrapper">
		<?php if ( $title || $sub_title ) : ?>
			<div class="section-heading-wrapper product-section-headline">
				<?php if ( '' != $title ) : ?>
					<div class="section-title-wrapper">
						<h2 class="section-title"><?php echo wp_kses_post( $title ); ?></h2>
					</div><!-- .section-title-wrapper -->
				<?php endif; ?>

				<?php if ( $sub_title ) : ?>
					<div class="taxonomy-description-wrapper">
						<p class="section-subtitle">
							<?php echo wp_kses_post( $sub_title ); ?>
						</p>
					</div><!-- .taxonomy-description-wrapper -->
				<?php endif; ?>
			</div><!-- .section-heading-wrapper -->
		<?php endif; ?>

		<div class="section-content-wrapper product-content-wrapper">
			<?php echo do_shortcode( $shortcode ); ?>
		</div><!-- .section-content-wrapper -->

		<?php
			$target = get_theme_mod( 'catch_store_recent_products_showcase_target' ) ? '_blank': '_self';
			$link   = get_theme_mod( 'catch_store_recent_products_showcase_link', get_permalink( wc_get_page_id( 'shop' ) ) );
			$text   = get_theme_mod( 'catch_store_recent_products_showcase_text' );

			if ( $text ) :
		?>
			<p class="view-more">
				<a class="button" target="<?php echo $target; ?>" href="<?php echo esc_url( $link ); ?>"><?php echo esc_html( $text ); ?></a>
			</p>
		<?php endif; ?>
	</div><!-- .wrapper -->
</div><!-- .sectionr -->
